#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Истекло время ожидания"
#define MSG_CAPABILITIES "Невозможно переключить разрешения (capabilities)"
#define MSG_CLIENT_CLOSED_CNX "Клиент закрыл соединение"
#define MSG_CLIENT_READ_ERR "Ошибка чтения от клиента"
#define MSG_CANT_OPEN_CNX "Невозможно соединиться"
#define MSG_CANT_CREATE_DATA_SOCKET "Невозможно создать сокет для передачи данных"
#define MSG_DEBUG_CLIENT_IS "Адрес клиента:"
#define MSG_SYNTAX_ERROR_IP "Синтаксическая ошибка в IP адресе"
#define MSG_PORT_SUCCESSFUL "Команда PORT выполнена успешно"
#define MSG_ONLY_IPV4V6 "Поддерживаются только IPv4 и IPv6 (1,2)"
#define MSG_ONLY_IPV4 "Поддерживается только IPv4 (1)"
#define MSG_TIMEOUT_PARSER "Истекло время ожидания - поторопитесь в следующий раз"
#define MSG_LINE_TOO_LONG "Слишком длинная строка"
#define MSG_LOG_OVERFLOW "Клиент попытался переполнить буффер командной строки"
#define MSG_GOODBYE "Всего хорошего. Вы закачали %llu и скачали %llu килобайт."
#define MSG_DEBUG_COMMAND "Команда"
#define MSG_IS_YOUR_CURRENT_LOCATION " - текущая директория"
#define MSG_NOT_LOGGED_IN "Вы еще не ввели свое имя и пароль"
#define MSG_AUTH_UNIMPLEMENTED "Команды улучшенной безопасности (AUTH и ADAT) не реализованы"
#define MSG_NO_FILE_NAME "Не задано имя файла"
#define MSG_NO_DIRECTORY_NAME "Не задано имя директории"
#define MSG_NO_RESTART_POINT "Не заданы место, с которого нужно возобновить закачку"
#define MSG_ABOR_SUCCESS "Команда ABOR выполнена успешно"
#define MSG_MISSING_ARG "Отсутствует аргумент"
#define MSG_GARBAGE_FOUND "Мусор после целого значения"
#define MSG_VALUE_TOO_LARGE "Целое значение слишком велико"
#define MSG_IDLE_TIME "Время ожидания установлена на %lu секунд(у/ы)"
#define MSG_SITE_HELP "Распознаются следующие команды SITE"
#define MSG_BAD_CHMOD "Плохие права доступа"
#define MSG_UNKNOWN_EXTENSION "- неизвестное расширение"
#define MSG_XDBG_OK "Команда XDBG выполнена успешно, debug level установлен в %d"
#define MSG_UNKNOWN_COMMAND "Неизвестная команда"
#define MSG_TIMEOUT_NOOP "Истекло время ожидания (никаких действий в течение %lu секунд(ы))"
#define MSG_TIMEOUT_DATA "Истекло время ожидания (не поступило данных в течение %lu секунд(ы))"
#define MSG_SLEEPING "Х-р-р-р..."
#define MSG_ALREADY_LOGGED "Вы уже вошли"
#define MSG_ANY_PASSWORD "Подойдет любой пароль"
#define MSG_ANONYMOUS_LOGGED "Вошел анонимный пользователь"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Анонимный пользователь вошел на виртуальный FTP"
#define MSG_USER_OK "Чтобы войти как %s требуется пароль"
#define MSG_CANT_DO_TWICE "Невозможно сделать этого в текущем сеансе"
#define MSG_UNABLE_SECURE_ANON "Невозможно запустить безопасное анонимное FTP"
#define MSG_BANDWIDTH_RESTRICTED "Пропускная способность для вас ограничена"
#define MSG_NO_PASSWORD_NEEDED "Пароль не требуется"
#define MSG_NOTRUST "Я не могу вам доверять"
#define MSG_WHOAREYOU "Представьтесь пожалуйста"
#define MSG_AUTH_FAILED "Авторизация не удалась, извините"
#define MSG_AUTH_TOOMANY "Слишком много попыток авторизации"
#define MSG_NO_HOMEDIR "Домашняя директория не доступна - завершение"
#define MSG_NO_HOMEDIR2 "%s не существует или не доступна"
#define MSG_START_SLASH "Начало с /"
#define MSG_USER_GROUP_ACCESS "Пользователю %s разрешен групповой доступ к"
#define MSG_FXP_SUPPORT "Этот сервер поддерживает перекачку FXP"
#define MSG_RATIO "Вы должны соблюдать соотношение %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "Невозможно создать безопасную chroot() тюрьму (jail, sandbox)"
#define MSG_CURRENT_DIR_IS "OK. Текущая директория %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Текущая корневая директория %s"
#define MSG_IS_NOW_LOGGED_IN "%s вошел"
#define MSG_CANT_CHANGE_DIR "Невозможно изменить директорию на %s"
#define MSG_PATH_TOO_LONG "Слишком длинный путь"
#define MSG_CANT_PASV "Невозможно использовать команду PASV на IPv6 соединении. Используйте EPSV."
#define MSG_CANT_PASSIVE "Невозможно установить пассивное FTP соединение"
#define MSG_PORTS_BUSY "Все зарезервированные порты TCP заняты"
#define MSG_GETSOCKNAME_DATA "Невозможно определить имя локального сокета данных"
#define MSG_GETPEERNAME "Невозможно идентифицировать локальный сокет"
#define MSG_INVALID_IP "Извините, неверный адрес"
#define MSG_NO_EPSV "Используйте IPv6-совместимый клиент с поддержкой команды EPSV"
#define MSG_BAD_PORT "Извините, но я не буду подключаться к порту с номером меньшим 1024"
#define MSG_NO_FXP "Я не соединюсь с %s (только с %s)"
#define MSG_FXP "Перекачка FXP: от %s к %s"
#define MSG_NO_DATA_CONN "Нет соединения для данных"
#define MSG_ACCEPT_FAILED "Невозможно установить соединение"
#define MSG_ACCEPT_SUCCESS "Установлено соединение для данных"
#define MSG_CNX_PORT_FAILED "Невозможно открыть соединение для данных к порту %d"
#define MSG_CNX_PORT "Соединение с портом %d"
#define MSG_ANON_CANT_MKD "Извините, анонимным пользователям запрещено создавать директории"
#define MSG_ANON_CANT_RMD "Извините, анонимным пользователям запрещено удалять директории"
#define MSG_ANON_CANT_RENAME "Анонимным пользователям запрещено перемещать/переименовывать файлы"
#define MSG_ANON_CANT_CHANGE_PERMS "Анонимным пользователям запрещено изменять права доступа"
#define MSG_GLOB_NO_MEMORY "Недостаточно памяти для обработки запроса %s"
#define MSG_PROBABLY_DENIED "(Это возможно означает \"Нет доступа\")"
#define MSG_GLOB_READ_ERROR "Ошибка чтения при обработке %s"
#define MSG_GLOB_NO_MATCH "Не найдено совпадений для %s в %s"
#define MSG_CHMOD_FAILED "Невозможно изменить права доступа к %s"
#define MSG_CHMOD_SUCCESS "Изменены права доступа к %s"
#define MSG_CHMOD_TOTAL_FAILURE "Извините, но я не могу менять права доступа"
#define MSG_ANON_CANT_DELETE "Анонимным пользователям запрещено удалять файлы"
#define MSG_ANON_CANT_OVERWRITE "Анонимным пользователям запрещено изменять существующие файлы"
#define MSG_DELE_FAILED "Невозможно удалить %s"
#define MSG_DELE_SUCCESS "Удалено: %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "Ни один файл не удален"
#define MSG_LOAD_TOO_HIGH \
    "Когда вы подключились нагрузка  была равна %3.2f. Мы не разрешаем скачивать\n" \
    "анонимным пользователям когда нагрузка так высока. Закачки разрешены\n" \
    "всегда."
#define MSG_OPEN_FAILURE "Невозможно открыть %s"
#define MSG_OPEN_FAILURE2 "Невозможно открыть этот файл"
#define MSG_STAT_FAILURE "Невозможно определить размер файла"
#define MSG_STAT_FAILURE2 "Невозможн определить существует ли файл"
#define MSG_REST_TOO_LARGE_FOR_FILE "Место возобновления %lld слишком велико для файла размером %lld."
#define MSG_REST_RESET "Смещение возобновления установлено в 0"
#define MSG_NOT_REGULAR_FILE "Вы можете читать только обычные файлы"
#define MSG_NOT_MODERATED \
    "Этот файл был закачен анонимным юзером. Он не был еще одобрен\n" \
    "для скачивания администратором сайта."
#define MSG_RATIO_DENIAL \
    "Извините, но отношение закачан/скачано равно %u:%u .\n" \
    "Вы закачали %llu КБ и скачали %llu КБ. Пожалуй вам следует\n" \
    "поделиться чем-нибудь и только потом скачивать."
#define MSG_NO_MORE_TO_DOWNLOAD "Больше ничего не осталось для скачивания"
#define MSG_WINNER "Компьютер - ваш друг. Доверяйте ему"
#define MSG_KBYTES_LEFT "%.1f КБ осталось"
#define MSG_ABORTED "Перекачка остановлена"
#define MSG_DATA_WRITE_FAILED "Ошибка при попытке передать данные"
#define MSG_DATA_READ_FAILED "Ошибка при попытке принять данные"
#define MSG_MMAP_FAILED "Невозможно отобразить файл в память"
#define MSG_WRITE_FAILED "Ошибка во время записи в файл"
#define MSG_TRANSFER_RATE_M "%.3f секунд прошло, %.2f МБ/c"
#define MSG_TRANSFER_RATE_K "%.3f секунд прошло, %.2f КБ/с"
#define MSG_TRANSFER_RATE_B "%.3f секунд прошло, %.2f Б/c"
#define MSG_SPACE_FREE_M "%.1f МБ свободного места"
#define MSG_SPACE_FREE_K "%f КБ свободного дискового пространства"
#define MSG_DOWNLOADED "загрузка завершена"
#define MSG_REST_NOT_NUMERIC "команде REST необходим численный параметр"
#define MSG_REST_ASCII_STRICT "Маркер возобновления должен быть нулем в ASCII режиме"
#define MSG_REST_ASCII_WORKAROUND "Восстановление с %lld. Но мы в ASCII режиме"
#define MSG_REST_SUCCESS "Возобновление с %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Запрещенное имя директории"
#define MSG_SANITY_FILE_FAILURE "Запрещенное имя файла: %s"
#define MSG_MKD_FAILURE "Невозможно создать директорию"
#define MSG_MKD_SUCCESS "Директория была успешно создана"
#define MSG_RMD_FAILURE "Невозможно удалить директорию"
#define MSG_RMD_SUCCESS "Директория была успешно удалена"
#define MSG_TIMESTAMP_FAILURE "Невозможно получить текущее время"
#define MSG_MODE_ERROR "Поддерживаются только ASCII и бинарный режимы"
#define MSG_CREATE_FAILURE "Невозможно создать файл"
#define MSG_ABRT_ONLY "Команда ABRT возможно только во время закачки"
#define MSG_UPLOAD_PARTIAL "Частично загружено"
#define MSG_REMOVED "удалено"
#define MSG_UPLOADED "загружено"
#define MSG_GMTIME_FAILURE "Невозможно получить местное время"
#define MSG_TYPE_8BIT_FAILURE "Только восьмибитные байты поддерживаются, на дворе XXI век"
#define MSG_TYPE_UNKNOWN "Неизвестный TYPE"
#define MSG_TYPE_SUCCESS "TYPE теперь"
#define MSG_STRU_FAILURE "Поддерживается только F(ile)"
#define MSG_MODE_FAILURE "Пожалуйста используйте режим S(tream)"
#define MSG_RENAME_ABORT "Отмена предыдущей операции переименования"
#define MSG_RENAME_RNFR_SUCCESS "RNFR принято, файл существует, укажите новое имя"
#define MSG_FILE_DOESNT_EXIST "Извините, но такой файл не существует"
#define MSG_RENAME_ALREADY_THERE "Переименование не удалось - файл с таким именем уже существует"
#define MSG_RENAME_NORNFR "Необходима команда RNFR перед RNTO"
#define MSG_RENAME_FAILURE "Не удалось переименовать/перенести"
#define MSG_RENAME_SUCCESS "Файл удачно переименовал или перемещен"
#define MSG_NO_SUPERSERVER "Пожалуйста запускайте pure-ftpd из супер-сервера (как tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Не найден аккаунт 'ftp'"
#define MSG_CONF_ERR "Ошибка в конфигурации"
#define MSG_NO_VIRTUAL_FILE "Не указано имя файла виртуальных пользователей"
#define MSG_ILLEGAL_THROTTLING "Неправильно значение ограничения пропускной способности"
#define MSG_ILLEGAL_TRUSTED_GID "Неправильный идентификатор группы"
#define MSG_ILLEGAL_USER_LIMIT "Неправильно ограничение на количество пользователей"
#define MSG_ILLEGAL_FACILITY "Неправильно указан тип сервиса syslog"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Неправильный файл конфигурации LDAP"
#define MSG_ILLEGAL_LOAD_LIMIT "Недопустимое ограничении нагрузки"
#define MSG_ILLEGAL_PORTS_RANGE "Недопустимый интервал портов"
#define MSG_ILLEGAL_LS_LIMITS "Неверные ограничения для 'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "Неправильный IP для пассивных соединений"
#define MSG_ILLEGAL_RATIO "Неправильно задано отношение скачано/закачано"
#define MSG_ILLEGAL_UID_LIMIT "Неверное ограничение uid"
#define MSG_ILLEGAL_OPTION "Неизвестный параметр"
#define MSG_LDAP_MISSING_BASE "Не задано LDAPBaseDN в файле конфигурации LDAP"
#define MSG_LDAP_WRONG_PARMS "Неверный параметр LDAP"
#define MSG_NEW_CONNECTION "Новое соединение с %s"
#define MSG_WELCOME_TO "Добро пожаловать на"
#define MSG_MAX_USERS "%lu пользователей (это максимум) уже подключились, извините"
#define MSG_NB_USERS "Вы пользователь %u из %u разрешенных"
#define MSG_WELCOME_TIME "Местное время %02d:%02d. Серверный порт: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Вход разрешен только для анонимных пользователей"
#define MSG_RATIOS_EVERYONE "СОБЛЮДЕНИЕ ПРОПОРЦИИ ОБЯЗАТЕЛЬНО ДЛЯ ВСЕХ:"
#define MSG_RATIOS_ANONYMOUS "АНОНИМНЫЕ ПОЛЬЗОВАТЕЛИ ПОДВЛАСТНЫ СООТНОШЕНИЮ ЗАКАЧАНО/СКАЧАНО:"
#define MSG_RATIOS_RULE "чтобы скачать %u МБ, закачайте %u МБ."
#define MSG_INFO_IDLE_M "Вы будете отсоединены после %lu минут бездеятельности."
#define MSG_INFO_IDLE_S "Вы будете отсоединены после %lu секунд бездеятельности."
#define MSG_CANT_READ_FILE "Извините, невозможно прочитать [%s]"
#define MSG_LS_TRUNCATED "Вывод обрезан до %u совпадений"
#define MSG_LS_SUCCESS "%u совпадений"
#define MSG_LOGOUT "Отсоединение."
#define MSG_AUTH_FAILED_LOG "Авторизация не удалась пользователю [%s]"
#define MSG_ILLEGAL_UMASK "Неверно задана umask"
#define MSG_STANDALONE_FAILED "Невозможно запустить standalone сервер"
#define MSG_NO_ANONYMOUS_LOGIN "Это закрытая система - Анонимный вход не разрешен"
#define MSG_ANONYMOUS_ANY_PASSWORD "Подойдет любой пароль"
#define MSG_MAX_USERS_IP "Слишком много соединений (%lu) с этого IP"
#define MSG_ACTIVE_DISABLED "Активный режим выключен"
#define MSG_TRANSFER_SUCCESSFUL "Файл передан удачно"
#define MSG_NO_DISK_SPACE "Диск полон - закачайте позже"
#define MSG_OUT_OF_MEMORY "Нет памяти"
#define MSG_ILLEGAL_TRUSTED_IP "Неверно задан проверенный IP"
#define MSG_NO_ASCII_RESUME "Докачка ASCII ненадежна, сначала удалите файл"
#define MSG_UNKNOWN_ALTLOG "Неверно задан формат журнала"
#define MSG_ACCOUNT_DISABLED "Невозможен вход как [%s]: аккаунт отключен"
#define MSG_SQL_WRONG_PARMS "Неверные SQL параметры"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Плохой файл конфигурации SQL"
#define MSG_SQL_MISSING_SERVER "Не задан сервер файле конфигурации SQL"
#define MSG_SQL_DOWN "SQL сервер кажется не работает"
#define MSG_ILLEGAL_QUOTA "Неправильная квота"
#define MSG_QUOTA_FILES "%llu файлов используется (%d%%) - разрешено: %llu файлов"
#define MSG_QUOTA_SIZE "%llu КБ используется (%d%%) - разрешено: %llu КБ"
#define MSG_QUOTA_EXCEEDED "Превышение квоты: [%s] не будет сохранен"
#define MSG_AUTH_UNKNOWN "Неизвестный метод авторизации"
#define MSG_PDB_BROKEN "Невозможно прочитать проиндексированный файл puredb (или это старый формат) - Попробуйте pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s это псевдоним для %s."
#define MSG_ALIASES_UNKNOWN "Неизвестный псевдоним %s."
#define MSG_ALIASES_BROKEN_FILE "Разрушен файл псевдонимов"
#define MSG_ALIASES_LIST "Доступны следующие псевдонимы:"
#define MSG_PERUSER_MAX "Невозможно использовать больше чем %lu соединений от одного пользователя"
#define MSG_IPV6_OK "Соединения по IPv6 также поддерживаются на этом сервере"
#define MSG_TLS_INFO "TLS: Используется %s с %s, %d-битный секретный ключ"
#define MSG_TLS_WEAK "TLS: Ключ ненадежен"
#define MSG_TLS_NEEDED "Извините, незащищенные подключения запрещены на сервере.\n" \
     "Подключитесь еще раз, используя шифрование TLS."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
