#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Timeout"
#define MSG_CAPABILITIES "Kan ikke endre egenskaper"
#define MSG_CLIENT_CLOSED_CNX "Klienten lukket tilkoblingen"
#define MSG_CLIENT_READ_ERR "Lesefeil fra klienten"
#define MSG_CANT_OPEN_CNX "Kan ikke åpne tilkoblingen"
#define MSG_CANT_CREATE_DATA_SOCKET "Kan ikke opprette datasokkel"
#define MSG_DEBUG_CLIENT_IS "Klientens adresse er"
#define MSG_SYNTAX_ERROR_IP "Syntaks-feil i IP-adresse"
#define MSG_PORT_SUCCESSFUL "PORT-kommando lyktes"
#define MSG_ONLY_IPV4V6 "Kun IPv4 og IPv6 er støttet (1,2)"
#define MSG_ONLY_IPV4 "Kun IPv4 er støttet (1)"
#define MSG_TIMEOUT_PARSER "Timeout - prøv å skrive litt raskere neste gang"
#define MSG_LINE_TOO_LONG "Linjen er for lang"
#define MSG_LOG_OVERFLOW "Klienten prøvde å overfylle kommandolinjens buffer"
#define MSG_GOODBYE "Farvel! Du lastet opp %llu og lastet ned %llu kbytes."
#define MSG_DEBUG_COMMAND "Kommando"
#define MSG_IS_YOUR_CURRENT_LOCATION "er din nåværende posisjon"
#define MSG_NOT_LOGGED_IN "Du er ikke logget inn"
#define MSG_AUTH_UNIMPLEMENTED "Sikkerhetsutvidelse er ikke implementert"
#define MSG_NO_FILE_NAME "Intet filnavn"
#define MSG_NO_DIRECTORY_NAME "Intet katalognavn"
#define MSG_NO_RESTART_POINT "Intet restartpunkt"
#define MSG_ABOR_SUCCESS "Siden du ser dette, må ABOR ha vært vellykket"
#define MSG_MISSING_ARG "Manglende argument"
#define MSG_GARBAGE_FOUND "Søppel funnet etter verdi"
#define MSG_VALUE_TOO_LARGE "Verdi er for stor"
#define MSG_IDLE_TIME "Inaktiv tid er satt til %lu sekunder"
#define MSG_SITE_HELP "Følgende SITE-kommandoer er tilgjengelige"
#define MSG_BAD_CHMOD "Ugyldige rettigheter"
#define MSG_UNKNOWN_EXTENSION "er en ukjent utvidelse"
#define MSG_XDBG_OK "XDBG kommando vellykket, debug nivå er nå %d"
#define MSG_UNKNOWN_COMMAND "Ukjent kommando"
#define MSG_TIMEOUT_NOOP "Timeout (ingenting utført på %lu sekunder)"
#define MSG_TIMEOUT_DATA "Timeout (ingen nye data på %lu sekunder)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Du er allerede logget inn"
#define MSG_ANY_PASSWORD "Et hvilket som helst passord duger"
#define MSG_ANONYMOUS_LOGGED "Anonym bruker er logget inn"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonym bruker er logget på virtuell FTP"
#define MSG_USER_OK "Bruker %s OK. Det kreves passord"
#define MSG_CANT_DO_TWICE "Vi kan ikke gjøre det i denne forbindelsen"
#define MSG_UNABLE_SECURE_ANON "Kan ikke opprette en sikker anonym FTP-forbindelse"
#define MSG_BANDWIDTH_RESTRICTED "Din båndbredde er begrenset."
#define MSG_NO_PASSWORD_NEEDED "Hvilket som helst passord vil fungere"
#define MSG_NOTRUST "Beklager, men jeg stoler ikke på deg"
#define MSG_WHOAREYOU "Vennligst fortell meg hvem du er"
#define MSG_AUTH_FAILED "Godkjenning mislyktes, beklager"
#define MSG_AUTH_TOOMANY "For mange mislykkede innloggingsforsøk"
#define MSG_NO_HOMEDIR "Hjemmekatalogen er ikke tilgjengelig - avbryter"
#define MSG_NO_HOMEDIR2 "%s eksisterer ikke eller kan ikke nås"
#define MSG_START_SLASH "Starter i /"
#define MSG_USER_GROUP_ACCESS "Brukeren %s har gruppetilgang til"
#define MSG_FXP_SUPPORT "Denne serveren støtter FXP-overføring"
#define MSG_RATIO "Du må respektere en %u:%u (UL/DL)-ratio"
#define MSG_CHROOT_FAILED "Kan ikke sette opp en sikker chroot()-celle"
#define MSG_CURRENT_DIR_IS "OK. Nåværende katalog er %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Nåværende begrenset mappe er %s"
#define MSG_IS_NOW_LOGGED_IN "%s er nå logget inn"
#define MSG_CANT_CHANGE_DIR "Kan ikke skifte katalog til %s"
#define MSG_PATH_TOO_LONG "Sti for lang"
#define MSG_CANT_PASV "Du kan ikke bruke PASV på IPv6 tilkoblinger. Bruk heller EPSV."
#define MSG_CANT_PASSIVE "Kan ikke åpne en passiv forbindelse"
#define MSG_PORTS_BUSY "Alle reserverte TCP porter er opptatt"
#define MSG_GETSOCKNAME_DATA "Kan ikke identifisere den lokale datasokkelen"
#define MSG_GETPEERNAME "Kan ikke identifisere den lokale datasokkelen"
#define MSG_INVALID_IP "Beklager, ugyldig IP-adresse"
#define MSG_NO_EPSV "Vennligst bruk en klient som støtter IPv6 med EPSV"
#define MSG_BAD_PORT "Beklager, men jeg kan ikke koble til porter < 1024"
#define MSG_NO_FXP "Jeg kan ikke åpne en forbindelse til %s (bare til %s)"
#define MSG_FXP "FXP-overføring: fra %s til %s"
#define MSG_NO_DATA_CONN "Ingen dataforbindelse"
#define MSG_ACCEPT_FAILED "Kunne ikke godkjenne forbindelsen"
#define MSG_ACCEPT_SUCCESS "Dataforbindelse godkjent"
#define MSG_CNX_PORT_FAILED "Kan ikke åpne dataforbindelse til port %d"
#define MSG_CNX_PORT "Kobler til port %d"
#define MSG_ANON_CANT_MKD "Beklager, anonyme brukere kan ikke opprette kataloger"
#define MSG_ANON_CANT_RMD "Beklager, anonyme brukere kan ikke slette kataloger"
#define MSG_ANON_CANT_RENAME "Anonyme brukere kan ikke flytte eller endre navn på filer"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonyme brukere kan ikke endre rettigheter"
#define MSG_GLOB_NO_MEMORY "Slutt på minnet under gjennomgang av %s"
#define MSG_PROBABLY_DENIED "(Dette betyr sannsynligvis 'Ingen tilgang')"
#define MSG_GLOB_READ_ERROR "Lesefeil under gjennomgang av %s"
#define MSG_GLOB_NO_MATCH "Ingen %s i %s"
#define MSG_CHMOD_FAILED "Kunne ikke endre rettigheter på %s"
#define MSG_CHMOD_SUCCESS "Rettigheter endret på %s"
#define MSG_CHMOD_TOTAL_FAILURE "Beklager, men jeg kunne ikke endre rettigheter"
#define MSG_ANON_CANT_DELETE "Anonyme brukere kan ikke slette filer"
#define MSG_ANON_CANT_OVERWRITE "Anonyme brukere kan ikke overskrive eksisterende filer"
#define MSG_DELE_FAILED "Kunne ikke slette %s"
#define MSG_DELE_SUCCESS "%s%s%s%s slettet"
#define MSG_DELE_TOTAL_FAILURE "Ingen filer slettet"
#define MSG_LOAD_TOO_HIGH \
    "Belastningen var %3.2f når du logget på. Vi tillater ikke anonyme brukere\n" \
    "å laste ned når belastningen er så høy. Opplasting er alltid tillatt."

#define MSG_OPEN_FAILURE "Kan ikke åpne %s"
#define MSG_OPEN_FAILURE2 "Kan ikke åpne den filen"
#define MSG_STAT_FAILURE "Kan ikke finne filstørrelsen"
#define MSG_STAT_FAILURE2 "Kan ikke sjekke om filen finnes"
#define MSG_REST_TOO_LARGE_FOR_FILE "Gjenstartpunkt %lld er for stor for filstørrelse %lld."
#define MSG_REST_RESET "Gjenstartpunkt satt til 0"
#define MSG_NOT_REGULAR_FILE "Jeg kan bare motta vanlige filer"
#define MSG_NOT_MODERATED \
    "Denne filen er lastet opp av en anonym bruker. Den er ennå\n" \
    "ikke blitt godkjent for nedlasting av administratorene."
#define MSG_RATIO_DENIAL \
    "Beklager, men opplastings/nedlastings-forholdet er %u:%u .\n" \
    "Du har lastet opp %llu Kb og lastet ned %llu Kb.\n" \
    "Vennligst last opp noe før du prøver å laste ned."
#define MSG_NO_MORE_TO_DOWNLOAD "Det er ingenting igjen å laste ned"
#define MSG_WINNER "Datamaskinen er din venn. Stol på datamaskinen"
#define MSG_KBYTES_LEFT "%.1f kbytes igjen å hente"
#define MSG_ABORTED "Overføring avbrutt"
#define MSG_DATA_WRITE_FAILED "Feil under skriving til dataforbindelsen"
#define MSG_DATA_READ_FAILED "Feil under lesing fra dataforbindelsen"
#define MSG_MMAP_FAILED "Kunne ikke legge filen i minnet"
#define MSG_WRITE_FAILED "Feil under skriving til fil"
#define MSG_TRANSFER_RATE_M "%.3f sekunder (målt her), %.2f Mbytes per sekund"
#define MSG_TRANSFER_RATE_K "%.3f sekunder (målt her), %.2f Kbytes per sekund"
#define MSG_TRANSFER_RATE_B "%.3f sekunder (målt her), %.2f bytes per sekund"
#define MSG_SPACE_FREE_M "%.1f Mbytes ledig disk plass"
#define MSG_SPACE_FREE_K "%f Kbytes ledig disk plass"
#define MSG_DOWNLOADED "nedlastet"
#define MSG_REST_NOT_NUMERIC "REST krever en numerisk parameter"
#define MSG_REST_ASCII_STRICT "Svar-markør må være 0 i ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "Startet på nytt ved %lld. Men vi er i ASCII mode"
#define MSG_REST_SUCCESS "Starter på nytt ved %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Fordbudt katalognavn"
#define MSG_SANITY_FILE_FAILURE "Forbudt filnavn: %s"
#define MSG_MKD_FAILURE "Kan ikke opprette katalog"
#define MSG_MKD_SUCCESS "Katalogen ble opprettet"
#define MSG_RMD_FAILURE "Kan ikke fjerne katalog"
#define MSG_RMD_SUCCESS "Katalogen ble fjernet"
#define MSG_TIMESTAMP_FAILURE "Kan ikke hente tidsstempel"
#define MSG_MODE_ERROR "Bare ASCII og binær overføring er støttet"
#define MSG_CREATE_FAILURE "Kan ikke opprette fil"
#define MSG_ABRT_ONLY "ABRT er den eneste lovlige kommandoen under opplasting"
#define MSG_UPLOAD_PARTIAL "Delvis opplastet"
#define MSG_REMOVED "fjernet"
#define MSG_UPLOADED "opplastet"
#define MSG_GMTIME_FAILURE "Kunne ikke hente den lokale tiden"
#define MSG_TYPE_8BIT_FAILURE "Kun 8-bit bytes er støttet, vi er ikke 10 år tilbake"
#define MSG_TYPE_UNKNOWN "Ukjent TYPE"
#define MSG_TYPE_SUCCESS "TYPE er nå"
#define MSG_STRU_FAILURE "Kun F(ile) er støttet"
#define MSG_MODE_FAILURE "Vennligst bruk S(tream) mode"
#define MSG_RENAME_ABORT "Avbryter forrige omdøpingsoppgave"
#define MSG_RENAME_RNFR_SUCCESS "RNFR godkjent - filen finnes, klar for destinasjon"
#define MSG_FILE_DOESNT_EXIST "Beklager, men den filen finnes ikke"
#define MSG_RENAME_ALREADY_THERE "RENAME mislyktes - destinasjonsfilen finnes allerede"
#define MSG_RENAME_NORNFR "Trenger RNFR før RNTO"
#define MSG_RENAME_FAILURE "Omdøpings/flyttingsfeil"
#define MSG_RENAME_SUCCESS "Filen er omdøpt eller flyttet"
#define MSG_NO_SUPERSERVER "Vennligst kjør pure-ftpd fra en super-server (f.eks. tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Kunne ikke finne 'ftp'-kontoen"
#define MSG_CONF_ERR "Konfigurasjonsfeil"
#define MSG_NO_VIRTUAL_FILE "Mangler navn på virtuell bruker"
#define MSG_ILLEGAL_THROTTLING "Ugyldig verdi for throttle"
#define MSG_ILLEGAL_TRUSTED_GID "Ugyldig 'trusted gid' for chroot"
#define MSG_ILLEGAL_USER_LIMIT "Ugyldig brukerbegrensning"
#define MSG_ILLEGAL_FACILITY "Ukjent fasilitetsnavn"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Feil i LDAP-konfigurasjonsfil"
#define MSG_ILLEGAL_LOAD_LIMIT "Ugyldig load-grense"
#define MSG_ILLEGAL_PORTS_RANGE "Ugyldig port-område"
#define MSG_ILLEGAL_LS_LIMITS "Ugyldig 'ls'-begrensing"
#define MSG_ILLEGAL_FORCE_PASSIVE "Ugyldig tvungen IP-adresse til passive forbindelser"
#define MSG_ILLEGAL_RATIO "Ugyldig opplastings/nedlastings-forhold"
#define MSG_ILLEGAL_UID_LIMIT "Ugyldig uid-grense"
#define MSG_ILLEGAL_OPTION "Ukjent run-time-valg"
#define MSG_LDAP_MISSING_BASE "Mangler LDAPBaseDN i LDAP-konfigurasjonsfilen"
#define MSG_LDAP_WRONG_PARMS "Feil LDAP-parameter"
#define MSG_NEW_CONNECTION "Ny tilkobling fra %s"
#define MSG_WELCOME_TO "Velkommen til"
#define MSG_MAX_USERS "%lu brukere (maks) er allerede logget på"
#define MSG_NB_USERS "Du er bruker nummer %u av %u tillatte"
#define MSG_WELCOME_TIME "Den lokale tiden er nå %02d:%02d. Server port: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Kun anonym FTP er tillatt her"
#define MSG_RATIOS_EVERYONE "RATIO ER SATT PÅ FOR ALLE:"
#define MSG_RATIOS_ANONYMOUS "ANONYME BRUKERE BLIR UNDERLAGT UL/DL-RATIO:"
#define MSG_RATIOS_RULE "for å laste ned %u Mb, må du laste opp %u Mb med godsaker."
#define MSG_INFO_IDLE_M "Du blir koblet fra etter %lu minutters inaktivitet."
#define MSG_INFO_IDLE_S "Du blir koblet fra etter %lu sekunders inaktivitet."
#define MSG_CANT_READ_FILE "Beklager, kunne ikke lese [%s]"
#define MSG_LS_TRUNCATED "Resultat er avkortet til %u treff"
#define MSG_LS_SUCCESS "%u treff totalt"
#define MSG_LOGOUT "Logg ut."
#define MSG_AUTH_FAILED_LOG "Godkjennelse mislyktes for [%s]"
#define MSG_ILLEGAL_UMASK "Feil umask"
#define MSG_STANDALONE_FAILED "Kan ikke starte en standalone server"
#define MSG_NO_ANONYMOUS_LOGIN "Dette er et privat system - Ingen anonyme innlogginger tillatt"
#define MSG_ANONYMOUS_ANY_PASSWORD "Et hvilket som helst passord virker"
#define MSG_MAX_USERS_IP "For mange forbindelser (%lu) fra denne IP-adressen"
#define MSG_ACTIVE_DISABLED "Active mode er slått av"
#define MSG_TRANSFER_SUCCESSFUL "Overføringen av filen var vellykket"
#define MSG_NO_DISK_SPACE "Disken er full - vennligst last opp senere"
#define MSG_OUT_OF_MEMORY "Minnet er oppbrukt"
#define MSG_ILLEGAL_TRUSTED_IP "Ugyldig pålitelig IP-adresse"
#define MSG_NO_ASCII_RESUME "Å fortsette på en ASCII fil er usikkert, slett filen først."
#define MSG_UNKNOWN_ALTLOG "Ukjent loggformat"
#define MSG_ACCOUNT_DISABLED "Kan ikke logge inn som [%s]: kontoen er stengt"
#define MSG_SQL_WRONG_PARMS "Feil SQL-parametere"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Ugyldig SQL-konfigurasjonsfil"
#define MSG_SQL_MISSING_SERVER "Mangler server i SQL-konfigurasjonsfilen"
#define MSG_SQL_DOWN "SQL-serveren ser ut til å være nede"
#define MSG_ILLEGAL_QUOTA "Ugyldig quota"
#define MSG_QUOTA_FILES "%llu filer blir brukt (%d%%) - tillatt: %llu filer"
#define MSG_QUOTA_SIZE "%llu Kbytes blir brukt (%d%%) - tillatt: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Quota oversteget: [%s] blir ikke lagret"
#define MSG_AUTH_UNKNOWN "Ukjent godkjennelsesmetode"
#define MSG_PDB_BROKEN "Kan ikke lese den indekserte puredb-filen (eller den er i gammelt format) - Prøv pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s er et alias for %s."
#define MSG_ALIASES_UNKNOWN "Ukjent alias %s."
#define MSG_ALIASES_BROKEN_FILE "Ødelagt alias-fil"
#define MSG_ALIASES_LIST "Følgende alias er tilgjengelige:"
#define MSG_PERUSER_MAX "Kan ikke akseptere mer enn %lu tilkoblinger fra samme bruker"
#define MSG_IPV6_OK "IPv6-forbindelser er også velkomne på denne serveren"
#define MSG_TLS_INFO "TLS: Aktivert %s med %s, %d bits kryperingsnøkkel"
#define MSG_TLS_WEAK "TLS: Krypteringsnøkkelen er for svak"
#define MSG_TLS_NEEDED "Beklager, klartekst-forbindelser er ikke tillatt på denne serveren.\n" \
    "Vær vennlig å koble til på nytt ved bruk av TLS-sikkerhetsmekanismer."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
