#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "čas vypršel"
#define MSG_CAPABILITIES "Nemohu změnit privilegia"
#define MSG_CLIENT_CLOSED_CNX "Klient uzavřel spojení"
#define MSG_CLIENT_READ_ERR "Chyba při čtení od klienta"
#define MSG_CANT_OPEN_CNX "Nemůžu vytvořit spojení"
#define MSG_CANT_CREATE_DATA_SOCKET "Nemůžu vytvořit datový socket"
#define MSG_DEBUG_CLIENT_IS "Klientova adresa je"
#define MSG_SYNTAX_ERROR_IP "Syntaktická chyba v IP adrese"
#define MSG_PORT_SUCCESSFUL "Příkaz PORT úspěšne vykonán"
#define MSG_ONLY_IPV4V6 "Jsou podporovány pouze IPv4 a IPv6 (1,2)"
#define MSG_ONLY_IPV4 "Podporován je pouze IPv4 (1)"
#define MSG_TIMEOUT_PARSER "čas vypršel, příště zkuste psát rychleji"
#define MSG_LINE_TOO_LONG "řádek je příliš dlouhý"
#define MSG_LOG_OVERFLOW "Klient se pokusil přeplnit buffer pro příkazový řádek"
#define MSG_GOODBYE "Nashledanou. Uploadli jste %llu a downloadli %llu kilobajtů."
#define MSG_DEBUG_COMMAND "Příkaz"
#define MSG_IS_YOUR_CURRENT_LOCATION "je vaše současná location"
#define MSG_NOT_LOGGED_IN "Nejste přihlášen"
#define MSG_AUTH_UNIMPLEMENTED "Bezpečnostní rozšíření nejsou implementovány"
#define MSG_NO_FILE_NAME "žádné jméno souboru"
#define MSG_NO_DIRECTORY_NAME "žádné jméno adresáře"
#define MSG_NO_RESTART_POINT "žádný začátek restartu"
#define MSG_ABOR_SUCCESS "Vidíte-li tohle, pak příkaz ABOR byl uspěšný"
#define MSG_MISSING_ARG "Chybějící argument"
#define MSG_GARBAGE_FOUND "Za hodnotou se nachází smetí"
#define MSG_VALUE_TOO_LARGE "Příliš vysoká hodnota"
#define MSG_IDLE_TIME "čas nečinnosti nastaven na %lu sekund"
#define MSG_SITE_HELP "Nasledující SITE příkazy jsou rozeznány"
#define MSG_BAD_CHMOD "Chybná přístupová práva"
#define MSG_UNKNOWN_EXTENSION "je neznámé rozšíření"
#define MSG_XDBG_OK "Příkaz XDBG byl úspěšný, debug úroveň nastavena na %d"
#define MSG_UNKNOWN_COMMAND "Neznámý příkaz"
#define MSG_TIMEOUT_NOOP "čas vypršel (žádna operace v průběhu %lu sekund)"
#define MSG_TIMEOUT_DATA "čas vypršel (žádná nová data v průběhu %lu sekund)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Už jste přihlášenej"
#define MSG_ANY_PASSWORD "Můžete zatat libovolné heslo"
#define MSG_ANONYMOUS_LOGGED "Přihlášen jako anonymní uživatel"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonymní uživatel se přihlásil ve virtuálním FTP"
#define MSG_USER_OK "Uživatel %s je OK. Heslo je povinné"
#define MSG_CANT_DO_TWICE "Během tohoto sezení to nemohu provést"
#define MSG_UNABLE_SECURE_ANON "Nemohu nastavit bezpečné anonymní FTP"
#define MSG_BANDWIDTH_RESTRICTED "Vaše přenosová rychlost je omezena"
#define MSG_NO_PASSWORD_NEEDED MSG_ANY_PASSWORD
#define MSG_NOTRUST "Lituji, ale nemohu Vám důvěřovat"
#define MSG_WHOAREYOU "Prosím řekněte mi, kdo jste"
#define MSG_AUTH_FAILED "Lituji, ale autentifikace zlyhala"
#define MSG_AUTH_TOOMANY "Příliš mnoho zlyhaní autentifikace"
#define MSG_NO_HOMEDIR "Domovský adresář je nepřístupný - konec"
#define MSG_NO_HOMEDIR2 "%s neexistuje nebo není dosažitelný"
#define MSG_START_SLASH "Začínám v /"
#define MSG_USER_GROUP_ACCESS "Uživatel %s má skupinový přístup do"
#define MSG_FXP_SUPPORT "Tento server podporuje FXP přenosy"
#define MSG_RATIO "Musíte dodržovat poměr %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "Nemohu vytvořit bezpečnou chroot() klec"
#define MSG_CURRENT_DIR_IS "OK. Aktualní adresář je %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Aktualní omezený adresář je %s"
#define MSG_IS_NOW_LOGGED_IN "%s je pravě přihlášen"
#define MSG_CANT_CHANGE_DIR "Nemůžu přejít do adresáře %s"
#define MSG_PATH_TOO_LONG "Cesta je příliš dlouhá"
#define MSG_CANT_PASV "Nemůžete používat PASV na IPv4 přenosech. Použijte EPSV."
#define MSG_CANT_PASSIVE "Nemohu vytvořit pasivní spojení"
#define MSG_PORTS_BUSY "Všechny rezervované TCP porty jsou používány"
#define MSG_GETSOCKNAME_DATA "Nemohu identifikovat lokalní datový socket"
#define MSG_GETPEERNAME "Nemohu identifikovat lokalní socket"
#define MSG_INVALID_IP "Lituji, ale zadali jste chybnou adresu"
#define MSG_NO_EPSV "Prosím použijte klienta kompatibliního s IPv6 s podporou EPSV"
#define MSG_BAD_PORT "Lituji, ale nepřipojím se na port nižší než 1024"
#define MSG_NO_FXP "Neotevřu spojení na %s (pouze do %s)"
#define MSG_FXP "FXP přenos : z %s na %s"
#define MSG_NO_DATA_CONN "Žádné datové spojení"
#define MSG_ACCEPT_FAILED "Spojení nemohlo být akceptováno"
#define MSG_ACCEPT_SUCCESS "Datové spojení přijaté"
#define MSG_CNX_PORT_FAILED "Nemohu vytvořit datové spojení na port %d"
#define MSG_CNX_PORT "Připájím se na port %d"
#define MSG_ANON_CANT_MKD "Lituji, ale anonymní uživatel nemůže vytvářet adresáře"
#define MSG_ANON_CANT_RMD "Lituji, ale anonymní uživatel nemůže mazat adresáře"
#define MSG_ANON_CANT_RENAME "Anonymní uživatel nemůže přesuvat/přejmenovávat soubory"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymní uživatel nemůže měnit přístupová práva"
#define MSG_GLOB_NO_MEMORY "Během globbingu %s došla paměť"
#define MSG_PROBABLY_DENIED "(Tohle pravděpodobně znamená \"Odmítnutý přístup\")"
#define MSG_GLOB_READ_ERROR "Chyba čtení při globbovaní %s"
#define MSG_GLOB_NO_MATCH "Žádná shoda mezi %s v %s"
#define MSG_CHMOD_FAILED "Nemohu změnit přístupová práva na %s"
#define MSG_CHMOD_SUCCESS "Přístupová práva změněna na %s"
#define MSG_CHMOD_TOTAL_FAILURE "Lituji, ale nemohl jsem změnit žádná přístupová práva"
#define MSG_ANON_CANT_DELETE "Anonymní uživatel nemůže mazat soubory"
#define MSG_ANON_CANT_OVERWRITE "Anonymní uživatel nemůže přepisovat existující soubory"
#define MSG_DELE_FAILED "%s nelze smazat"
#define MSG_DELE_SUCCESS "Soubor %s%s%s%s smazán"
#define MSG_DELE_TOTAL_FAILURE "Žádný soubor nebyl smazán"
#define MSG_LOAD_TOO_HIGH \
  "Zátěž systému, když jste se přihlásil, byla %3.2f. Nedovolujeme dowloady\n" \
  "anonymním uživatelům při tak vysoké zátěži. Uploady jsou vždy povoleny\n"

#define MSG_OPEN_FAILURE "Nemohu otevřít %s"
#define MSG_OPEN_FAILURE2 "Nemohu otevřít ten soubor"
#define MSG_STAT_FAILURE "Nemohu zjistit velikost souboru"
#define MSG_STAT_FAILURE2 "Nemohu ověřit existenci souboru"
#define MSG_REST_TOO_LARGE_FOR_FILE "Offset %lld pro restart stahování je příliš vysoký, soubor má velikost pouze %lld."
#define MSG_REST_RESET "Začátek restartu nastaven na 0"
#define MSG_NOT_REGULAR_FILE "Soubor není běžný"
#define MSG_NOT_MODERATED \
     "Tento soubor byl uploadnut anonymním uživatelem. Administrátor serveru " \
     "ho pro download zatím neschválil."
#define MSG_RATIO_DENIAL \
     "Lituji, ale poměr upload/download je %u:%u .\n" \
     "Zatím jste uploadli %llu kilobajtů, downloadli %llu kilobajtů.\n" \
     "Jestli nám tu uploadnete něco hezkého, můžete si pak na oplátku taky něco hezkého stáhnout."
#define MSG_NO_MORE_TO_DOWNLOAD "Na download tu už nic není"
#define MSG_WINNER "Počítač je tvůj přítel. Důvěřuj mu!"
#define MSG_KBYTES_LEFT "%.1f kilobajtů na download"
#define MSG_ABORTED "Přenos přerušen"
#define MSG_DATA_WRITE_FAILED "Chyba během zápisu do datového spojení"
#define MSG_DATA_READ_FAILED "Chyba během čtení z datového spojení"
#define MSG_MMAP_FAILED "Nemůžu namapovat soubor do paměti"
#define MSG_WRITE_FAILED "Chyba během zápisu do souboru"
#define MSG_TRANSFER_RATE_M "%.3f sekund (měřeno zde), %.2f megabajtů za sekundu"
#define MSG_TRANSFER_RATE_K "%.3f sekund (měřeno zde), %.2f kilobajtů za sekundu"
#define MSG_TRANSFER_RATE_B "%.3f sekund (měřeno zde), %.2f bajtů za sekundu"
#define MSG_SPACE_FREE_M "%.1f megabajtů volného diskového prostoru"
#define MSG_SPACE_FREE_K "%f kilobjatů volného diskového prostoru"
#define MSG_DOWNLOADED "downloadnut"
#define MSG_REST_NOT_NUMERIC "REST vyžaduje číselný parametr"
#define MSG_REST_ASCII_STRICT "Označení odpovědi musí být 0 v ASCII režimu"
#define MSG_REST_ASCII_WORKAROUND "Pokračuji od %lld. Ale jsme v ASCII režimu"
#define MSG_REST_SUCCESS "Pokračuji od %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Zakázaný název adresáře"
#define MSG_SANITY_FILE_FAILURE "Zakázaný název souboru: %s"
#define MSG_MKD_FAILURE "Nemohu vytvořit adresář"
#define MSG_MKD_SUCCESS "Adresář byl úspěšně vytvořen"
#define MSG_RMD_FAILURE "Nemohu smazat adresář"
#define MSG_RMD_SUCCESS "Adresář byl úspěšně smazán"
#define MSG_TIMESTAMP_FAILURE "Nemohu získat časovu značku"
#define MSG_MODE_ERROR "Podporován je pouze ASCII a binární režim"
#define MSG_CREATE_FAILURE "Nemohu vytvořit soubor"
#define MSG_ABRT_ONLY "Příkaz ABRT je možné použít pouze během uploadu."
#define MSG_UPLOAD_PARTIAL "částěčně uploadnut"
#define MSG_REMOVED "odstraněn"
#define MSG_UPLOADED "uploadnut"
#define MSG_GMTIME_FAILURE "Nemohu zjistit lokální čas"
#define MSG_TYPE_8BIT_FAILURE "Podporuju pouze 8 bitové bajty, odkud jste přišel, člověče??"
#define MSG_TYPE_UNKNOWN "Neznámý TYPE"
#define MSG_TYPE_SUCCESS "TYPE je nyní"
#define MSG_STRU_FAILURE "Pouze F(ile) je podporován"
#define MSG_MODE_FAILURE "Prosím použijte S(tream) režim"
#define MSG_RENAME_ABORT "Přerušuji předešlé přejmenování"
#define MSG_RENAME_RNFR_SUCCESS "Příkaz RNFR byl akceptován, soubor existuje, očekávám cíl"
#define MSG_FILE_DOESNT_EXIST "Lituji, ale zadaný soubor neexistuje"
#define MSG_RENAME_ALREADY_THERE "Příkaz RENAME selhal - cílový soubor již existuje"
#define MSG_RENAME_NORNFR "Potřebuji RNFR před RNTO"
#define MSG_RENAME_FAILURE "Chyba přemenování/přesunu"
#define MSG_RENAME_SUCCESS "Soubor úspněšně přesunut/přemenován"
#define MSG_NO_SUPERSERVER "Prosím spouštějte pure-ftpd ze super-serveru (například z tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nemohu najít účet 'ftp'"
#define MSG_CONF_ERR "Chyba konfigurace"
#define MSG_NO_VIRTUAL_FILE "Chybějící soubor virtualních uživatelů"
#define MSG_ILLEGAL_THROTTLING "Chybná hodnota škrcení rychlosti přenosu"
#define MSG_ILLEGAL_TRUSTED_GID "Chybná důvěřovaná gid pro chroot"
#define MSG_ILLEGAL_USER_LIMIT "Chybný limit uživatelů"
#define MSG_ILLEGAL_FACILITY "Neznámé jméno služby"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Chybný konfigurační soubor LDAPu"
#define MSG_ILLEGAL_LOAD_LIMIT "Chyný limit meze zátěže systému"
#define MSG_ILLEGAL_PORTS_RANGE "Chybný rozsah portů"
#define MSG_ILLEGAL_LS_LIMITS "Chybný limit pro 'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "Chybná vnucená IP pro pasivní přenosy"
#define MSG_ILLEGAL_RATIO "Chybný upload/download poměr"
#define MSG_ILLEGAL_UID_LIMIT "Chybný uid limit"
#define MSG_ILLEGAL_OPTION "Neznámá run-time volba"
#define MSG_LDAP_MISSING_BASE "Chybějící LDAPBaseDN v konfiguračním souboru LDAPu"
#define MSG_LDAP_WRONG_PARMS "Chybné LDAP parametry"
#define MSG_NEW_CONNECTION "Nové spojení z %s"
#define MSG_WELCOME_TO "Vítejte na"
#define MSG_MAX_USERS "Lituji, ale %lu (maximum) uživatelů je již přihlášených"
#define MSG_NB_USERS "Jste uživatelem číslo %u z %u povolených"
#define MSG_WELCOME_TIME "Lokalní čas je %02d:%02d. Port serveru je %u."
#define MSG_ANONYMOUS_FTP_ONLY "Zde je povolen pouze anonymní přístup"
#define MSG_RATIOS_EVERYONE "VŠICHNI UŽIVATELE MUSI DODRŽET POMER UL/DL :"
#define MSG_RATIOS_ANONYMOUS "ANONYMNI UŽIVATELE MUSI DODRŽET POMER UL/DL :"
#define MSG_RATIOS_RULE "na download %u MB musíte uploadnut %u MB."
#define MSG_INFO_IDLE_M "Budete odpojeni po %lu minutách nečinnosti."
#define MSG_INFO_IDLE_S "Budete odpojeni po %lu sekundách nečinnosti."
#define MSG_CANT_READ_FILE "Lituji, nebyl jsem schopný přečíst [%s]"
#define MSG_LS_TRUNCATED "Výstup zkrácen na %u shod"
#define MSG_LS_SUCCESS "Spolu %u shod"
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Autentifikace uživatele selhala [%s]"
#define MSG_ILLEGAL_UMASK "Neplatná maska"
#define MSG_STANDALONE_FAILED "Nemohu spustit samostatný server"
#define MSG_NO_ANONYMOUS_LOGIN "Tohle je soukromý systém - anonymní uživatelé jsou zakázáni"
#define MSG_ANONYMOUS_ANY_PASSWORD "Můžete zadat libovolné heslo"
#define MSG_MAX_USERS_IP "Příliš mnoho aktivních spojení (%lu) z vaší IP"
#define MSG_ACTIVE_DISABLED "Aktivní režim je vypnut"
#define MSG_TRANSFER_SUCCESSFUL "Soubor byl úspěšně přenesen"
#define MSG_NO_DISK_SPACE "Disk je plný, zkuste později"
#define MSG_OUT_OF_MEMORY "Nedostatek paměti"
#define MSG_ILLEGAL_TRUSTED_IP "Neplatná důvěřovaná IP adresa"
#define MSG_NO_ASCII_RESUME "Pokračování přenosu v ASCII režime není bezpečné, soubor nejdřív smažte, prosím"
#define MSG_UNKNOWN_ALTLOG "Neznámý logovací formát"
#define MSG_ACCOUNT_DISABLED "Nemůžete se přihlásit jako [%s] : účet je deaktivován"
#define MSG_SQL_WRONG_PARMS "Chybné SQL parametry"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Chybný konfigurační soubor SQL"
#define MSG_SQL_MISSING_SERVER "V konfiguračním souboru chybí SQL server"
#define MSG_SQL_DOWN "Vypadá to, že SQL server spadl"
#define MSG_ILLEGAL_QUOTA "Chybná kvota"
#define MSG_QUOTA_FILES "%llu souborů použitých (%d%%) - autorizovaných: %llu souborů"
#define MSG_QUOTA_SIZE "%llu kilobajtů použitých (%d%%) - autorizovaných: %llu kilobajtů"
#define MSG_QUOTA_EXCEEDED "Kvota překročena: [%s] nebude uložen"
#define MSG_AUTH_UNKNOWN "Neznámá autentifikační metoda"
#define MSG_PDB_BROKEN "Nebylo možné přečíst indexovaný soubor puredb (nebo byla detekována stará verze) - Vyzkoušejte spustit pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s je alias pro %s."
#define MSG_ALIASES_UNKNOWN "Neznámý alias %s."
#define MSG_ALIASES_BROKEN_FILE "Poškozen soubor s aliasy"
#define MSG_ALIASES_LIST "Jsou dostupné nasledující aliasy:"
#define MSG_PERUSER_MAX "Nemohu akceptovat víc než %lu připojení stejného uživatele"
#define MSG_IPV6_OK "Na tento server se lze rovněž připojovat použitím IPv6 protokolu"
#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Neplatný argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
