#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Timeout"
#define MSG_CAPABILITIES "Oförmögen att ändra möjligheter"
#define MSG_CLIENT_CLOSED_CNX "Klienten avbröt anslutningen"
#define MSG_CLIENT_READ_ERR "Läsfel från klienten"
#define MSG_CANT_OPEN_CNX "Kan ej ansluta"
#define MSG_CANT_CREATE_DATA_SOCKET "Kan ej skapa data socket"
#define MSG_DEBUG_CLIENT_IS "Klientens adress är"
#define MSG_SYNTAX_ERROR_IP "Syntax error i IP adress"
#define MSG_PORT_SUCCESSFUL "PORT kommando lyckades"
#define MSG_ONLY_IPV4V6 "Endast stöd för IPv4 och IPv6 (1,2)"
#define MSG_ONLY_IPV4 "Endast stöd för IPv4 (1)"
#define MSG_TIMEOUT_PARSER "Timeout - försök att skriva snabbare nästa gång"
#define MSG_LINE_TOO_LONG "Raden är för lång"
#define MSG_LOG_OVERFLOW "Klienten försökte fylla kommandoradsbufferten"
#define MSG_GOODBYE "Adjö. Du har laddat upp %llu och laddat ned %llu kbytes."
#define MSG_DEBUG_COMMAND "Kommando"
#define MSG_IS_YOUR_CURRENT_LOCATION "är din nuvarande plats"
#define MSG_NOT_LOGGED_IN "Du är inte inloggad"
#define MSG_AUTH_UNIMPLEMENTED "Säkerhetsfunktionen är ej installerad"
#define MSG_NO_FILE_NAME "Filnamn saknas"
#define MSG_NO_DIRECTORY_NAME "Biblioteksnamn saknas"
#define MSG_NO_RESTART_POINT "Omstartsplats saknas"
#define MSG_ABOR_SUCCESS "Eftersom du ser det här måste ABOR lyckats"
#define MSG_MISSING_ARG "Argument saknas"
#define MSG_GARBAGE_FOUND "Skräp efter värde"
#define MSG_VALUE_TOO_LARGE "Värdet är för stort"
#define MSG_IDLE_TIME "Idle time är %lu sekunder"
#define MSG_SITE_HELP "Följande SITE kommandon känns igen"
#define MSG_BAD_CHMOD "Felaktig behörighet"
#define MSG_UNKNOWN_EXTENSION "är en okänd extension"
#define MSG_XDBG_OK "XDBG kommando lyckades, debug nivå är nu %d"
#define MSG_UNKNOWN_COMMAND "Okänt kommando"
#define MSG_TIMEOUT_NOOP "Timeout (ingen inmatning under %lu sekunder)"
#define MSG_TIMEOUT_DATA "Timeout (inga nya data under %lu sekunder)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Du är redan inloggad"
#define MSG_ANY_PASSWORD "Vilket lösenord som helst fungerar"
#define MSG_ANONYMOUS_LOGGED "Anonym användare är inloggad"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonym användare loggade in i virtuell FTP"
#define MSG_USER_OK "Användare %s OK. Lösenord krävs"
#define MSG_CANT_DO_TWICE "Vi kan inte göra det i denna session"
#define MSG_UNABLE_SECURE_ANON "Oförmögen att starta säker anonym FTP"
#define MSG_BANDWIDTH_RESTRICTED "Din bandbredd är begränsad"
#define MSG_NO_PASSWORD_NEEDED "Vilket lösenord som helst fungerar"
#define MSG_NOTRUST "Jag kan tyärr inte lita på Dig"
#define MSG_WHOAREYOU "Var vänlig och tala om vem Du är"
#define MSG_AUTH_FAILED "Behörighetskontroll misslyckades"
#define MSG_AUTH_TOOMANY "För många behörighetskontroller har misslyckats"
#define MSG_NO_HOMEDIR "Hembibliotek är inte tillgängligt - avbryter"
#define MSG_NO_HOMEDIR2 "%s existerar inte eller kan ej nås"
#define MSG_START_SLASH "Startar i /"
#define MSG_USER_GROUP_ACCESS "Användare %s har grupptillhörighet"
#define MSG_FXP_SUPPORT "Denna server stödjer FXP överföringar"
#define MSG_RATIO "Du måste respektera en %u:%u (UL/DL) kvot"
#define MSG_CHROOT_FAILED "Oförmögen att starta ett säkert chroot() skal"
#define MSG_CURRENT_DIR_IS "OK. Nuvarande bibliotek är %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Nuvarande begränsade bibliotek är %s"
#define MSG_IS_NOW_LOGGED_IN "%s har loggat in"
#define MSG_CANT_CHANGE_DIR "Kan ej ändra bibliotek till %s"
#define MSG_PATH_TOO_LONG "Sökvägen är för lång"
#define MSG_CANT_PASV "Du kan ej använda PASV på IPv6 anslutningar. Använd EPSV istället."
#define MSG_CANT_PASSIVE "Kan ej öppna en passiv anslutning"
#define MSG_PORTS_BUSY "Alla reserverade TCP portar är upptagna"
#define MSG_GETSOCKNAME_DATA "Kan ej identifiera lokal data socket"
#define MSG_GETPEERNAME "Kan ej identifiera lokal socket"
#define MSG_INVALID_IP "Felaktig adress"
#define MSG_NO_EPSV "Var vänlig och använd en IPv6 klient med EPSV stöd"
#define MSG_BAD_PORT "Jag ansluter ej till portar < 1024"
#define MSG_NO_FXP "Jag öppnar ej en anslutning till %s (endast till %s)"
#define MSG_FXP "FXP överföring: från %s till %s"
#define MSG_NO_DATA_CONN "Ingen dataförbindelse"
#define MSG_ACCEPT_FAILED "Anslutningen kunde ej accepteras"
#define MSG_ACCEPT_SUCCESS "Dataförbindelsen accepteras"
#define MSG_CNX_PORT_FAILED "Kan ej öppna dataförbindelse till port %d"
#define MSG_CNX_PORT "Ansluter till port %d"
#define MSG_ANON_CANT_MKD "Anonyma användare har inte behörighet att skapa bibliotek"
#define MSG_ANON_CANT_RMD "Anonyma användare har inte behörighet att radera bibliotek"
#define MSG_ANON_CANT_RENAME "Anonyma användare har inte behörighet att flytta eller byta namn på filer"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonyma användare kan inte ändra rättigheter"
#define MSG_GLOB_NO_MEMORY "Minnet är slut pga globbing av %s"
#define MSG_PROBABLY_DENIED "(Detta betyder antagligen \"Åtkomst nekad\")"
#define MSG_GLOB_READ_ERROR "Läsfel under globbing av %s"
#define MSG_GLOB_NO_MATCH "Ingen träff för %s i %s"
#define MSG_CHMOD_FAILED "Kan ej ändra rättigheter på %s"
#define MSG_CHMOD_SUCCESS "Rättigheter ändrade på %s"
#define MSG_CHMOD_TOTAL_FAILURE "Jag kunde inte ändra någon rättighet"
#define MSG_ANON_CANT_DELETE "Anonyma användare kan inte radera filer"
#define MSG_ANON_CANT_OVERWRITE "Anonyma användare kan inte skriva över existerande filer"
#define MSG_DELE_FAILED "Kan ej radera %s"
#define MSG_DELE_SUCCESS "Raderade %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "Ingen fil är raderad"
#define MSG_LOAD_TOO_HIGH \
    "Belastningen var %3.2f när du upprättade förbindelse. Vi tillåter ej nedladdningar\n" \
    "av anonyma användare när belastningen är såpass hög. Uppladdningar är alltid\n" \
    "tillåtna."
#define MSG_OPEN_FAILURE "Kan ej öppna %s"
#define MSG_OPEN_FAILURE2 "Kan ej öppna den filen"
#define MSG_STAT_FAILURE "Kan ej finna filstorleken"
#define MSG_STAT_FAILURE2 "Kan ej kontrollera filens existens"
#define MSG_REST_TOO_LARGE_FOR_FILE "Omstart offset %lld är för stor för filstorlek %lld."
#define MSG_REST_RESET "Omstart offset är satt till 0"
#define MSG_NOT_REGULAR_FILE "Jag kan bara hämta normala filer"
#define MSG_NOT_MODERATED \
    "Denna fil har laddats upp av en anonym användare. Den har ännu\n" \
    "inte blivit godkänd för nedladdning av systemadministratör."
#define MSG_RATIO_DENIAL \
    "Uppladdning/nedladdningskvoten är  %u:%u .\n" \
    "Du har laddat upp %llu Kb och laddat ned %llu Kb.\n" \
    "Vänligen ladda upp litet goa grejer och försök suga senare."
#define MSG_NO_MORE_TO_DOWNLOAD "Inget kvar att ladda ned"
#define MSG_WINNER "Datorn är Din vän. Lita på datorn"
#define MSG_KBYTES_LEFT "%.1f kbytes att ladda ned"
#define MSG_ABORTED "Överföring avbruten"
#define MSG_DATA_WRITE_FAILED "Fel under write to data anslutning"
#define MSG_DATA_READ_FAILED "Fel under read from data anslutning"
#define MSG_MMAP_FAILED "Oförmögen att lägga filen i minnet"
#define MSG_WRITE_FAILED "Fel då data skrivs till fil"
#define MSG_TRANSFER_RATE_M "%.3f sekunder (uppmätt här), %.2f Mbytes per sekund"
#define MSG_TRANSFER_RATE_K "%.3f sekunder (uppmätt här), %.2f Kbytes per sekund"
#define MSG_TRANSFER_RATE_B "%.3f sekunder (uppmätt här), %.2f bytes per sekund"
#define MSG_SPACE_FREE_M "%.1f Mbytes ledigt diskutrymme"
#define MSG_SPACE_FREE_K "%f Kbytes ledigt diskutrymme"
#define MSG_DOWNLOADED "nedladdad"
#define MSG_REST_NOT_NUMERIC "REST behöver numerisk parameter"
#define MSG_REST_ASCII_STRICT "Svarsmarkör måste vara 0 i ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "Startar om vid %lld. Men vi är i ASCII mode"
#define MSG_REST_SUCCESS "Startar om vid %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Biblioteksnamnet är ej tillåtet"
#define MSG_SANITY_FILE_FAILURE "Filnamnet %s är ej tillåtet"
#define MSG_MKD_FAILURE "Kan ej skapa bibliotek"
#define MSG_MKD_SUCCESS "Biblioteket har skapats"
#define MSG_RMD_FAILURE "Kan ej radera biblioteket"
#define MSG_RMD_SUCCESS "Biblioteket har raderats"
#define MSG_TIMESTAMP_FAILURE "Kan ej erhålla time stamp"
#define MSG_MODE_ERROR "Endast stöd för ASCII och binary modes"
#define MSG_CREATE_FAILURE "Kan ej skapa fil"
#define MSG_ABRT_ONLY "ABRT är det enda tillåtna kommandot vid uppladdning"
#define MSG_UPLOAD_PARTIAL "delvis uppladdad"
#define MSG_REMOVED "raderad"
#define MSG_UPLOADED "uppladdad"
#define MSG_GMTIME_FAILURE "Kunde ej erhålla lokal tid"
#define MSG_TYPE_8BIT_FAILURE "Endast stöd för 8-bit bytes , Hallå - vakna!"
#define MSG_TYPE_UNKNOWN "Okänd TYPE"
#define MSG_TYPE_SUCCESS "TYPE är nu"
#define MSG_STRU_FAILURE "Endast stöd för F(ile)"
#define MSG_MODE_FAILURE "Använd S(tream) mode"
#define MSG_RENAME_ABORT "Avbryter tidigare namnbytesoperation"
#define MSG_RENAME_RNFR_SUCCESS "RNFR accepteras - filen existerar, redo för destination"
#define MSG_FILE_DOESNT_EXIST "Filen existerar ej"
#define MSG_RENAME_ALREADY_THERE "RENAME misslyckades - destinationsfilen finns redan"
#define MSG_RENAME_NORNFR "Behöver RNFR före RNTO"
#define MSG_RENAME_FAILURE "Byt namn/flytta misslyckades"
#define MSG_RENAME_SUCCESS "Filen har bytt namn eller flyttats"
#define MSG_NO_SUPERSERVER "Kör pure-ftpd i en super-server (t ex tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Kan ej hitta 'ftp' kontot"
#define MSG_CONF_ERR "Konfigurationsfel"
#define MSG_NO_VIRTUAL_FILE "Virtuella användares filnamn saknas"
#define MSG_ILLEGAL_THROTTLING "Illegalt värde för throttling"
#define MSG_ILLEGAL_TRUSTED_GID "Illegal betrodd gid för chroot"
#define MSG_ILLEGAL_USER_LIMIT "Illegal användargräns"
#define MSG_ILLEGAL_FACILITY "Okänt namn"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Felaktig LDAP konfigurationsfil"
#define MSG_ILLEGAL_LOAD_LIMIT "Illegal belastningsgräns"
#define MSG_ILLEGAL_PORTS_RANGE "Illegalt portspann"
#define MSG_ILLEGAL_LS_LIMITS "Illegal 'ls' begränsning"
#define MSG_ILLEGAL_FORCE_PASSIVE "Illegal tvingad IP för passiva anslutningar"
#define MSG_ILLEGAL_RATIO "Illegal upp-/nedladdningskvot"
#define MSG_ILLEGAL_UID_LIMIT "Illegal uid begränsning"
#define MSG_ILLEGAL_OPTION "Okänt körningsval"
#define MSG_LDAP_MISSING_BASE "LDAPBaseDN saknas i LDAP konfigurationsfil"
#define MSG_LDAP_WRONG_PARMS "Felaktiga LDAP parametrar"
#define MSG_NEW_CONNECTION "Nyanslutning från %s"
#define MSG_WELCOME_TO "Välkommen till"
#define MSG_MAX_USERS "%lu användare (maximala antalet) är redan inloggade"
#define MSG_NB_USERS "Du är användare nummer %u av %u tillåtna"
#define MSG_WELCOME_TIME "Lokal tid är nu %02d:%02d. Server port: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Endast anonym FTP är tillåten"
#define MSG_RATIOS_EVERYONE "RATIOS är aktiverat för ALLA:"
#define MSG_RATIOS_ANONYMOUS "ANONYMA användare utsätts för en UL/DL kvot:"
#define MSG_RATIOS_RULE "för att ladda ned %u Mb, är det nödvändigt att ladda upp %u Mb."
#define MSG_INFO_IDLE_M "Du kommer att kopplas ned efter %lu minuters inaktivitet."
#define MSG_INFO_IDLE_S "Du kommer att kopplas ned efter %lu sekunders inaktivitet."
#define MSG_CANT_READ_FILE "Kan ej läsa [%s]"
#define MSG_LS_TRUNCATED "Utdata trunkeras till %u träffar"
#define MSG_LS_SUCCESS "%u träffar totalt"
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Behörighetskontroll misslyckas för användare [%s]"
#define MSG_ILLEGAL_UMASK "Ogiltig umask"
#define MSG_STANDALONE_FAILED "Kan ej starta standalone server"
#define MSG_NO_ANONYMOUS_LOGIN "Detta är ett privat system - Ingen anonym login"
#define MSG_ANONYMOUS_ANY_PASSWORD "Vilket lösenord som helst fungerar"
#define MSG_MAX_USERS_IP "För många anslutningar (%lu) från denna IP"
#define MSG_ACTIVE_DISABLED "Aktiv mode är avstängd"
#define MSG_TRANSFER_SUCCESSFUL "Filen har öveförts"
#define MSG_NO_DISK_SPACE "Disken är full - Vänligen ladda upp senare"
#define MSG_OUT_OF_MEMORY "Minnet är slut"
#define MSG_ILLEGAL_TRUSTED_IP "Ogiltig betrodd IP adress"
#define MSG_NO_ASCII_RESUME "ASCII resume är osäker, radera filen först"
#define MSG_UNKNOWN_ALTLOG "Okänt loggningsformat"
#define MSG_ACCOUNT_DISABLED "Kan ej logga in som [%s]: kontot är avstängt"
#define MSG_SQL_WRONG_PARMS "Fel SQL parametrar"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Felaktig SQL konfigurationsfil"
#define MSG_SQL_MISSING_SERVER "Server saknas i SQL konfigurationsfil"
#define MSG_SQL_DOWN "SQL servern förefaller vara nere"
#define MSG_ILLEGAL_QUOTA "Ogiltig kvot"
#define MSG_QUOTA_FILES "%llu filer använda (%d%%) - authorized: %llu files"
#define MSG_QUOTA_SIZE "%llu Kbytes använda (%d%%) - Tillåtet: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Kvoten överskriden: [%s] kommer inte att sparas"
#define MSG_AUTH_UNKNOWN "Okänd behörighetskontroll"
#define MSG_PDB_BROKEN "Kan ej läsa den indexerade puredb filen (eller gammalt format) - Försök med pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s är ett alias för %s."
#define MSG_ALIASES_UNKNOWN "Okänt alias %s."
#define MSG_ALIASES_BROKEN_FILE "Skadad alias fil"
#define MSG_ALIASES_LIST "Följande alias är tillgängliga :"
#define MSG_PERUSER_MAX "Jag kan inte acceptera fler än %lu anslutningar från en och samma användare"
#define MSG_IPV6_OK "IPv6 anslutningar är också välkomna till denna server"
#define MSG_TLS_INFO "TLS: Använder %s med %s, %d bitars kryptering"
#define MSG_TLS_WEAK "TLS: Krypteringen är för svag"
#define MSG_TLS_NEEDED "Tyvärr är sessioner i klartext inte tillåtna på denna server.\n" \
    "Vänligen återanslut och använd TLS för ökad säkerhet."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
