#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Timeout"
#define MSG_CAPABILITIES "Impossibile modificare i permessi"
#define MSG_CLIENT_CLOSED_CNX "Il client ha chiuso la connessione"
#define MSG_CLIENT_READ_ERR "Errore di lettura dal client"
#define MSG_CANT_OPEN_CNX "Impossibile aprire la connessione"
#define MSG_CANT_CREATE_DATA_SOCKET "Impossibile creare il socket dati"
#define MSG_DEBUG_CLIENT_IS "L'indirizzo del client è"
#define MSG_SYNTAX_ERROR_IP "Errore di sintassi nell'indirizzo IP"
#define MSG_PORT_SUCCESSFUL "Comando PORT eseguito con successo"
#define MSG_ONLY_IPV4V6 "Sono supportati solo IPv4 e IPv6 (1,2)"
#define MSG_ONLY_IPV4 "È supportato solo IPv4 (1)"
#define MSG_TIMEOUT_PARSER "Timeout - prova a digitare più velocemente la prossima volta"
#define MSG_LINE_TOO_LONG "Linea troppo lunga"
#define MSG_LOG_OVERFLOW "Il client ha cercato di mandare in overflow il buffer della linea di comando"
#define MSG_GOODBYE "Arrivederci. Hai uploadato %llu e downloadato %llu kbytes."
#define MSG_DEBUG_COMMAND "Comando"
#define MSG_IS_YOUR_CURRENT_LOCATION "è la tua locazione corrente"
#define MSG_NOT_LOGGED_IN "Non ti sei loggato"
#define MSG_AUTH_UNIMPLEMENTED "Estensioni di sicurezza non implementate"
#define MSG_NO_FILE_NAME "Nessun nome di file"
#define MSG_NO_DIRECTORY_NAME "Nessun nome di directory"
#define MSG_NO_RESTART_POINT "Nessun punto di ripresa"
#define MSG_ABOR_SUCCESS "Visto che vedi questo, ABOR deve essere riuscito"
#define MSG_MISSING_ARG "Argomento mancante"
#define MSG_GARBAGE_FOUND "Trovata spazzatura dopo il valore"
#define MSG_VALUE_TOO_LARGE "Valore troppo grande"
#define MSG_IDLE_TIME "Tempo di inattività impostato a %lu secondi"
#define MSG_SITE_HELP "I seguenti comandi SITE sono riconosciuti"
#define MSG_BAD_CHMOD "Permessi non validi"
#define MSG_UNKNOWN_EXTENSION "è una estensione sconosciuta"
#define MSG_XDBG_OK "Comando XDBG riuscito, il livello di debug è ora %d"
#define MSG_UNKNOWN_COMMAND "Comando sconosciuto"
#define MSG_TIMEOUT_NOOP "Timeout (nessuna operazione per %lu secondi)"
#define MSG_TIMEOUT_DATA "Timeout (nessun nuovo dato per %lu secondi)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Sei gia' loggato"
#define MSG_ANY_PASSWORD "Qualunque password funzionerà"
#define MSG_ANONYMOUS_LOGGED "Utente anonimo loggato"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Utente anonimo loggato nell'FTP virtuale"
#define MSG_USER_OK "Utente %s OK. Richiesta password"
#define MSG_CANT_DO_TWICE "Non possiamo farlo nella sessione corrente"
#define MSG_UNABLE_SECURE_ANON "Impossibile attivare un FTP anonimo sicuro"
#define MSG_BANDWIDTH_RESTRICTED "Il tuo uso della larghezza di banda è ristetto"
#define MSG_NO_PASSWORD_NEEDED "Qualunque password funzionerà"
#define MSG_NOTRUST "Mi dispiace, ma non posso fidarmi di te"
#define MSG_WHOAREYOU "Per favore dimmi chi sei"
#define MSG_AUTH_FAILED "Autenticazione fallita, spiacente"
#define MSG_AUTH_TOOMANY "Troppe autenticazioni fallite"
#define MSG_NO_HOMEDIR "Home directory non disponibile - annullo"
#define MSG_NO_HOMEDIR2 "%s non esiste o è irraggiungibile"
#define MSG_START_SLASH "Partenza in /"
#define MSG_USER_GROUP_ACCESS "L'utente %s ha accesso di gruppo"
#define MSG_FXP_SUPPORT "Questo server supporta trasferimenti FXP"
#define MSG_RATIO "Devi rispettare una ratio di %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "Impossibile impostare un jail chroot() sicuro"
#define MSG_CURRENT_DIR_IS "OK. La directory corrente è %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. La directory limitata corrente è %s"
#define MSG_IS_NOW_LOGGED_IN "%s è ora loggato"
#define MSG_CANT_CHANGE_DIR "Impossibile cambiare la directory in %s"
#define MSG_PATH_TOO_LONG "Percorso troppo lungo"
#define MSG_CANT_PASV "Non puoi usare PASV nelle connessioni IPv6. Usa EPSV invece."
#define MSG_CANT_PASSIVE "Impossibile aprire una connessione passiva"
#define MSG_PORTS_BUSY "Tutte le porte TCP riservate sono occupate"
#define MSG_GETSOCKNAME_DATA "Impossibile identificare il socket dati locale"
#define MSG_GETPEERNAME "Impossibile identificare il socket locale"
#define MSG_INVALID_IP "Spiacente, indirizzo fornito non valido"
#define MSG_NO_EPSV "Prego, usare un client comforme a IPv6 con supportp per  EPSV"
#define MSG_BAD_PORT "Spiacente, ma non mi connetto a porte < 1024"
#define MSG_NO_FXP "Non aprirò una connessione verso %s (solo verso %s)"
#define MSG_FXP "Trasferimento FXP: da %s a %s"
#define MSG_NO_DATA_CONN "Nessuna connessione dati"
#define MSG_ACCEPT_FAILED "La connessione non può essere accettata"
#define MSG_ACCEPT_SUCCESS "Connessione dati accettata"
#define MSG_CNX_PORT_FAILED "Impossibile aprire una connessione dati sulla porta %d"
#define MSG_CNX_PORT "Mi sto collegando alla porta %d"
#define MSG_ANON_CANT_MKD "Spiacente, gli utenti anonimi non hanno il permesso di creare directories"
#define MSG_ANON_CANT_RMD "Spiacente, gli utenti anonimi non hanno il permesso di cancellare directories"
#define MSG_ANON_CANT_RENAME "Gli utenti anonimi non hanno il permesso di spostare/rinominare files"
#define MSG_ANON_CANT_CHANGE_PERMS "Gli utnti anonimi non possono cambiare i permessi"
#define MSG_GLOB_NO_MEMORY "Memoria esaurita durante il globbing di %s"
#define MSG_PROBABLY_DENIED "(Questo probabilmente significa \"Permesso negato\")"
#define MSG_GLOB_READ_ERROR "Errore di lettura durante il globbing di %s"
#define MSG_GLOB_NO_MATCH "Nessuna corrispondenza di %s in %s"
#define MSG_CHMOD_FAILED "Impossibile cambiare i permessi su %s"
#define MSG_CHMOD_SUCCESS "Permessi cambiati su %s"
#define MSG_CHMOD_TOTAL_FAILURE "Spiacente, ma non posso cambiare nessun permesso"
#define MSG_ANON_CANT_DELETE "Gli utenti anonimi non possono cancellare files"
#define MSG_ANON_CANT_OVERWRITE "Gli utenti anonimi non possono sovrascrivere files esistenti"
#define MSG_DELE_FAILED "Impossibile cancellare %s"
#define MSG_DELE_SUCCESS "Cancellato %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "Nessun file cancellato"
#define MSG_LOAD_TOO_HIGH \
    "Il carico era %3.2f quando ti sei connesso. Non permettiamo downloads\n" \
    "da parte di utenti anonimi quando il carico è così alto. Gli uploads sono sempre\n" \
    "permessi."
#define MSG_OPEN_FAILURE "Impossibile aprire %s"
#define MSG_OPEN_FAILURE2 "Impossibile aprire quel file"
#define MSG_STAT_FAILURE "Impossibile trovare la dimensione del file"
#define MSG_STAT_FAILURE2 "Impossibile controllare l'esistenza del file"
#define MSG_REST_TOO_LARGE_FOR_FILE "L'offset di ripartenza %lld è troppo grande per la dimensione del file %lld."
#define MSG_REST_RESET "Offset di ripartenza resettato a 0"
#define MSG_NOT_REGULAR_FILE "Posso servire solo normali files"
#define MSG_NOT_MODERATED \
    "Questo file è stato uploadato da un utente anonimo. Non è\n" \
    "stato ancora approvato per il downloading dagli amministratore del sito."
#define MSG_RATIO_DENIAL \
    "Spiacente, ma la ratio di upload/download è %u:%u .\n" \
    "Hai uploadato %llu Kb e downloadato %llu Kb.\n" \
    "Per favore uploada un po' di roba e prova a scaricare più tardi."
#define MSG_NO_MORE_TO_DOWNLOAD "Niente altro da downloadare"
#define MSG_WINNER "Il computer è tuo amico. Fidati del computer"
#define MSG_KBYTES_LEFT "%.1f kbytes da downloadare"
#define MSG_ABORTED "Trasferimento annullato"
#define MSG_DATA_WRITE_FAILED "Errore durante la scrittura sulla connessione dati"
#define MSG_DATA_READ_FAILED "Errore durante la lettura dalla connessione dati"
#define MSG_MMAP_FAILED "Impossibile mappare il file in memoria"
#define MSG_WRITE_FAILED "Errore durante la scrittura sul file"
#define MSG_TRANSFER_RATE_M "%.3f secondi (misurati qui), %.2f Mbytes al secondo"
#define MSG_TRANSFER_RATE_K "%.3f secondi (misurati qui), %.2f Kbytes al secondo"
#define MSG_TRANSFER_RATE_B "%.3f secondi (misurati qui), %.2f bytes al secondo"
#define MSG_SPACE_FREE_M "%.1f Mbytes di spazio libero su disco"
#define MSG_SPACE_FREE_K "%f Kbytes di spazio libero su disco"
#define MSG_DOWNLOADED "downloadato"
#define MSG_REST_NOT_NUMERIC "REST ha bisogno di un parametro numerico"
#define MSG_REST_ASCII_STRICT "Il marcatore di reply deve essere 0 in modalità ASCII"
#define MSG_REST_ASCII_WORKAROUND "Ripartenza a %lld. Ma siamo in modalità ASCII"
#define MSG_REST_SUCCESS "Ripartenza a %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Nome directory proibito"
#define MSG_SANITY_FILE_FAILURE "Nome file proibito: %s"
#define MSG_MKD_FAILURE "Impossibile creare la directory"
#define MSG_MKD_SUCCESS "La directory è stata creata con successo"
#define MSG_RMD_FAILURE "Impossibile cancellare la directory"
#define MSG_RMD_SUCCESS "La directory è stata cancellata con successo"
#define MSG_TIMESTAMP_FAILURE "Impossibile ottenere un timestamp"
#define MSG_MODE_ERROR "Sono supportati solo le modalità ASCII e binary"
#define MSG_CREATE_FAILURE "Impossibile creare il file"
#define MSG_ABRT_ONLY "ABRT è l'unico comando consentito durante l'upload"
#define MSG_UPLOAD_PARTIAL "parzialmente uploadato"
#define MSG_REMOVED "cancellato"
#define MSG_UPLOADED "uploadato"
#define MSG_GMTIME_FAILURE "Impossibile ottenere l'ora locale"
#define MSG_TYPE_8BIT_FAILURE "Sono supportati solo bytes di 8-bit, non siamo rimasti a 10 anni fà"
#define MSG_TYPE_UNKNOWN "TYPE sconosciuto"
#define MSG_TYPE_SUCCESS "TYPE è ora"
#define MSG_STRU_FAILURE "È supportato solo F(ile)"
#define MSG_MODE_FAILURE "Per favore usa la modalità S(tream)"
#define MSG_RENAME_ABORT "Annullo la precedente operazione di rinomina"
#define MSG_RENAME_RNFR_SUCCESS "RNFR accettato - il file esiste, pronto per destinazione"
#define MSG_FILE_DOESNT_EXIST "Spiacente, ma quel file non esiste"
#define MSG_RENAME_ALREADY_THERE "RENAME Fallito - il file di destinazione esiste già"
#define MSG_RENAME_NORNFR "È necessario RNFR prima di RNTO"
#define MSG_RENAME_FAILURE "Errore in rinomina/sposta"
#define MSG_RENAME_SUCCESS "File rinominato o spostato con successo"
#define MSG_NO_SUPERSERVER "Lancia pure-ftpd da un super-server (come tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Impossibile trovare l'account 'ftp'"
#define MSG_CONF_ERR "Errore di configurazione"
#define MSG_NO_VIRTUAL_FILE "Nome file degli utenti virtuali mancante"
#define MSG_ILLEGAL_THROTTLING "Valore per throttling non valido"
#define MSG_ILLEGAL_TRUSTED_GID "Gid trusted per chroot non valido"
#define MSG_ILLEGAL_USER_LIMIT "Limite utenti non valido"
#define MSG_ILLEGAL_FACILITY "Nome facility sconosciuto"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "File di configurazione LDAP non valido"
#define MSG_ILLEGAL_LOAD_LIMIT "Limite di carico non valido"
#define MSG_ILLEGAL_PORTS_RANGE "Range di porte non valido"
#define MSG_ILLEGAL_LS_LIMITS "Limiti 'ls' non validi"
#define MSG_ILLEGAL_FORCE_PASSIVE "Indirizzo IP forzato per connessioni passive non valido"
#define MSG_ILLEGAL_RATIO "Ratio di upload/download non valida"
#define MSG_ILLEGAL_UID_LIMIT "Limite uid non valido"
#define MSG_ILLEGAL_OPTION "Opzione run-time sconosciuta"
#define MSG_LDAP_MISSING_BASE "LDAPBaseDN mancante nel file di configurazione LDAP"
#define MSG_LDAP_WRONG_PARMS "Parametri LDAP errati"
#define MSG_NEW_CONNECTION "Nuova connessione da %s"
#define MSG_WELCOME_TO "Benvenuto in"
#define MSG_MAX_USERS "%lu utenti (il massimo) sono già colleggati, spiacente"
#define MSG_NB_USERS "Sei l'utente numero %u di %u consentiti"
#define MSG_WELCOME_TIME "L'ora locale è %02d:%02d. Porta del server: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Qui è permesso solo FTP anonimo"
#define MSG_RATIOS_EVERYONE "LE RATIOS SONO ABILITATE PER TUTTI:"
#define MSG_RATIOS_ANONYMOUS "GLI UTENTI ANONIMI SONO SOGGETTI A UNA RATIO DI UL/DL  :"
#define MSG_RATIOS_RULE "per downloadare %u Mb, è obbligatorio uploadare %u Mb di roba."
#define MSG_INFO_IDLE_M "Sarai disconnesso dopo %lu minuti di inattività."
#define MSG_INFO_IDLE_S "Sarai disconnesso dopo  %lu secondi di inattività."
#define MSG_CANT_READ_FILE "Spiacente, impossibile leggere [%s]"
#define MSG_LS_TRUNCATED "Output troncato a %u corrispondenze"
#define MSG_LS_SUCCESS "%u corrispondenze totali"
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Autenticazione falita per l'utente [%s]"
#define MSG_ILLEGAL_UMASK "Umask non valida"
#define MSG_STANDALONE_FAILED "Impossibile avviare il server in modalità standalone"
#define MSG_NO_ANONYMOUS_LOGIN "Questo è un sistema privato - Nessun login anonimo"
#define MSG_ANONYMOUS_ANY_PASSWORD "Qualunque password funzionerà"
#define MSG_MAX_USERS_IP "Troppe connessioni (%lu) da questo IP"
#define MSG_ACTIVE_DISABLED "La modalità attiva è disabilitata"
#define MSG_TRANSFER_SUCCESSFUL "File trasferito con successo"
#define MSG_NO_DISK_SPACE "Disco pieno - uploada più tardi"
#define MSG_OUT_OF_MEMORY "Memoria esaurita"
#define MSG_ILLEGAL_TRUSTED_IP "Indirizzo IP trusted non valido"
#define MSG_NO_ASCII_RESUME "Il resume ASCII non è sicuro, cancella prima il file"
#define MSG_UNKNOWN_ALTLOG "Formato di logging sconosciuto"
#define MSG_ACCOUNT_DISABLED "Impossibile loggarsi come [%s] : account disabilitato"
#define MSG_SQL_WRONG_PARMS "Parametri SQL errati"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "File di configurazione SQL non valido "
#define MSG_SQL_MISSING_SERVER "Server mancante nel file di configurazione SQL"
#define MSG_SQL_DOWN "Il server SQL sembra essere down"
#define MSG_ILLEGAL_QUOTA "Quota non valida"
#define MSG_QUOTA_FILES "%llu files usati (%d%%) - autorizzati: %llu files"
#define MSG_QUOTA_SIZE "%llu Kbytes usati (%d%%) - autorizzati: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Quota superata : [%s] non verrà salvato"
#define MSG_AUTH_UNKNOWN "Metodo di autenticazione sconosciuto"
#define MSG_PDB_BROKEN "Impossibile leggere il file puredb indicizzato (o è stato trovato un vecchio formato) - Prova con pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s è un alias per %s."
#define MSG_ALIASES_UNKNOWN "Alias %s sconosciuto."
#define MSG_ALIASES_BROKEN_FILE "File degli aliases danneggiato"
#define MSG_ALIASES_LIST "Sono disponibili i seguenti aliases :"
#define MSG_PERUSER_MAX "Non posso accettare più di %lu connessioni dallo stesso utente"
#define MSG_IPV6_OK "Anche le connessioni IPv6 sono benvenute su questo server"
#define MSG_TLS_INFO "TLS: Abilitato %s con cifratura %s a %d bit"
#define MSG_TLS_WEAK "TLS: Cifratura troppo debole"
#define MSG_TLS_NEEDED "Spiacente, su questo server non sono ammesse sessioni in chiaro.\n" \
    "Ricollegati usando i sistemi di sicurezza TLS."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
