#define MSG_TLS_CIPHER_FAILED "TLS: Y a une couillasse dans ton TLSCipherSuite '%s'"
#define MSG_TIMEOUT "Putain mais achete-toi des doigts"
#define MSG_CAPABILITIES "Ton kernel m'a envoye chier"
#define MSG_CLIENT_CLOSED_CNX "Le mec s'est casse"
#define MSG_CLIENT_READ_ERR "Il s'est deco comme un porc"
#define MSG_CANT_OPEN_CNX "Je te parle pas a toi"
#define MSG_CANT_CREATE_DATA_SOCKET "Fuck off"
#define MSG_DEBUG_CLIENT_IS "Le mec a pour IP "
#define MSG_SYNTAX_ERROR_IP "C'est quoi cette IP de merde ?"
#define MSG_PORT_SUCCESSFUL "Ta commande PORT tu peux te la foutre au cul"
#define MSG_ONLY_IPV4V6 "C'est quoi ce protocole de merde ?"
#define MSG_ONLY_IPV4 "T'as que de l'IPv4, loser"
#define MSG_TIMEOUT_PARSER "Putain mais tu dors ou quoi ? Degage, bouffon"
#define MSG_LINE_TOO_LONG "Dans tes reves"
#define MSG_LOG_OVERFLOW "Meme pas en reve"
#define MSG_GOODBYE "Degage connard, tu m'as balance %llu Ko dans la gueule et pompe %llu Ko."
#define MSG_DEBUG_COMMAND "Commande"
#define MSG_IS_YOUR_CURRENT_LOCATION "c'est la ou tu te trouves ducon"
#define MSG_NOT_LOGGED_IN "Dans tes reves"
#define MSG_AUTH_UNIMPLEMENTED "Je chiffrerai pas ta merde"
#define MSG_NO_FILE_NAME "Et le nom du fichier, tu me le chies ?"
#define MSG_NO_DIRECTORY_NAME "File un nom de repertoire, on verra apres"
#define MSG_NO_RESTART_POINT "Super, essaye encore"
#define MSG_ABOR_SUCCESS "L'enfoire, il a coupe mon transfert"
#define MSG_MISSING_ARG "Le mec, il sait meme pas se servir du FTP"
#define MSG_GARBAGE_FOUND "Mais bien sur... y en a pas un peu trop, la ?"
#define MSG_VALUE_TOO_LARGE "Comment il se la pete. Va te faire foutre"
#define MSG_IDLE_TIME "Tu crois que je vais poireauter %lu secondes ?"
#define MSG_SITE_HELP "Le manuel du petit branleur :"
#define MSG_BAD_CHMOD "Ton chmod, tu vas le bouffer"
#define MSG_UNKNOWN_EXTENSION "est une extension a la con"
#define MSG_XDBG_OK "Genre tu vas debugger mon soft... Pfft... Le niveau est %d"
#define MSG_UNKNOWN_COMMAND "Va te faire foutre"
#define MSG_TIMEOUT_NOOP "Putain mais tu glandes depuis %lu secondes ? T'es mort ?"
#define MSG_TIMEOUT_DATA "Eh, ca fait %lu secondes que je m'emmerde"
#define MSG_SLEEPING "Fais tourner le techi..."
#define MSG_ALREADY_LOGGED "Tu t'amuses ?"
#define MSG_ANY_PASSWORD "Eh, t'as pas une clope ?"
#define MSG_ANONYMOUS_LOGGED "Salut tete de mort. Si tu peta mon FTP ma parole j'te bute"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Ahah, le bouffon, il est sur un serveur virtuel"
#define MSG_USER_OK "Eh %s ! File-moi ton code de carte bleue"
#define MSG_CANT_DO_TWICE "Et la marmotte, elle met le chocolat dans le papier d'alu"
#define MSG_UNABLE_SECURE_ANON "C'est quoi ce delire, le ftp anonyme il est tout fucke"
#define MSG_BANDWIDTH_RESTRICTED "T'es un bouffon, tu merites une bande passante de merde"
#define MSG_NO_PASSWORD_NEEDED "Si tu me balances un mot de passe, t'es vraiment trop con"
#define MSG_NOTRUST "Ton compte, j'ai enveloppe un keebab dedans"
#define MSG_WHOAREYOU "Eh, mais tu joues a quoi, la ?"
#define MSG_AUTH_FAILED "Va te faire foutre"
#define MSG_AUTH_TOOMANY "Degage connard, va jouer ailleurs"
#define MSG_NO_HOMEDIR "Mon pitbull a bouffe ton home directory"
#define MSG_NO_HOMEDIR2 "%s s'est fait humidifier le rectum"
#define MSG_START_SLASH "Bon, on va direct en /"
#define MSG_USER_GROUP_ACCESS "Putain, %s il fait partie de"
#define MSG_FXP_SUPPORT "Le FXP est active, alors balance de la wawa"
#define MSG_RATIO "T'es un pote, j'te fais un ratio de %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "Le chroot() deconne"
#define MSG_CURRENT_DIR_IS "OK. On va voir si y a de la bonne dans %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Mais tu restes dans ta cite : %s"
#define MSG_IS_NOW_LOGGED_IN "%s vient de debarquer"
#define MSG_CANT_CHANGE_DIR "C'est quoi ce delire, je peux pas aller dans %s"
#define MSG_PATH_TOO_LONG "Tu delires"
#define MSG_CANT_PASV "Gros con, c'est pas la bonne commande pour IPv6"
#define MSG_CANT_PASSIVE "J'en veux pas de ta connexion passive de merde"
#define MSG_PORTS_BUSY "La machine est toute flinguee, y a pu de port libre"
#define MSG_GETSOCKNAME_DATA "J'ai trop bu, je vais gerber un gros meulard"
#define MSG_GETPEERNAME "Y a eu un sale delire, j'ai pas pu voir qui c'etait"
#define MSG_INVALID_IP "Adresse de merde"
#define MSG_NO_EPSV "C'est quoi ce client a deux balles ?"
#define MSG_BAD_PORT "Ton port < 1024 tu va le bouffer avec tes couilles"
#define MSG_NO_FXP "Tu crois que je vais parler a %s ? Tu reves (seulement a %s)"
#define MSG_FXP "Transfert de 0-day warez : depuis %s vers %s"
#define MSG_NO_DATA_CONN "Sans connexion de donnees ca va etre hardos"
#define MSG_ACCEPT_FAILED "Putain, mais j'en veux pas de ta socket"
#define MSG_ACCEPT_SUCCESS "Tu pues de la gueule"
#define MSG_CNX_PORT_FAILED "Je peux pas aller sur le port %d"
#define MSG_CNX_PORT "Ca me casse les couilles, mais je vais me connecter au port %d"
#define MSG_ANON_CANT_MKD "Un utilisateur anonyme ca cree pas de repertoire, bordel"
#define MSG_ANON_CANT_RMD "Tu touches pas a ce repertoire, ou je peta ta reum"
#define MSG_ANON_CANT_RENAME "Tu me cherches ou quoi ?"
#define MSG_ANON_CANT_CHANGE_PERMS "C'est ca, va jouer au chmod avec ta soeur"
#define MSG_GLOB_NO_MEMORY "Bordel, y a pas assez de memoire pour %s"
#define MSG_PROBABLY_DENIED "(ou alors t'as essayer de me faire un coup de pute)"
#define MSG_GLOB_READ_ERROR "Ca me fait chier d'evaluer %s"
#define MSG_GLOB_NO_MATCH "Tu sors ca d'ou ? Y a pas de %s dans %s"
#define MSG_CHMOD_FAILED "Va te faire pratiquer un coit anal et touche pas a %s"
#define MSG_CHMOD_SUCCESS "Un chmod sur %s c'est little player quand meme"
#define MSG_CHMOD_TOTAL_FAILURE "Ahah comment t'as trop l'air d'un con sur ce coup-la"
#define MSG_ANON_CANT_DELETE "Tu touches pas a ce putain de fichier ou je te butte"
#define MSG_ANON_CANT_OVERWRITE "Ce fichier, il est cool, alors t'es gentil, tu touches pas"
#define MSG_DELE_FAILED "T'as pas assez de couilles pour butter %s"
#define MSG_DELE_SUCCESS "%s%s%s%s s'est fait defoncer la face"
#define MSG_DELE_TOTAL_FAILURE "Total loser"
#define MSG_LOAD_TOO_HIGH \
    "Le serveur a une putain de charge de %3.2f .\n" \
    "Alors tu vas pomper ailleurs.\n" \
    "(par contre tu peux toujours balancer de la bonne stuff)."
#define MSG_OPEN_FAILURE "Dans tes reves, le fichier %s"
#define MSG_OPEN_FAILURE2 "Mais va te faire foutre, bordel"
#define MSG_STAT_FAILURE "La taille du fichier c'est quoi ?"
#define MSG_STAT_FAILURE2 "Sans fichier ca va pas etre facile"
#define MSG_REST_TOO_LARGE_FOR_FILE "Ton offset de ouf %lld il devrait pas depasser %lld."
#define MSG_REST_RESET "Chez Simone, c'est 10 balles la pipe"
#define MSG_NOT_REGULAR_FILE "Et mon pipe, tu l'as vu mon gros pipe ?"
#define MSG_NOT_MODERATED \
    "Ca te plairait de pomper ce fichier, hein ?\n" \
    "Il a pas ete modere alors : FUCK OFF."
#define MSG_RATIO_DENIAL \
    "T'es un bouffon, ton ratio est de %u:%u .\n" \
    "T'as balance %llu Ko et pompe %llu Ko.\n" \
    "Alors balance de la stuff ou casse-toi."
#define MSG_NO_MORE_TO_DOWNLOAD "Plus rien a pepom"
#define MSG_WINNER "Total respekt"
#define MSG_KBYTES_LEFT "%.1f Ko a pomper"
#define MSG_ABORTED "Putain mais pourquoi t'as tout arrete ? T'es con ou quoi ?"
#define MSG_DATA_WRITE_FAILED "Il m'a raccroche a la gueule cet enfoire"
#define MSG_DATA_READ_FAILED "Putain il s'est barre, l'encule"
#define MSG_MMAP_FAILED "Le systeme il est fucke, meme le mmap() il marche pas"
#define MSG_WRITE_FAILED "Une sodo par un ours, ca te dit ?"
#define MSG_TRANSFER_RATE_M "%.3f secondes (mesurees ici), %.2f Mo par seconde"
#define MSG_TRANSFER_RATE_K "%.3f secondes (mesurees ici), %.2f Ko par seconde"
#define MSG_TRANSFER_RATE_B "%.3f secondes (mesurees ici), %.2f octets par seconde"
#define MSG_SPACE_FREE_M "%.1f Mo dispos pour rajouter de la bonne"
#define MSG_SPACE_FREE_K "%f Ko dispos, c'est tout ?"
#define MSG_DOWNLOADED "leeche"
#define MSG_REST_NOT_NUMERIC "REST c'est pas pour les bouffons"
#define MSG_REST_ASCII_STRICT "C'est quoi ton client de merde ?"
#define MSG_REST_ASCII_WORKAROUND "Ton client de merde veut recommencer en %lld."
#define MSG_REST_SUCCESS "Ok, on se la refait a partir de %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Dans tes reves, ce repertoire"
#define MSG_SANITY_FILE_FAILURE "Ca te fait envie, le fichier %s, hein ?"
#define MSG_MKD_FAILURE "Ton repertoire, il pue la fouf moisie"
#define MSG_MKD_SUCCESS "Tiens, ton repertoire a la con"
#define MSG_RMD_FAILURE "Genre tu veux peta le repertoire, ahahah"
#define MSG_RMD_SUCCESS "T'es vraiment un batard d'avoir peta le repertoire"
#define MSG_TIMESTAMP_FAILURE "C'est quoi ce systeme de merde ?"
#define MSG_MODE_ERROR "Il sort d'ou ton MODE a deux balles ?"
#define MSG_CREATE_FAILURE "T'es trop con, j'en veux pas de ton fichier"
#define MSG_ABRT_ONLY "Tu te degonfles, bouffon ?"
#define MSG_UPLOAD_PARTIAL "Il en manque la moitie, c'est trop nul"
#define MSG_REMOVED "s'est mange un kick dans la face"
#define MSG_UPLOADED "a ete balance"
#define MSG_GMTIME_FAILURE "Eh, eh, eh, t'as l'heure ?"
#define MSG_TYPE_8BIT_FAILURE "Elle sort d'ou ton architecture ?"
#define MSG_TYPE_UNKNOWN "TYPE de merde"
#define MSG_TYPE_SUCCESS "TYPE on va se le faire en"
#define MSG_STRU_FAILURE "Seul F(ile) assure"
#define MSG_MODE_FAILURE "Mode S(tream)"
#define MSG_RENAME_ABORT "Je renomme rien, ca me fait chier"
#define MSG_RENAME_RNFR_SUCCESS "Putain moi j'aimais bien l'ancien nom"
#define MSG_FILE_DOESNT_EXIST "Ouais, sauf que le fichier il existe pas"
#define MSG_RENAME_ALREADY_THERE "Y a deja un truc qui s'appelle comme ca"
#define MSG_RENAME_NORNFR "T'as rien compris a la vie"
#define MSG_RENAME_FAILURE "Ahaahaha, ca a foire, bien fait"
#define MSG_RENAME_SUCCESS "Bon voila, c'est fait"
#define MSG_NO_SUPERSERVER "Pure-FTPd faut le lancer a partir d'un super-serveur"
#define MSG_NO_FTP_ACCOUNT "Y a meme pas de compte 'ftp' sur cette becane de merde"
#define MSG_CONF_ERR "Ta conf elle est pourrie"
#define MSG_NO_VIRTUAL_FILE "Et le fichier de conf avec les users, il est ou ?"
#define MSG_ILLEGAL_THROTTLING "C'est quoi ton delire avec la bande passante ?"
#define MSG_ILLEGAL_TRUSTED_GID "gid de confiance toute defoncee"
#define MSG_ILLEGAL_USER_LIMIT "Limitation utilisateur de merde"
#define MSG_ILLEGAL_FACILITY "Tu sais meme pas te servir du syslog"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Et la confi LDAP je me la fous au cul ?"
#define MSG_ILLEGAL_LOAD_LIMIT "Eh, tu sais pas c'est quoi une limite de charge ?"
#define MSG_ILLEGAL_PORTS_RANGE "Liste de ports toute fuckee"
#define MSG_ILLEGAL_LS_LIMITS "Limitations de 'ls' toutes merdiques"
#define MSG_ILLEGAL_FORCE_PASSIVE "Tu forces les connexions vers n'importe nawak"
#define MSG_ILLEGAL_RATIO "Ratio d'upload/download tout pourrave"
#define MSG_ILLEGAL_UID_LIMIT "Limitation d'UID merdique"
#define MSG_ILLEGAL_OPTION "Faut lire le manuel, bouffon"
#define MSG_LDAP_MISSING_BASE "LDAPBaseDN manquant dans le fichier de configuration LDAP"
#define MSG_LDAP_WRONG_PARMS "Parametre LDAP pourrave"
#define MSG_NEW_CONNECTION "%s ramene son cul"
#define MSG_WELCOME_TO "C'est de la bonne :"
#define MSG_MAX_USERS "%lu relous (le maximum) sont deja connectes, degage"
#define MSG_NB_USERS "T'es le numero %u sur les %u max."
#define MSG_WELCOME_TIME "L'heure locale est %02d:%02d. Port du serveur : %u."
#define MSG_ANONYMOUS_FTP_ONLY "Je prend que les mecs anonymes"
#define MSG_RATIOS_EVERYONE "Y A DES RATIOS POUR TOUS LES UTILISATEURS :"
#define MSG_RATIOS_ANONYMOUS "LES UTILISATEURS ANONYMES ONT DES RATIOS DE UL/DL :"
#define MSG_RATIOS_RULE "Pour leecher %u Mo, tu dois balancer %u Mo."
#define MSG_INFO_IDLE_M "Si tu pionces plus de %lu minutes, tu te fais tej."
#define MSG_INFO_IDLE_S "Si tu pionces plus de %lu secondes tu te fais tej."
#define MSG_CANT_READ_FILE "[%s] il suce des bites en enfer"
#define MSG_LS_TRUNCATED "Je t'en file %u et c'est deja pas mal"
#define MSG_LS_SUCCESS "%u elements, y a de la stuff"
#define MSG_LOGOUT "Cassos."
#define MSG_AUTH_FAILED_LOG "[%s] c'est un batard, il connait pas son code"
#define MSG_ILLEGAL_UMASK "Umask pourrave"
#define MSG_STANDALONE_FAILED "Le serveur en standalone ? Tu reves."
#define MSG_NO_ANONYMOUS_LOGIN "Soit t'as un compte ici, soit tu te casses tout de suite"
#define MSG_ANONYMOUS_ANY_PASSWORD "Eh, elle est bonne ta soeur ?"
#define MSG_MAX_USERS_IP "Trop de relous (%lu) depuis cette IP"
#define MSG_ACTIVE_DISABLED "Mode actif plus actif du tout"
#define MSG_TRANSFER_SUCCESSFUL "C'est bon, tu l'as recuperee, ta merde ?"
#define MSG_NO_DISK_SPACE "Bordel, mon disque est plein !"
#define MSG_OUT_OF_MEMORY "Bordel, ma memoire est pleine !"
#define MSG_ILLEGAL_TRUSTED_IP "Fous une IP valide et ca ira mieux"
#define MSG_NO_ASCII_RESUME "D'abord tu degages le fichier, apres on discute"
#define MSG_UNKNOWN_ALTLOG "Format d'historique de merde"
#define MSG_ACCOUNT_DISABLED "Le compte [%s] s'est fait buter"
#define MSG_SQL_WRONG_PARMS "Parametre SQL a la con"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Fichier de configuration SQL foireux"
#define MSG_SQL_MISSING_SERVER "Pas de serveur dans la configuration SQL"
#define MSG_SQL_DOWN "Le serveur SQL est tout destroy"
#define MSG_ILLEGAL_QUOTA "Quota tout pourri"
#define MSG_QUOTA_FILES "%llu fichiers utilises (%d%%) - autorises : %llu fichiers"
#define MSG_QUOTA_SIZE "%llu Ko utilises (%d%%) - autorises : %llu Ko"
#define MSG_QUOTA_EXCEEDED "T'as explose ton quota : [%s] va etre pulverise"
#define MSG_AUTH_UNKNOWN "C'est quoi ta methode d'authentification a 2 balles ?"
#define MSG_PDB_BROKEN "Impossible de lire le fichier puredb indexe (ou il est dans un vieux format pourri) - Tente pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s c'est un truc de flemmard a la place de %s."
#define MSG_ALIASES_UNKNOWN "Je connais pas %s."
#define MSG_ALIASES_BROKEN_FILE "Ahahah gros naze, ton fichier d'alias est tout pourrave"
#define MSG_ALIASES_LIST "Si t'as la flemme, tu peux utiliser ces raccourcis :"
#define MSG_PERUSER_MAX "T'es deja la %lu fois, j'en ai marre de voir ta gueule"
#define MSG_IPV6_OK "Si t'es pas un batard, tu peux te connecter en IPv6."
#define MSG_TLS_INFO "TLS: Direct, le scarla il deale du %s (%s) en %d bits !"
#define MSG_TLS_WEAK "TLS: C'est quoi ce chiffrement de tafiole ?"
#define MSG_TLS_NEEDED "Ecoute-moi connard : t'as 10 secondes pour configurer\n" \
    "ton client de merde en TLS. En attendant, degage."
#define MSG_ILLEGAL_CHARSET "Ton jeu de caractere il puxore grave."
#define MSG_TLS_NO_CTX "TLS: contexte introuvable. Cassos."
#define MSG_PROT_OK "Niveau de super mega protection : \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Le reglage envoye avec PROT est une grosse daube que je refuse pour transmettre des donnees."
#define MSG_PROT_UNKNOWN_LEVEL "C'est quoi ce niveau de protection %s ? Pas compris. Je vais donc choisir \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT ca marche qu'apres un PBSZ reussi"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP n'a pas retourne d'attribut userPassword, ptet que les droits d'acces LDAP chient."
#define MSG_LDAP_INVALID_AUTH_METHOD "LDAPAuthMethod dans le fichier de conf, ca doit etre 'bind' ou 'password'."
#define MSG_INVALID_ARGUMENT "\"%s\" c'est n'importe nawak"
#define MSG_READY_TO_PROCEED "OP"
#define MSG_ASCII_MODE_UNSUPPORTED "Tu veux faire un transfert en ASCII ? T'es un malade toi"
#define MSG_ASCII_MODE_WARNING "Attention : ton client est configure en ASCII. T'es serieux, la ? Tu vas te retrouver avec un fichier tout pete"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
