#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Timeout"
#define MSG_CAPABILITIES "Kan ikke ændre muligheder"
#define MSG_CLIENT_CLOSED_CNX "Klient afbrød forbindelsen"
#define MSG_CLIENT_READ_ERR "Læsefejl fra klienten"
#define MSG_CANT_OPEN_CNX "Kan ikke åbne forbindelse"
#define MSG_CANT_CREATE_DATA_SOCKET "Kan ikke oprette data sokkel"
#define MSG_DEBUG_CLIENT_IS "Klientens adresse er"
#define MSG_SYNTAX_ERROR_IP "Syntaks fejl i IP adresse"
#define MSG_PORT_SUCCESSFUL "PORT kommando lykkedes"
#define MSG_ONLY_IPV4V6 "Kun IPv4 og IPv6 er understøttet (1,2)"
#define MSG_ONLY_IPV4 "Kun IPv4 er understøttet (1)"
#define MSG_TIMEOUT_PARSER "Timeout - prøv at skrive lidt hurtigere næste gang"
#define MSG_LINE_TOO_LONG "Linie for lang"
#define MSG_LOG_OVERFLOW "Klienten prøvede at overfylde kommandolinie bufferen"
#define MSG_GOODBYE "Farvel, du har uploaded %llu og downloaded %llu kbytes."
#define MSG_DEBUG_COMMAND "Kommando"
#define MSG_IS_YOUR_CURRENT_LOCATION "er din nuværende possition"
#define MSG_NOT_LOGGED_IN "Du er ikke logget på"
#define MSG_AUTH_UNIMPLEMENTED "Sikkerhedsudvidelser er ikke implementeret"
#define MSG_NO_FILE_NAME "Intet filnavn"
#define MSG_NO_DIRECTORY_NAME "Intet mappenavn"
#define MSG_NO_RESTART_POINT "Intet genstartspunkt"
#define MSG_ABOR_SUCCESS "Siden du ser denne ABOR, er det nok lykkedes"
#define MSG_MISSING_ARG "Manglende besked"
#define MSG_GARBAGE_FOUND "Skidt fundet efter værdi"
#define MSG_VALUE_TOO_LARGE "Værdi for stor"
#define MSG_IDLE_TIME "Ledig tid sat til %lu sekunder"
#define MSG_SITE_HELP "Disse SITE kommandoer kendes"
#define MSG_BAD_CHMOD "Forkerte tilladelser"
#define MSG_UNKNOWN_EXTENSION "er en ukendt udvidelse"
#define MSG_XDBG_OK "XDBG kommando lykkedes, debug niveao er nu %d"
#define MSG_UNKNOWN_COMMAND "Ukendt kommando"
#define MSG_TIMEOUT_NOOP "Timeout (intet udført i %lu sekunder)"
#define MSG_TIMEOUT_DATA "Timeout (ingen ny data i %lu sekunder)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Du er allerede logget på"
#define MSG_ANY_PASSWORD "Et hvilketsomhlest kodeord virker"
#define MSG_ANONYMOUS_LOGGED "Anonym bruger er logget på"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonym bruger er logget på virtuel FTP"
#define MSG_USER_OK "Bruger %s OK. Der skal bruges kodeord"
#define MSG_CANT_DO_TWICE "Det kan vi ikke i denne forbindelse"
#define MSG_UNABLE_SECURE_ANON "Kunne ikke oprette sikker anonym FTP forbindelse"
#define MSG_BANDWIDTH_RESTRICTED "Dit båndbredde forbrug er begrænset"
#define MSG_NO_PASSWORD_NEEDED "Jeg beøves intet kodeord, kære anonyme ko"
#define MSG_NOTRUST "Desværre, jeg stoler ikke på dig"
#define MSG_WHOAREYOU "Fortæl mig venligst hvem du er"
#define MSG_AUTH_FAILED "Godkendelse mislykkedes"
#define MSG_AUTH_TOOMANY "For mange mislykkedes godkendelses forsøg"
#define MSG_NO_HOMEDIR "Hjemmemappe ikke tilgængelig - afbrydder"
#define MSG_NO_HOMEDIR2 "%s kan ikke findes "
#define MSG_START_SLASH "Starter i /"
#define MSG_USER_GROUP_ACCESS "Bruger %s har gruppeadgang til"
#define MSG_FXP_SUPPORT "Denne server understøtter FXP overførsler"
#define MSG_RATIO "Du må respektere %u:%u (op/ned) ratioen"
#define MSG_CHROOT_FAILED "Kunne ikke sætte en sikker chroot() sælle"
#define MSG_CURRENT_DIR_IS "OK. Nuværende mappe er %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Nuværende begrænsede mappe er %s"
#define MSG_IS_NOW_LOGGED_IN "%s er logget på nu"
#define MSG_CANT_CHANGE_DIR "Kan ikke ændre mappen til %s"
#define MSG_PATH_TOO_LONG "Sti for lang"
#define MSG_CANT_PASV "Jeg kan ikke oprette en passiv forbindelse med den forældede kommando"
#define MSG_CANT_PASSIVE "Kunne ikke oprette en passiv forbindelse"
#define MSG_PORTS_BUSY "Alle reserverede TCP porte er optaget"
#define MSG_GETSOCKNAME_DATA "Kunne ikke identificere den lokale data sokkel"
#define MSG_GETPEERNAME "Kunne ikke identificere den lokale sokkel"
#define MSG_INVALID_IP "Desværre, ugyldig adresse"
#define MSG_NO_EPSV "Brug venligst en klient der understøtter IPv6 med EPSV"
#define MSG_BAD_PORT "Jeg vil desværre ikke forbinde til porte < 1024"
#define MSG_NO_FXP "Jeg vil ikke åbne en forbindelse til %s (kun til %s)"
#define MSG_FXP "FXP overførsel : fra %s til %s"
#define MSG_NO_DATA_CONN "Ingen date forbindelse"
#define MSG_ACCEPT_FAILED "Forbindelsen kunne ikke blive godkendt"
#define MSG_ACCEPT_SUCCESS "Dataforbindelse godkendt"
#define MSG_CNX_PORT_FAILED "Kunne ikke åbne for dataforbindelsen til port %d"
#define MSG_CNX_PORT "Forbinder til port %d"
#define MSG_ANON_CANT_MKD "Anonyme brugere må ikke oprette mapper"
#define MSG_ANON_CANT_RMD "Anonyme brugere må ikke slette mapper"
#define MSG_ANON_CANT_RENAME "Anonyme brugere må ikke flytte/omdøbe filer"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonyme brugere kan ikke ændre tilladelser"
#define MSG_GLOB_NO_MEMORY "Løb tør for hukommelse under gennemgang af %s"
#define MSG_PROBABLY_DENIED "(Det her betydder sikkert 'Ingen adgang')"
#define MSG_GLOB_READ_ERROR "Læsefejl under gennemgang af %s"
#define MSG_GLOB_NO_MATCH "Ingen %s i %s"
#define MSG_CHMOD_FAILED "Kunne ikke ændre tilladelser på  %s"
#define MSG_CHMOD_SUCCESS "Tilladelser på %s ændret"
#define MSG_CHMOD_TOTAL_FAILURE "Desværre, jeg kunne ikke ændre nogen tilladelser"
#define MSG_ANON_CANT_DELETE "Anonyme brugere kan ikke slette filer"
#define MSG_ANON_CANT_OVERWRITE "Anonyme brugere må ikke overskive filer"
#define MSG_DELE_FAILED "Kunne ikke slette %s"
#define MSG_DELE_SUCCESS "Slettede %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "Ingen fil slettet"
#define MSG_LOAD_TOO_HIGH \
    "Belastningen var %3.2f da du kom på. Vi tillader ikke anonyme brugere\n" \
    "at downloade når belastngingen er så høj. Uploads er altid tilladt"

#define MSG_OPEN_FAILURE "Kan ikke åbne %s"
#define MSG_OPEN_FAILURE2 "Kan ikke åbne den fil"
#define MSG_STAT_FAILURE "Kan ikke finde filstørrelse"
#define MSG_STAT_FAILURE2 "Kan ikke checke om filen findes"
#define MSG_REST_TOO_LARGE_FOR_FILE "Genstart offset %lld er for stor for filstørrelse %lld."
#define MSG_REST_RESET "genstart offset sat til 0"
#define MSG_NOT_REGULAR_FILE "Jeg kan kun hente almindelig filer"
#define MSG_NOT_MODERATED \
    "Denne fil er uploaded af en anonym bruger. Den er endnu ikke\n" \
    "blevet godkendt af administratorerne til download."
#define MSG_RATIO_DENIAL \
    "Upload/download forholdet er %u:%u.\n" \
    "Du har uploaded %llu Kb og downloaded %llu Kb.\n" \
    "Upload venligst nogle godter og kom tilbage og snylt senere."
#define MSG_NO_MORE_TO_DOWNLOAD "Der er intet tilbage at downloade"
#define MSG_WINNER "Computeren er din ven. Stol på computeren"
#define MSG_KBYTES_LEFT "%.1f kbytes at hente"
#define MSG_ABORTED "Overførelse afbrudt"
#define MSG_DATA_WRITE_FAILED "Fejl under skrivning til dataforbindelsen"
#define MSG_DATA_READ_FAILED "Fejl under læsning fra dataforbindelsen"
#define MSG_MMAP_FAILED "Kunne ikke lægge filen i RAM"
#define MSG_WRITE_FAILED "Fejl under skrivning til fil"
#define MSG_TRANSFER_RATE_M "%.3f sekunder (målt her), %.2f Mbytes pr sekund"
#define MSG_TRANSFER_RATE_K "%.3f sekunder (målt her), %.2f Kbytes pr sekund"
#define MSG_TRANSFER_RATE_B "%.3f sekunder (målt her), %.2f bytes pr sekund"
#define MSG_SPACE_FREE_M "%.1f Mbytes fri disk plads"
#define MSG_SPACE_FREE_K "%f Kbytes fri disk plads"
#define MSG_DOWNLOADED "downloaded"
#define MSG_REST_NOT_NUMERIC "REST skal bruge en numereisk parameter"
#define MSG_REST_ASCII_STRICT "Svar markør skal være 0 i ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "Genstarter ved %lld. Men vi er i ASCII mode"
#define MSG_REST_SUCCESS "Genstarter ved %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Forbudt mappenavn"
#define MSG_SANITY_FILE_FAILURE "Forbudt filnavn: %s"
#define MSG_MKD_FAILURE "Kan ikke oprette mappe"
#define MSG_MKD_SUCCESS "Mappen blev oprettet"
#define MSG_RMD_FAILURE "Kan ikke fjerne mappen"
#define MSG_RMD_SUCCESS "Mappen blev fjernet"
#define MSG_TIMESTAMP_FAILURE "Kan ikke hente tidsstempel"
#define MSG_MODE_ERROR "Kun ASCII og binær overførsel er understøttet"
#define MSG_CREATE_FAILURE "Kunne ikke oprette fil"
#define MSG_ABRT_ONLY "ABRT er den eneste lovlige kommando under upload"
#define MSG_UPLOAD_PARTIAL "Delvist uploaded"
#define MSG_REMOVED "fjernet"
#define MSG_UPLOADED "uploaded"
#define MSG_GMTIME_FAILURE "Kunne ikke hente den lokale tid"
#define MSG_TYPE_8BIT_FAILURE "Kun 8 bit er understøttet, vi er ikke 10 år tilbage"
#define MSG_TYPE_UNKNOWN "Ukendt TYPE"
#define MSG_TYPE_SUCCESS "TYPE er nu"
#define MSG_STRU_FAILURE "Kun F(il) er understøttet"
#define MSG_MODE_FAILURE "Brug venligst S(tream) mode"
#define MSG_RENAME_ABORT "Afbrydder forige omdøb opgave"
#define MSG_RENAME_RNFR_SUCCESS "RNFR godkendt - fil findes, klar til destination"
#define MSG_FILE_DOESNT_EXIST "Den fil findes ikke"
#define MSG_RENAME_ALREADY_THERE "OMDØB mislykkedes - destinations fil findes allerede"
#define MSG_RENAME_NORNFR "Skal bruge RNFR før RNTO"
#define MSG_RENAME_FAILURE "Omdøb/flyt fejl"
#define MSG_RENAME_SUCCESS "Fil blev omdøbt eller flyttet"
#define MSG_NO_SUPERSERVER "Kør venligst pure-ftpd fra en super-server (f. eks. tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Kunne ikke finde 'ftp' kontoen"
#define MSG_CONF_ERR "Konfigurations fejl"
#define MSG_NO_VIRTUAL_FILE "Virtuelle brugers filnavn mangler"
#define MSG_ILLEGAL_THROTTLING "Ulovlig værdi for throttle"
#define MSG_ILLEGAL_TRUSTED_GID "Ulovlig gid for chroot"
#define MSG_ILLEGAL_USER_LIMIT "Ulovlig grænse for bruger"
#define MSG_ILLEGAL_FACILITY "Ukendt facilitets navn"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Forkert LDAP konfigurations fil"
#define MSG_ILLEGAL_LOAD_LIMIT "Ulovlig læse grænse"
#define MSG_ILLEGAL_PORTS_RANGE "Forkert port område"
#define MSG_ILLEGAL_LS_LIMITS "Forkerte 'ls' grænser"
#define MSG_ILLEGAL_FORCE_PASSIVE "Ulovlig tvungen IP til passive forbindelser"
#define MSG_ILLEGAL_RATIO "Ulovlig upload/download forhold"
#define MSG_ILLEGAL_UID_LIMIT "Ulovlig uid grænse"
#define MSG_ILLEGAL_OPTION "Ukendt run-time valg"
#define MSG_LDAP_MISSING_BASE "Manglende LDAPBaseDN i LDAP konfigurations filen"
#define MSG_LDAP_WRONG_PARMS "Forkerte LDAP parametre"
#define MSG_NEW_CONNECTION "Ny forbindelse fra %s"
#define MSG_WELCOME_TO "Velkommen til"
#define MSG_MAX_USERS "%lu brugere (det maksimale) er allerede logget på, desværre"
#define MSG_NB_USERS "Du er bruger nr %u af %u tilladte"
#define MSG_WELCOME_TIME "Lokal tid er nu %02d:%02d. Server port: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Kun anonym FTP er tilladt her"
#define MSG_RATIOS_EVERYONE "FORHOLD ER SLÅET TIL FOR ALLE :"
#define MSG_RATIOS_ANONYMOUS "ANONUME BRUGERE FÅR ET UL/DL FORHOLD :"
#define MSG_RATIOS_RULE "for at downloade %u Mb, skal du uploade %u Mb godter."
#define MSG_INFO_IDLE_M "Du bliver koblet af efter %lu minutters inaktivitet."
#define MSG_INFO_IDLE_S "Du bliver koblet af efter %lu sekunders inaktivitet."
#define MSG_CANT_READ_FILE "Kunne ikke læse [%s]"
#define MSG_LS_TRUNCATED "Data afrundet til %u sammenfald"
#define MSG_LS_SUCCESS "%u sammenfald totalt"
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Godkendelse mislykkedes for [%s]"
#define MSG_ILLEGAL_UMASK "Forkert umask"
#define MSG_STANDALONE_FAILED "Kunne ikke starte tandalone server"
#define MSG_NO_ANONYMOUS_LOGIN "Dette er et privat system - Ingen anonyme logins"
#define MSG_ANONYMOUS_ANY_PASSWORD "Et hvilketsomhlest kodeord virker"
#define MSG_MAX_USERS_IP "For mange forbindelser(%lu) fra denne IP"
#define MSG_ACTIVE_DISABLED "Aktiv mode er slået fra"
#define MSG_TRANSFER_SUCCESSFUL "Filoverførsel lykkedes"
#define MSG_NO_DISK_SPACE "Disken er fuld - upload venligst senere"
#define MSG_OUT_OF_MEMORY "Er løbet tør for hukommelse"
#define MSG_ILLEGAL_TRUSTED_IP "Ulovlig pålidelig IP adresse"
#define MSG_NO_ASCII_RESUME "ASCII genoptagning er usikker, slet venligst filen først"
#define MSG_UNKNOWN_ALTLOG "Ukendt log format"
#define MSG_ACCOUNT_DISABLED "Du kan ikke logge på som [%s]: konto er deaktiveret"
#define MSG_SQL_WRONG_PARMS "Forkerte SQL indstillinger"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Forkert SQL konfigurations fil"
#define MSG_SQL_MISSING_SERVER "Server i SQL konfigurationsfil mangler"
#define MSG_SQL_DOWN "Det ladder til at SQL serveren er nede"
#define MSG_ILLEGAL_QUOTA "Forkert quota"
#define MSG_QUOTA_FILES "%llu filer bliver brugt (%d%%) - autoriseret: %llu filer"
#define MSG_QUOTA_SIZE "%llu Kbyte er brugt (%d%%) - autoriseret: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Quota grænse overskredet : [%s] bliver ikke gemt"
#define MSG_AUTH_UNKNOWN "Ukendt godkendelses metode"
#define MSG_PDB_BROKEN "Kunne ikke læse den indexerede puredb fil (eller gammelt format fundet) - Prøv pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s er et alias for %s."
#define MSG_ALIASES_UNKNOWN "Ukendt alias %s."
#define MSG_ALIASES_BROKEN_FILE "Ødelagt alias fil"
#define MSG_ALIASES_LIST "Dess aliaser er tilgængelige :"
#define MSG_PERUSER_MAX "Jeg kan ikke åbne mere en %lu forbindelser for den samme bruger"
#define MSG_IPV6_OK "IPv6 forbindelser er også velkomne på denne server"
#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
