#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Id?túllépés"
#define MSG_CAPABILITIES "Képesség váltás sikertelen"
#define MSG_CLIENT_CLOSED_CNX "A Kliens bontotta a kapcsolatot"
#define MSG_CLIENT_READ_ERR "Kliens oldali olvasási hiba"
#define MSG_CANT_OPEN_CNX "A kapcsolat nem jött létre"
#define MSG_CANT_CREATE_DATA_SOCKET "Az adatcsatorna nem jött létre"
#define MSG_DEBUG_CLIENT_IS "A Kliens címe"
#define MSG_SYNTAX_ERROR_IP "Szintax hiba az IP címben"
#define MSG_PORT_SUCCESSFUL "PORT parancs sikeres"
#define MSG_ONLY_IPV4V6 "Csak IPv4 és IPv6 támogatott (1,2)"
#define MSG_ONLY_IPV4 "Csak IPv4 támogatott (1)"
#define MSG_TIMEOUT_PARSER "Id?túllépés - próbálj meg kicsit gyorsabban gépelni legközelebb"
#define MSG_LINE_TOO_LONG "A sor túl hosszú"
#define MSG_LOG_OVERFLOW "A Kliens megpróbálta túlcsordítani a parancsvonali buffert"
#define MSG_GOODBYE "Viszlát. Te feltöltöttél %llu és letöltöttél %llu kbájtot."
#define MSG_DEBUG_COMMAND "Parancs"
#define MSG_IS_YOUR_CURRENT_LOCATION "a pillanatnyi helyzeted"
#define MSG_NOT_LOGGED_IN "Nemvagy belépve"
#define MSG_AUTH_UNIMPLEMENTED "Ez a biztonsági séma nincsen implementálva"
#define MSG_NO_FILE_NAME "Nincs ilyen fájlnév"
#define MSG_NO_DIRECTORY_NAME "Nincs ilyen könyvtárnév"
#define MSG_NO_RESTART_POINT "Nincs újraindítási pont"
#define MSG_ABOR_SUCCESS "Megszakítás (ABOR) sikeres volt"
#define MSG_MISSING_ARG "Hiányzó meghatározás"
#define MSG_GARBAGE_FOUND "Szemét található az érték után"
#define MSG_VALUE_TOO_LARGE "Az érték túl nagy"
#define MSG_IDLE_TIME "Üresjárati id? beállítva %lu másodpercre"
#define MSG_SITE_HELP "A következ? SITE parancsok ismerhet?ek fel"
#define MSG_BAD_CHMOD "Érvénytelen engedélyek"
#define MSG_UNKNOWN_EXTENSION "egy érvénytelen kiterjesztés"
#define MSG_XDBG_OK "XDBG parancs sikeres, debug szint %d"
#define MSG_UNKNOWN_COMMAND "Ismeretlen parancs"
#define MSG_TIMEOUT_NOOP "Id?túllépés (nincs m?velet %lu másodperce)"
#define MSG_TIMEOUT_DATA "Id?túllépés (nincs új adat %lu másodperce)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Már bejelentkeztél"
#define MSG_ANY_PASSWORD "Akármilyen jelszó megfelel"
#define MSG_ANONYMOUS_LOGGED "Anonymous felhasználó lépett be"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonymous felhasználó lépett be a virtuális FTP-n keresztül"
#define MSG_USER_OK "Felhasználó %s rendben. Kérem a jelszót"
#define MSG_CANT_DO_TWICE "Ez képtelenség a jelenlegi folyamatban"
#define MSG_UNABLE_SECURE_ANON "A biztonságos anonymous FTP kapcsolat felépítése sikertelen volt"
#define MSG_BANDWIDTH_RESTRICTED "A sávszélesség használatod korlátozva van"
#define MSG_NO_PASSWORD_NEEDED "Akármilyen jelszó megfelel"
#define MSG_NOTRUST "Sajnálom, de nemtudok megbízni benned"
#define MSG_WHOAREYOU "Kérlek mondd meg ki vagy te"
#define MSG_AUTH_FAILED "Azonosítás sikertelen, sajnálom"
#define MSG_AUTH_TOOMANY "Túl sok sikertelen azonosítás"
#define MSG_NO_HOMEDIR "A kezd?mappa nem elérhet?, megszakítás"
#define MSG_NO_HOMEDIR2 "%s nem létezik vagy elérhetetlen"
#define MSG_START_SLASH "Indítás itt /"
#define MSG_USER_GROUP_ACCESS "A %s felhasználó csoportja"
#define MSG_FXP_SUPPORT "Ez a szerver támogatja az FXP átvitelt"
#define MSG_RATIO "Tisztelned kell az %u:%u (UL/DL) arányokat"
#define MSG_CHROOT_FAILED "A biztonságos chroot() jail létrehozása sikertelen"
#define MSG_CURRENT_DIR_IS "Rendben. %s a jelenlegi könyvtár"
#define MSG_CURRENT_RESTRICTED_DIR_IS "Rendben. %s a jelenlegi korlátozott könyvtár"
#define MSG_IS_NOW_LOGGED_IN "%s belépett"
#define MSG_CANT_CHANGE_DIR "A %s könyvtárba váltás sikertelen"
#define MSG_PATH_TOO_LONG "Az elérési út túl hosszú"
#define MSG_CANT_PASV "Nem használhatsz PASV-ot IPv6 kapcsolatnál. Használj EPSV-t helyette."
#define MSG_CANT_PASSIVE "A passiv módú kapcsolat nem jött létre"
#define MSG_PORTS_BUSY "Az összes fenntartott TCP port foglalt"
#define MSG_GETSOCKNAME_DATA "A helyi adatcsatorna azonosítása sikertelen"
#define MSG_GETPEERNAME "A helyi csatorna azonosítása sikertelen"
#define MSG_INVALID_IP "Elnzést, a megadott cím érvénytelen"
#define MSG_NO_EPSV "Kérem használjon IPv6-szerkezetu klienst EPSV támogatással"
#define MSG_BAD_PORT "Hiba, nemtudok az < 1024 portokhoz kapcsolódni"
#define MSG_NO_FXP "Nemtudok kapcsolatot megnyitni megnyitni a %s -nak (csak %s -nak)"
#define MSG_FXP "FXP transfer: forrás: %s cél: %s"
#define MSG_NO_DATA_CONN "Nincs adatkapcsolat"
#define MSG_ACCEPT_FAILED "A kapcsolat nem elfogadható"
#define MSG_ACCEPT_SUCCESS "Adatkapcsolat elfogadva"
#define MSG_CNX_PORT_FAILED "Az adatkapcsolat létrehozása a %d portra sikertelen"
#define MSG_CNX_PORT "Kapcsolódás a  %d porthoz"
#define MSG_ANON_CANT_MKD "Hiba, anonymous felhasználók nem hozhatnak létre könyvtárakat"
#define MSG_ANON_CANT_RMD "Hiba, anonymous felhasználók nem törölhetnek könyvtárakat"
#define MSG_ANON_CANT_RENAME "Anonymous felhasználók nem mozgathatnak/nevezhetnek át könyvtárakat"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymous felhasználók nem állíthatnak engedélyeket"
#define MSG_GLOB_NO_MEMORY "Elfogyott a memória %s teljesítése közben"
#define MSG_PROBABLY_DENIED "(Ez valószínuleg ezt jelenti \"Engedély megtagadva\") "
#define MSG_GLOB_READ_ERROR "Olvasási hiba %s teljesítése közben"
#define MSG_GLOB_NO_MATCH "Nincs hasonlóság %s  ebben: %s "
#define MSG_CHMOD_FAILED "Engedélyváltás sikertelen %s"
#define MSG_CHMOD_SUCCESS "Engedélyváltás sikeres %s"
#define MSG_CHMOD_TOTAL_FAILURE "Hiba, de nemtudok engedélyt váltani"
#define MSG_ANON_CANT_DELETE "Anonymous felhasználók nem törölhetnek"
#define MSG_ANON_CANT_OVERWRITE "Anonymous felhasználók talán nem írhatnak felül meglévo fájlokat"
#define MSG_DELE_FAILED "Nem lehet törölni %s"
#define MSG_DELE_SUCCESS "%s%s%s%s törölve"
#define MSG_DELE_TOTAL_FAILURE "Egyetlen fájl sem lett törölve"
#define MSG_LOAD_TOO_HIGH \
    "A terhelés %3.2f mikor csatlakoztál. A letöltés le van tiltva\n" \
    "az anonymous felhasználóknak, mikor a teherlés ilyen nagy. A feltöltések \n" \
    "mindíg engedélyezve vannak."
#define MSG_OPEN_FAILURE "Sikertelen megnyitás %s"
#define MSG_OPEN_FAILURE2 "A fájl megnyitása sikertelen"
#define MSG_STAT_FAILURE "A fájl mérete nem található"
#define MSG_STAT_FAILURE2 "A fájl létezésének ellenorzése sikertelen"
#define MSG_REST_TOO_LARGE_FOR_FILE "Az újraindítási érték %lld túl nagy a fájl méretéhez %lld."
#define MSG_REST_RESET "Újraindítási érték 0 -ra változtatva"
#define MSG_NOT_REGULAR_FILE "Csak hagyományos fájlt tud letölteni"
#define MSG_NOT_MODERATED \
    "A fájlt anonymus felhasználó töltötte fel. " \
    "a fájl letöltését az adminisztrátorok még nem hagyták jóvá"
#define MSG_RATIO_DENIAL \
    "Hiba, a feltöltési/letöltési arány %u:%u .\n" \
    "Feltöltöttél jelenleg %llu Kb és letöltöttél %llu Kb.\n" \
    "Kérlek tölts fel valami hasznosat és utána leech-elj."
#define MSG_NO_MORE_TO_DOWNLOAD "Semmi letöltenivaló nem maradt"
#define MSG_WINNER "A számítógép a barátod. Bízz a számítógépben."
#define MSG_KBYTES_LEFT "%.1f kbájt a hátralévo letöltendo mennyiség"
#define MSG_ABORTED "Átvitel megszakítva"
#define MSG_DATA_WRITE_FAILED "Íráshiba az adatkapcsolatból"
#define MSG_DATA_READ_FAILED "Olvasási hiba az adatkapcsolatból"
#define MSG_MMAP_FAILED "A fájl memóriába való bejegyzése sikertelen"
#define MSG_WRITE_FAILED "Fájlba írás közben hiba történt"
#define MSG_TRANSFER_RATE_M "%.3f másodperc (itt mérve), %.2f Mbájt per másodperc"
#define MSG_TRANSFER_RATE_K "%.3f másodperc (itt mérve), %.2f Kbájt per másodperc"
#define MSG_TRANSFER_RATE_B "%.3f másodperc (itt mérve), %.2f bájt per másodperc"
#define MSG_SPACE_FREE_M "%.1f Mbájt a szabad lemezterület"
#define MSG_SPACE_FREE_K "%f Kbájt a szabad lemezterület"
#define MSG_DOWNLOADED "letöltve"
#define MSG_REST_NOT_NUMERIC "REST numerikus paraméter szükséges"
#define MSG_REST_ASCII_STRICT "Reply marker must be 0 in ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "Újraindítás ezen a ponton %lld. De ASCII módban vagyunk."
#define MSG_REST_SUCCESS "Újraindítás ezen a pontom %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Prohibited directory name"
#define MSG_SANITY_FILE_FAILURE "Tiltott fájl név: %s"
#define MSG_MKD_FAILURE "Könyvtár létrehozás sikertelen"
#define MSG_MKD_SUCCESS "A könyvtár sikeresen létrejött"
#define MSG_RMD_FAILURE "Könyvtár törlése sikertelen"
#define MSG_RMD_SUCCESS "A könyvtár sikeresen törölve"
#define MSG_TIMESTAMP_FAILURE "Az ido bélyeg nem meghatározható"
#define MSG_MODE_ERROR "Csak ASCII és bináris mód támogatott"
#define MSG_CREATE_FAILURE "Fájl létrehozása sikertelen"
#define MSG_ABRT_ONLY "ABRT az egyetlen jogos parancs feltöltés közben"
#define MSG_UPLOAD_PARTIAL "részlegesen feltöltve"
#define MSG_REMOVED "eltávolítva"
#define MSG_UPLOADED "feltöltve"
#define MSG_GMTIME_FAILURE "Helyi ido meghatározása sikertelen"
#define MSG_TYPE_8BIT_FAILURE "Csak 8-bites bájtok támogatottak, nem 10 évvel ezelott vagyunk"
#define MSG_TYPE_UNKNOWN "Ismeretlen típus (TYPE)"
#define MSG_TYPE_SUCCESS "TYPE most"
#define MSG_STRU_FAILURE "Csak F(ile) támogatott"
#define MSG_MODE_FAILURE "Kérem használjon S(tream) módot"
#define MSG_RENAME_ABORT "Elozo átnevezés megszakítva"
#define MSG_RENAME_RNFR_SUCCESS "RNFR elfogadva - fájl létezik, kész az új névre"
#define MSG_FILE_DOESNT_EXIST "Hiba, a megadott fájlnév nem létezik"
#define MSG_RENAME_ALREADY_THERE "Átnevezés (RENAME) sikertelen - a célfájl már létezik"
#define MSG_RENAME_NORNFR "RNFR szükséges RNTO elott"
#define MSG_RENAME_FAILURE "Átnevezés/mozgatás hiba"
#define MSG_RENAME_SUCCESS "A fájl sikeresen át lett nevezve vagy mozgatva"
#define MSG_NO_SUPERSERVER "Kérem futtassa a pure-ftpd -t egy szuper szerveren belül (mint a tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nem találom 'ftp' azonosítót"
#define MSG_CONF_ERR "Konfigurációs hiba"
#define MSG_NO_VIRTUAL_FILE "A virtuális felhasználó fájlnév hiányzik"
#define MSG_ILLEGAL_THROTTLING "Érvénytelen sávszélesség fojtó érték"
#define MSG_ILLEGAL_TRUSTED_GID "Érvénytelen megbízható gid chroot -nak"
#define MSG_ILLEGAL_USER_LIMIT "Érvénytelen felhasználó korlát"
#define MSG_ILLEGAL_FACILITY "Ismeretlen képesség név"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Érvénytelen LDAP konfigurációs fájl"
#define MSG_ILLEGAL_LOAD_LIMIT "Érvénytelen terhelési korlát"
#define MSG_ILLEGAL_PORTS_RANGE "Érvénytelen port tartomány"
#define MSG_ILLEGAL_LS_LIMITS "Érvénytelen 'ls' korlátok"
#define MSG_ILLEGAL_FORCE_PASSIVE "Érvénytelen eroltetett IP passzív módú kapcsolathoz"
#define MSG_ILLEGAL_RATIO "Érvénytelen feltöltési/letöltési ráta"
#define MSG_ILLEGAL_UID_LIMIT "Érvénytelen UID korlát"
#define MSG_ILLEGAL_OPTION "Ismeretlen futási opció"
#define MSG_LDAP_MISSING_BASE "Az LDAPBaseDN hiányzik az LDAP konfigurációs fájlból"
#define MSG_LDAP_WRONG_PARMS "Rossz LDAP paraméterek"
#define MSG_NEW_CONNECTION "Új kapcsolat a következo címrol: %s"
#define MSG_WELCOME_TO "Üdvözlöm"
#define MSG_MAX_USERS "%lu felhasználó (a maximum) már be van lépve, sajnálom"
#define MSG_NB_USERS "Te vagy a %u a %u felhasználó közül, aki beléphet."
#define MSG_WELCOME_TIME "A Helyi Ido %02d:%02d. szerver port: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Csak anonymous FTP megengedett"
#define MSG_RATIOS_EVERYONE "A RÁTÁK MINDENKIRE ÉRVÉNYESEK:"
#define MSG_RATIOS_ANONYMOUS "ANONYMOUS FELHASZÁLÓK AZ UL/DL A KÖVETKEZO RÁTÁNAK VANNAK ALÁRENDELVE:"
#define MSG_RATIOS_RULE "ahhoz, hogy letölts %u Mb-ot, %u Mb nyalánkság feltöltése kötelezo."
#define MSG_INFO_IDLE_M "%lu perc inaktivitás után a kapcsolat megszakad."
#define MSG_INFO_IDLE_S "%lu másodperc inaktivitás után a kapcsolat megszakad."
#define MSG_CANT_READ_FILE "Hiba, az olvasás lehetetlen [%s]"
#define MSG_LS_TRUNCATED "Kimenet %u részre csonkítva"
#define MSG_LS_SUCCESS "%u az összes megfelelo"
#define MSG_LOGOUT "Kijelentkezés."
#define MSG_AUTH_FAILED_LOG "Azonosítás sikertelen [%s] felhasználónak"
#define MSG_ILLEGAL_UMASK "Érvénytelen umask"
#define MSG_STANDALONE_FAILED "Egyedülálló szerver elindítása sikertelen"
#define MSG_NO_ANONYMOUS_LOGIN "Ez egy privát rendszer - nincs anonymous bejelentkezés"
#define MSG_ANONYMOUS_ANY_PASSWORD "Bármilyen jelszó megfelel"
#define MSG_MAX_USERS_IP "Túl sok kapcsolat errol az IP-rol: (%lu) "
#define MSG_ACTIVE_DISABLED "Aktív mód letiltva"
#define MSG_TRANSFER_SUCCESSFUL "A fájl sikeresen át lett töltve"
#define MSG_NO_DISK_SPACE "A Diszk tele van - kérem késobb töltsön fel"
#define MSG_OUT_OF_MEMORY "Elfogyott a memória"
#define MSG_ILLEGAL_TRUSTED_IP "Érvénytelen megbízható IP cím"
#define MSG_NO_ASCII_RESUME "ASCII folytatás nem biztonságos, kérem eloször törölje a fájlt"
#define MSG_UNKNOWN_ALTLOG "Ismeretlen naplózási formátum"
#define MSG_ACCOUNT_DISABLED " Nemtud belépni ezzel a felhasználónévvel: [%s]: belépési név letiltva"
#define MSG_SQL_WRONG_PARMS "Rossz SQL paraméterek"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Érvénytelen SQL konfigurációs fájl"
#define MSG_SQL_MISSING_SERVER "Hiányzik a szerver az  SQL konfigurációs fájlból"
#define MSG_SQL_DOWN "Az SQL szerver úgylátszik nem muködik"
#define MSG_ILLEGAL_QUOTA "Érvénytelen kvóta"
#define MSG_QUOTA_FILES "%llu fájl használt (%d%%) - engedélyezve: %llu fájl"
#define MSG_QUOTA_SIZE "%llu Kbájt használt (%d%%) - engedélyezve: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Kvóta elérve: [%s] mentés sikertelen"
#define MSG_AUTH_UNKNOWN "Ismeretlen hitelesítési módszer"
#define MSG_PDB_BROKEN "Az indexelt puredb fájl olvasása sikertelen (vagy régi formátum) - próbálja: pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s egy alias %s -nak."
#define MSG_ALIASES_UNKNOWN "Ismeterlen alias %s."
#define MSG_ALIASES_BROKEN_FILE "Sérült alias fájlok"
#define MSG_ALIASES_LIST "A következo aliasok elérhetoek :"
#define MSG_PERUSER_MAX "Nem fogadhatok el több kapcsolatot, mint %lu ugyanattól a felhasználótól"
#define MSG_IPV6_OK "IPv6 kapcsolatok szintén használhatóak a szerveren."
#define MSG_TLS_INFO "TLS: Engedélyezve %s, %s, %d titkos bittel titkosítva"
#define MSG_TLS_WEAK "TLS: Titkosítás túl gyenge"
#define MSG_TLS_NEEDED "Hiba, cleartext belépési forma nem engedélyezett.\n" \
    "Kérem kapcsolódjon újra TLS biztonsági módot használva."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
