#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Temporizare expirata"
#define MSG_CAPABILITIES "Nu pot comuta capabilitatile"
#define MSG_CLIENT_CLOSED_CNX "Clientul a inchis conexiunea"
#define MSG_CLIENT_READ_ERR "Eroare de citire de la client"
#define MSG_CANT_OPEN_CNX "Nu pot deschide conexiunea"
#define MSG_CANT_CREATE_DATA_SOCKET "Nu pot crea soclu de date"
#define MSG_DEBUG_CLIENT_IS "Adresa clientului este"
#define MSG_SYNTAX_ERROR_IP "Eroare de sintaxa in adresa IP"
#define MSG_PORT_SUCCESSFUL "Comanda PORT terminata cu succes"
#define MSG_ONLY_IPV4V6 "Este suportat numai IPv4 si IPv6 (1,2)"
#define MSG_ONLY_IPV4 "Este suportat numai IPv4 (1)"
#define MSG_TIMEOUT_PARSER "Temporizare expirata - incercati sa scrieti putin mai repede data viitoare"
#define MSG_LINE_TOO_LONG "Linie prea lunga"
#define MSG_LOG_OVERFLOW "Clientul a incercat sa depaseasca buffer-ul liniei de comanda"
#define MSG_GOODBYE "La revedere. Ati upload-at %llu si download-at %llu kocteti."
#define MSG_DEBUG_COMMAND "Comanda"
#define MSG_IS_YOUR_CURRENT_LOCATION "este locatia dumneavoastra"
#define MSG_NOT_LOGGED_IN "Nu sinteti inca logat"
#define MSG_AUTH_UNIMPLEMENTED "Extensiile de securitate nu sint implementate"
#define MSG_NO_FILE_NAME "Nu ati dat un nume de fisier"
#define MSG_NO_DIRECTORY_NAME "Nu ati dat un nume de director"
#define MSG_NO_RESTART_POINT "Nu exista un punct de repornire"
#define MSG_ABOR_SUCCESS "Deoarece ati vazut aceasta comanda ABOR inseamna ca ati reusit"
#define MSG_MISSING_ARG "Argumentul lipseste"
#define MSG_GARBAGE_FOUND "Am gasit date defecte dupa valoare"
#define MSG_VALUE_TOO_LARGE "Valoare prea mare"
#define MSG_IDLE_TIME "Timpul de pauza a fost setat la %lu secunde"
#define MSG_SITE_HELP "Sint recunoscute urmatoarele comenzi SITE"
#define MSG_BAD_CHMOD "Permisiuni eronate"
#define MSG_UNKNOWN_EXTENSION "este o extensie necunoscuta"
#define MSG_XDBG_OK "Comanda XDBG a reusit. Nivelul de depanare este acum %d"
#define MSG_UNKNOWN_COMMAND "Comanda necunoscuta"
#define MSG_TIMEOUT_NOOP "Temporizare expirata (nici o operatie de %lu secunde)"
#define MSG_TIMEOUT_DATA "Temporizare expirata (nici un fel de date noi de %lu secunde)"
#define MSG_SLEEPING "zzZ zzZZ ..."
#define MSG_ALREADY_LOGGED "Sinteti deja logat"
#define MSG_ANY_PASSWORD "Orice parola va merge"
#define MSG_ANONYMOUS_LOGGED "Utilizatorul anonim s-a logat"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Utilizatorul anonim s-a logat in server-ul FTP virtual"
#define MSG_USER_OK "Utilizatorul %s este acceptat. Este necesara parola"
#define MSG_CANT_DO_TWICE "Nu se poate face acest lucru in sesiunea curenta"
#define MSG_UNABLE_SECURE_ANON "Nu pot seta un server FTP anonim securizat"
#define MSG_BANDWIDTH_RESTRICTED "Banda de trafic alocata este restrictionata"
#define MSG_NO_PASSWORD_NEEDED "Draga utilizator anonim, nu ai nevoie de nici o parola"
#define MSG_NOTRUST "Imi pare rau, dar nu am incredere in tine"
#define MSG_WHOAREYOU "Te rog frumos sa-mi spui cine esti"
#define MSG_AUTH_FAILED "Autentificarea a esuat"
#define MSG_AUTH_TOOMANY "Prea multe autentificari esuate"
#define MSG_NO_HOMEDIR "Directorul personal nu este disponibil. Renunt."
#define MSG_NO_HOMEDIR2 "%s nu exista sau nu poate fi accesat"
#define MSG_START_SLASH "Pornesc in /"
#define MSG_USER_GROUP_ACCESS "Utilizatorul %s are acces de grup la"
#define MSG_FXP_SUPPORT "Acest server suporta transferuri FXP"
#define MSG_RATIO "Ar trebui sa va asteptati la o rata %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "Nu am putut seta un chroot() securizat"
#define MSG_CURRENT_DIR_IS "OK. Directorul curent este %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Directorul curent restrictionat este %s"
#define MSG_IS_NOW_LOGGED_IN "%s este acum logat"
#define MSG_CANT_CHANGE_DIR "Nu pot intra in directorul %s"
#define MSG_PATH_TOO_LONG "Cale prea lunga"
#define MSG_CANT_PASV "Nu pot deschide o conexiune pasiva cu aceasta comanda invechita"
#define MSG_CANT_PASSIVE "Nu pot deschide o conexiune pasiva"
#define MSG_PORTS_BUSY "Toate porturile TCP rezervate sint ocupate"
#define MSG_GETSOCKNAME_DATA "Nu pot identifica soclul de date local"
#define MSG_GETPEERNAME "Nu pot identifica soclul local"
#define MSG_INVALID_IP "Adresa eronata"
#define MSG_NO_EPSV "Utilizati un client compatibil IPv6 cu suport EPSV"
#define MSG_BAD_PORT "Nu ma conectez la porturi < 1024"
#define MSG_NO_FXP "Nu voi deschide o conexiune catre %s (numai catre %s)"
#define MSG_FXP "Transfer FXP : de la %s la %s"
#define MSG_NO_DATA_CONN "Nu exista conexiune de date"
#define MSG_ACCEPT_FAILED "Nu pot accepta conexiunea"
#define MSG_ACCEPT_SUCCESS "Conexiune de date acceptata"
#define MSG_CNX_PORT_FAILED "Nu pot deschide conexiune de date pe portul %d"
#define MSG_CNX_PORT "Conectez la portul %d"
#define MSG_ANON_CANT_MKD "Utilizatorii anonimi nu au voie sa creeze directoare"
#define MSG_ANON_CANT_RMD "Utilizatorii anonimi nu au voie sa stearga directoare"
#define MSG_ANON_CANT_RENAME "Utilizatorii anonimi nu au voie sa mute/redenumeasca fisiere"
#define MSG_ANON_CANT_CHANGE_PERMS "Utilizatorii anonimi nu au voie sa modifice permisiunile"
#define MSG_GLOB_NO_MEMORY "Nu mai exista memorie (datorita operatiei de globalizare a %s)"
#define MSG_PROBABLY_DENIED "(Acest lucru inseamna probabil \"permisiune respinsa\")"
#define MSG_GLOB_READ_ERROR "Eroare de citire la operatia de globalizare a %s"
#define MSG_GLOB_NO_MATCH "Nici o potrivire pentru %s in %s"
#define MSG_CHMOD_FAILED "Nu pot modifica permisiunile pentru %s"
#define MSG_CHMOD_SUCCESS "Permisiuni modificate pentru %s"
#define MSG_CHMOD_TOTAL_FAILURE "Nu pot modifica nici un fel de permisiuni"
#define MSG_ANON_CANT_DELETE "Utilizatorii anonimi nu pot sterge fisiere"
#define MSG_ANON_CANT_OVERWRITE "Utilizatorii anonimi nu pot suprascrie fisiere existente"
#define MSG_DELE_FAILED "Nu pot sterge %s"
#define MSG_DELE_SUCCESS "Am sters %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "Nici un fisier selectat"
#define MSG_LOAD_TOO_HIGH \
    "Incarcarea server-ului era %3.2f cind v-ati conectat. Nu sint permise download-uri\n" \
    "pentru utilizatorii anonimi cind incarcarea este atit de mare. Upload-uri sint\n" \
    "intotdeauna permise."
#define MSG_OPEN_FAILURE "Nu pot deschide %s"
#define MSG_OPEN_FAILURE2 "Nu pot deschide acel fisier"
#define MSG_STAT_FAILURE "Nu pot determina marimea fisierului"
#define MSG_STAT_FAILURE2 "Nu pot verifica existenta fisierului"
#define MSG_REST_TOO_LARGE_FOR_FILE "Adresa de reluare %lld este prea mare fata de marimea fisierului %lld."
#define MSG_REST_RESET "Adresa de reluare a fost resetata la 0"
#define MSG_NOT_REGULAR_FILE "Pot transfera numai fisiere obisnuite"
#define MSG_NOT_MODERATED \
    "Acest fisier a fost upload-at de catre un utilizator anonim. El nu a fost\n" \
    "inca aprobat pentru download de catre administratorul site-ului."
#define MSG_RATIO_DENIAL \
    "Rata upload/download este %u:%u .\n" \
    "Deocamdata ati upload-at %llu Kb si download-at %llu Kb.\n" \
    "Mai upload-ati fisiere si apoi incercati  mai tirziu sa download-ati ceva."
#define MSG_NO_MORE_TO_DOWNLOAD "Nu mai este nimic de download-at"
#define MSG_WINNER "Calculatorul este prietenul tau. Ai incredere in el"
#define MSG_KBYTES_LEFT "%.1f kocteti de download-at"
#define MSG_ABORTED "Transfer anulat"
#define MSG_DATA_WRITE_FAILED "Eroare la scriere pe conexiunea de date"
#define MSG_DATA_READ_FAILED "Eroare la citirea din conexiunea de date"
#define MSG_MMAP_FAILED "Nu pot mapa fisierul in memorie"
#define MSG_WRITE_FAILED "Eroare la scrierea fisierului"
#define MSG_TRANSFER_RATE_M "%.3f secunde (masurate aici), %.2f Mocteti pe secunda"
#define MSG_TRANSFER_RATE_K "%.3f secunde (masurate aici), %.2f Kocteti pe secunda"
#define MSG_TRANSFER_RATE_B "%.3f secunde (masurate aici), %.2f octeti pe secunda"
#define MSG_SPACE_FREE_M "%.1f Mocteti spatiu liber pe disc"
#define MSG_SPACE_FREE_K "%f Kocteti spatiu liber pe disc"
#define MSG_DOWNLOADED "download-at"
#define MSG_REST_NOT_NUMERIC "REST are nevoie de un parametru numeric"
#define MSG_REST_ASCII_STRICT "Markerul de rapuns trebuie sa fie 0 in modul ASCII"
#define MSG_REST_ASCII_WORKAROUND "Restartez de la %lld. Dar sint in modul ASCII"
#define MSG_REST_SUCCESS "Restartez de la %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Nume de director interzis"
#define MSG_SANITY_FILE_FAILURE "Nume de fisier interzis: %s"
#define MSG_MKD_FAILURE "Nu pot crea directorul"
#define MSG_MKD_SUCCESS "Am creat cu succes directorul"
#define MSG_RMD_FAILURE "Nu pot sterge directorul"
#define MSG_RMD_SUCCESS "Am sters cu succes directorul"
#define MSG_TIMESTAMP_FAILURE "Nu pot obtine un marker de timp"
#define MSG_MODE_ERROR "Sint suportate numai modurile ASCII si binar"
#define MSG_CREATE_FAILURE "Nu pot crea fisierul"
#define MSG_ABRT_ONLY "Comanda ABRT este normala numai la upload"
#define MSG_UPLOAD_PARTIAL "upload-at partial"
#define MSG_REMOVED "sters"
#define MSG_UPLOADED "upload-at"
#define MSG_GMTIME_FAILURE "Nu pot obtine timpul local"
#define MSG_TYPE_8BIT_FAILURE "Sint suportati numai octeti de 8 biti; nu sintem acum 10 ani"
#define MSG_TYPE_UNKNOWN "TYPE necunoscut"
#define MSG_TYPE_SUCCESS "TYPE este acum"
#define MSG_STRU_FAILURE "Numai File (fisier) este suportat"
#define MSG_MODE_FAILURE "Utilizati modul Stream (flux)"
#define MSG_RENAME_ABORT "Anulez comanda precedenta de redenumire"
#define MSG_RENAME_RNFR_SUCCESS "RNFR acceptat - fisierul exista si este gata pentru destinatie"
#define MSG_FILE_DOESNT_EXIST "Acest fisier nu exista"
#define MSG_RENAME_ALREADY_THERE "Operatie RENAME esuata - fisierul destinatie exista deja"
#define MSG_RENAME_NORNFR "Este nevoie de RNFR inainte de RNTO"
#define MSG_RENAME_FAILURE "Eroare de redenumire/mutare"
#define MSG_RENAME_SUCCESS "Fisier redenumit sau mutat cu succes"
#define MSG_NO_SUPERSERVER "Va rog sa rulati pure-ftpd cu un program super-server (precum tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nu am gasit contul 'ftp'"
#define MSG_CONF_ERR "Eroare de configurare"
#define MSG_NO_VIRTUAL_FILE "Lipseste numele fisierului de utilizatori virtuali"
#define MSG_ILLEGAL_THROTTLING "Valoare eronatã pentru limita ratei de transfer"
#define MSG_ILLEGAL_TRUSTED_GID "GID-ul de incredere pentru chroot() nu este corespunzator"
#define MSG_ILLEGAL_USER_LIMIT "Limita utilizator eronata"
#define MSG_ILLEGAL_FACILITY "Nume necunoscut de facilitate"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Fisier de configuare LDAP eronat"
#define MSG_ILLEGAL_LOAD_LIMIT "Limita de incarcare eronata"
#define MSG_ILLEGAL_PORTS_RANGE "Domeniu de porturi eronat"
#define MSG_ILLEGAL_LS_LIMITS "Limita 'ls' eronata"
#define MSG_ILLEGAL_FORCE_PASSIVE "IP eronat pentru conexiuni pasive fortate"
#define MSG_ILLEGAL_RATIO "Cota upload/download eronata"
#define MSG_ILLEGAL_UID_LIMIT "Limita de UID necorespunzatoare"
#define MSG_ILLEGAL_OPTION "Optiune de executie necunoscuta"
#define MSG_LDAP_MISSING_BASE "Lipseste LDAPBaseDN in fisierul de configurare LDAP"
#define MSG_LDAP_WRONG_PARMS "Parametrii LDAP eronati"
#define MSG_NEW_CONNECTION "Conexiune noua de la %s"
#define MSG_WELCOME_TO "Bine ati venit pe"
#define MSG_MAX_USERS "%lu utilizatori (maximul) sint deja logati"
#define MSG_NB_USERS "Sineti utilizatorul cu numarul %u din %u permisi"
#define MSG_WELCOME_TIME "Timpul local este acum %02d:%02d. Port server: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Aici este permis numai acces FTP anonim"
#define MSG_RATIOS_EVERYONE "COTELE SINT ACTIVATE PENTRU ORICINE :"
#define MSG_RATIOS_ANONYMOUS "UTILIZATORII ANONIMI SINT SUPUSI UNEI COTE UL/DL :"
#define MSG_RATIOS_RULE "pentru a download-a %u Mb, este obligatoriu sa upload-ati %u Mb de alte fisiere."
#define MSG_INFO_IDLE_M "Veti fi deconectat dupa %lu minute de inactivitate."
#define MSG_INFO_IDLE_S "Veti fi deconectat dupa %lu secunde de inactivitate."
#define MSG_CANT_READ_FILE "Nu am putut citi [%s]"
#define MSG_LS_TRUNCATED "Rezultat trunchiat la %u potriviri"
#define MSG_LS_SUCCESS "%u potriviri in total"
#define MSG_LOGOUT "Iesire."
#define MSG_AUTH_FAILED_LOG "Autentificare esuata pentru utilizatorul [%s]"
#define MSG_ILLEGAL_UMASK "Valoare umask eronata"
#define MSG_STANDALONE_FAILED "Nu am putut starta un server de sine statator"
#define MSG_NO_ANONYMOUS_LOGIN "Acesta este un sistem privat - Nu este permisa logarea anonima"
#define MSG_ANONYMOUS_ANY_PASSWORD "Va fi valabila orice parola"
#define MSG_MAX_USERS_IP "Prea multe conexiuni (%lu) de la acest IP"
#define MSG_ACTIVE_DISABLED "Modul activ este dezactivat"
#define MSG_TRANSFER_SUCCESSFUL "Fisier transferat cu succes"
#define MSG_NO_DISK_SPACE "Disc plin - incercati sa upload-ati mai tirziu"
#define MSG_OUT_OF_MEMORY "Nu mai exista memorie"
#define MSG_ILLEGAL_TRUSTED_IP "Adresa IP neacceptata"
#define MSG_SQL_WRONG_PARMS "Parametrii SQL eronati"
#define MSG_NO_ASCII_RESUME "Reluarea fisierelor ASCII este nesigura. Stergeti mai intii fisierul"
#define MSG_UNKNOWN_ALTLOG "Format de logare necunoscut"
#define MSG_ACCOUNT_DISABLED "Nu pot loga ca [%s] : cont dezactivat"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Fisier de configurarea SQL eronat"
#define MSG_SQL_MISSING_SERVER "In fisierul de configurare SQL lipseste server-ul"
#define MSG_SQL_DOWN "Se pare ca server-ul SQL este oprit"
#define MSG_ILLEGAL_QUOTA "Cota eronata"
#define MSG_QUOTA_FILES "%llu fisiere utilizate (%d%%) - autorizat: %llu fisiere"
#define MSG_QUOTA_SIZE "%llu Kocteti utilizati (%d%%) - autorizat: %llu Kocteti"
#define MSG_QUOTA_EXCEEDED "Cota depasita: [%s] nu va fi salvat"
#define MSG_AUTH_UNKNOWN "Metoda de autentificare necunoscuta"
#define MSG_PDB_BROKEN "Nu pot citi fisierul puredb indexat (probabil e in format vechi) - Incercati pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s este un alias pentru %s."
#define MSG_ALIASES_UNKNOWN "Aliasul %s este necunoscut."
#define MSG_ALIASES_BROKEN_FILE "Fisier de aliasuri defect"
#define MSG_ALIASES_LIST "Sint disponibile urmatoarele aliasuri: "
#define MSG_PERUSER_MAX "Nu pot accepta mai mult de %lu conexiuni de la acelasi utilizator"
#define MSG_IPV6_OK "Conexiunile IPv6 sint acceptate de catre acest server"
#define MSG_TLS_INFO "TLS: Am activat %s cu %s, criptare cu %d biti"
#define MSG_TLS_WEAK "TLS: Sistem de criptare prea slab"
#define MSG_TLS_NEEDED "Sesiunile in text clar nu sint acceptate pe acest server.\n" \
    "Reconectati-va utilizind mecanismele de securitate TLS."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
