#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "시간 초과"
#define MSG_CAPABILITIES "기능 전환 불가"
#define MSG_CLIENT_CLOSED_CNX "클라이언트가 접속을 닫음"
#define MSG_CLIENT_READ_ERR "클라이언트 읽기 오류"
#define MSG_CANT_OPEN_CNX "연결 불가"
#define MSG_CANT_CREATE_DATA_SOCKET "데이터 소켓을 만들수 없음"
#define MSG_DEBUG_CLIENT_IS "접속자의 주소는"
#define MSG_SYNTAX_ERROR_IP "IP 주소 구문에 문제가 있음"
#define MSG_PORT_SUCCESSFUL "PORT 명령 성공"
#define MSG_ONLY_IPV4V6 "IPv4 와 IPv6 만 지원함 (1,2)"
#define MSG_ONLY_IPV4 "IPv4 만 지원 (1)"
#define MSG_TIMEOUT_PARSER "시간 초과"
#define MSG_LINE_TOO_LONG "너무 긴줄"
#define MSG_LOG_OVERFLOW "접속자가 명령어 버퍼의 overflow를 시도함"
#define MSG_GOODBYE "안녕히~ 업로드 %llu / 다운로드 %llu kb"
#define MSG_DEBUG_COMMAND "명령어"
#define MSG_IS_YOUR_CURRENT_LOCATION "에 위치하고 있습니다."
#define MSG_NOT_LOGGED_IN "로그인 하지 않았습니다."
#define MSG_AUTH_UNIMPLEMENTED "보안 도구를 사용할수 없음"
#define MSG_NO_FILE_NAME "파일명 없음"
#define MSG_NO_DIRECTORY_NAME "디렉토리 이름 없음"
#define MSG_NO_RESTART_POINT "재시작 위치가 없음"
#define MSG_ABOR_SUCCESS "ABOR 가 성공함"
#define MSG_MISSING_ARG "변수값이 없음"
#define MSG_GARBAGE_FOUND "변수값뒤에 쓰레기 값이 있음"
#define MSG_VALUE_TOO_LARGE "변수가 너무 큼"
#define MSG_IDLE_TIME "대기 시간 %lu 초로 설정됨"
#define MSG_SITE_HELP "다음 SITE 명령어를 인식함"
#define MSG_BAD_CHMOD "잘못된 권한"
#define MSG_UNKNOWN_EXTENSION "는 모르는 기능임"
#define MSG_XDBG_OK "XDBG 명령 성공, 디버그 수준: %d"
#define MSG_UNKNOWN_COMMAND "모르는 명령"
#define MSG_TIMEOUT_NOOP "시간초과 (%lu 동안 작동하지 않음)"
#define MSG_TIMEOUT_DATA "시간초과 (%lu 초 동안 새로운 데이터를 받지 못함)"
#define MSG_SLEEPING "아~ 졸려 Zzzz..."
#define MSG_ALREADY_LOGGED "이미 로그인 되어있습니다."
#define MSG_ANY_PASSWORD "아무 패스워드로도 로그인 가능함"
#define MSG_ANONYMOUS_LOGGED "Anonymous 유저 로그인"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "가상 FTP에 Anonymous 유저가 로그인함"
#define MSG_USER_OK "유저 %s OK. 암호가 필요합니다."
#define MSG_CANT_DO_TWICE "현재 세션에서는 불가능 합니다."
#define MSG_UNABLE_SECURE_ANON "안전한 anonymous FTP 가 불가능함"
#define MSG_BANDWIDTH_RESTRICTED "대역폭이 제한되어 있습니다."
#define MSG_NO_PASSWORD_NEEDED "아무 패스워드로도 로그인 가능함"
#define MSG_NOTRUST "죄송합니다만, 당신을 믿을 수 없군요."
#define MSG_WHOAREYOU "당신이 누구신가요?"
#define MSG_AUTH_FAILED "인증 실패"
#define MSG_AUTH_TOOMANY "반복된 인증 실패"
#define MSG_NO_HOMEDIR "홈 디렉토리가 존재하지 않음 - 취소"
#define MSG_NO_HOMEDIR2 "%s 가 존재하지 않거나 억세스 할수 없음"
#define MSG_START_SLASH "/ 에서 시작함"
#define MSG_USER_GROUP_ACCESS "유저 %s 는 다음 그룹에 접근 가능"
#define MSG_FXP_SUPPORT "이 서버는 FXP 전송이 사용가능 합니다."
#define MSG_RATIO "업/다운로드 (%u:%u) 비율을 지켜주세요."
#define MSG_CHROOT_FAILED "chroot() 를 설정할수 없음"
#define MSG_CURRENT_DIR_IS "현재 디렉토리: %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "제한된 디렉토리는 %s"
#define MSG_IS_NOW_LOGGED_IN "%s 가 로그인"
#define MSG_CANT_CHANGE_DIR "%s 디렉토리로 이동할수 없음"
#define MSG_PATH_TOO_LONG "패스가 너무 깁니다."
#define MSG_CANT_PASV "IPv6 접속에서 PASV 를 사용할수 없습니다. EPSV 를 사용하세요."
#define MSG_CANT_PASSIVE "패시브 접속을 열수 없음"
#define MSG_PORTS_BUSY "예약된 모든 TCP 포트가 사용중입니다."
#define MSG_GETSOCKNAME_DATA "내부 데이터 소켓이 확인할수 없음"
#define MSG_GETPEERNAME "내부 소켓을 확인할수 없음"
#define MSG_INVALID_IP "잘못된 주소"
#define MSG_NO_EPSV "EPSV 를 지원하는 IPv6 클라이언트를 사용하세요."
#define MSG_BAD_PORT "죄송하지만, 1024 이하 포트로는 접속할수 없습니다."
#define MSG_NO_FXP "%s 포트로는 접속할수 없습니다. (%s 만 사용가)"
#define MSG_FXP "FXP 전송 : %s - %s"
#define MSG_NO_DATA_CONN "데이터가 없음"
#define MSG_ACCEPT_FAILED "접속을 받아들일수 없었음"
#define MSG_ACCEPT_SUCCESS "데이터 접속을 받음"
#define MSG_CNX_PORT_FAILED "%d 포트로 접속이 불가능"
#define MSG_CNX_PORT "%d 포트로 접속중"
#define MSG_ANON_CANT_MKD "죄송합니다. anonymous 유저는 디렉토리를 만들수 없습니다."
#define MSG_ANON_CANT_RMD "죄송합니다. anonymous 유저는 디렉토리를 삭제할수 없습니다."
#define MSG_ANON_CANT_RENAME "Anonymous 유저의 파일의 이동, 파일명 변경이 제한되어 있습니다."
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymous 유저는 퍼미션 변경이 불가능 합니다."
#define MSG_GLOB_NO_MEMORY "%s 를 globbing 하던중 메모리 초과"
#define MSG_PROBABLY_DENIED "(이것은 \"허가 거부\")입니다."
#define MSG_GLOB_READ_ERROR "%s 를 globbing 하던중 읽기 오류 발생"
#define MSG_GLOB_NO_MATCH "찾을수 없음 %s / %s"
#define MSG_CHMOD_FAILED "%s 에서 퍼미션 변경이 불가"
#define MSG_CHMOD_SUCCESS "%s 로 퍼미션이 변경된"
#define MSG_CHMOD_TOTAL_FAILURE "퍼미션 변경이 불가능합니다."
#define MSG_ANON_CANT_DELETE "Anonymous 유저는 파일을 삭제 할수 없습니다."
#define MSG_ANON_CANT_OVERWRITE "Anonymous 유저는 덮어씌우기가 불가능 합니다."
#define MSG_DELE_FAILED "%s 를 삭제할수 없음"
#define MSG_DELE_SUCCESS "%s%s%s%s 삭제됨"
#define MSG_DELE_TOTAL_FAILURE "삭제된 파일 없음"
#define MSG_LOAD_TOO_HIGH \
    "시스템의 부하가 %3.2f 입니다. 현재 다운로드는 불가능합니다.\n" \
    "업로드는 언제나 가능함"

#define MSG_OPEN_FAILURE "%s 를 열수 없음"
#define MSG_OPEN_FAILURE2 "그 파일을 열수 없습니다."
#define MSG_STAT_FAILURE "파일 크기를 알수 없습니다."
#define MSG_STAT_FAILURE2 "파일의 존재여부를 확인할수 없습니다."
#define MSG_REST_TOO_LARGE_FOR_FILE "offset %lld 에서 재시작 불가. 파일 크기 %lld"
#define MSG_REST_RESET "offset 0 부터 재시작"
#define MSG_NOT_REGULAR_FILE "일반적인 파일만 다운로드 할수 있습니다."
#define MSG_NOT_MODERATED \
    "이 파일은 다른 anonymous가 업로드한것으로 관리자의 확인을 거쳐야만 다운로드 할수 있습니다."

#define MSG_RATIO_DENIAL \
    "죄송합니다. 당신의 업/다운 비율은 %u:%u 입니다.\n" \
     "당신은 %llu Kb 를 업로드하고 %llu Kb를 다운로드 하였습니다.\n" \
    "좋은 파일을 업로드 해주세요."
#define MSG_NO_MORE_TO_DOWNLOAD "다운로드 할 것이 없음"
#define MSG_WINNER "컴퓨터는 당신의 친구이니 믿어야만 합니다!"
#define MSG_KBYTES_LEFT "%.1f kb 다운로드"
#define MSG_ABORTED "전송 취소"
#define MSG_DATA_WRITE_FAILED "데이터를 쓰는중 오류 발생"
#define MSG_DATA_READ_FAILED "데이터를 읽는중 오류 발생"
#define MSG_MMAP_FAILED "map 파일을 메모리에 읽어들일수 없음"
#define MSG_WRITE_FAILED "파일을 쓰는중 오류 발생"
#define MSG_TRANSFER_RATE_M "%.3f 초, %.2f Mb/초"
#define MSG_TRANSFER_RATE_K "%.3f 초, %.2f Kb/초"
#define MSG_TRANSFER_RATE_B "%.3f 초, %.2f b/초"
#define MSG_SPACE_FREE_M "사용가능 디스크 용량 %.1f Mb"
#define MSG_SPACE_FREE_K "사용가능 디스크 용량 %f Kb"
#define MSG_DOWNLOADED "다운로드 종료"
#define MSG_REST_NOT_NUMERIC "REST는 숫자 변수를 필요로 함"
#define MSG_REST_ASCII_STRICT "ASCII 모드에서는 Reply marker 가 0 여야함"
#define MSG_REST_ASCII_WORKAROUND "%lld 부터 재시작. 그러나 ASCII 모드임"
#define MSG_REST_SUCCESS "%lld 부터 재시작"
#define MSG_SANITY_DIRECTORY_FAILURE "사용 불가능한 디렉토리명"
#define MSG_SANITY_FILE_FAILURE "사용 불가능한 파일 이름: %s"
#define MSG_MKD_FAILURE "디렉토리를 만들수 없음"
#define MSG_MKD_SUCCESS "디렉토리를 성공적으로 만듬"
#define MSG_RMD_FAILURE "디렉토리를 삭제할수 없음"
#define MSG_RMD_SUCCESS "디렉토리가 성공적으로 삭제됨"
#define MSG_TIMESTAMP_FAILURE "time stamp를 읽지 못함"
#define MSG_MODE_ERROR "ASCII과 바이너리 모드만을 지원함"
#define MSG_CREATE_FAILURE "파일 생성 불가"
#define MSG_ABRT_ONLY "ABRT 명령은 업로드때만 사용할수 있습니다."
#define MSG_UPLOAD_PARTIAL "일부분만 업로드됨"
#define MSG_REMOVED "삭제됨"
#define MSG_UPLOADED "업로드됨"
#define MSG_GMTIME_FAILURE "현재 시간을 알수 없음"
#define MSG_TYPE_8BIT_FAILURE "8-bit bytes만을 지원합니다. 지금은 10년전이 아니잖아요?"
#define MSG_TYPE_UNKNOWN "알수 없는 TYPE"
#define MSG_TYPE_SUCCESS "현재 TYPE 은"
#define MSG_STRU_FAILURE "F(ile) 만을 지원함"
#define MSG_MODE_FAILURE "S(tream) 모드를 사용하세요"
#define MSG_RENAME_ABORT "이름 변경 작업을 취소함"
#define MSG_RENAME_RNFR_SUCCESS "RNFR 허용됨 - 파일 존재, 전송 준비됨"
#define MSG_FILE_DOESNT_EXIST "죄송합니다만, 파일이 없습니다."
#define MSG_RENAME_ALREADY_THERE "RENAME 실패 - 파일이 이미 존재합니다."
#define MSG_RENAME_NORNFR "RNFR 후에 RNTO 사용"
#define MSG_RENAME_FAILURE "이름변경/이동 실패"
#define MSG_RENAME_SUCCESS "파일이 성공적으로 변경/이동됨"
#define MSG_NO_SUPERSERVER "pure-ftpd를 super-server (tcpserver와 같은)로 실행하세요."
#define MSG_NO_FTP_ACCOUNT "'ftp' 계정이 존재하지 않음"
#define MSG_CONF_ERR "설정 오류"
#define MSG_NO_VIRTUAL_FILE "가상 유저 파일 이름이 없음"
#define MSG_ILLEGAL_THROTTLING "잘못된 전송 속도값"
#define MSG_ILLEGAL_TRUSTED_GID "chroot를 위한 gid 값이 잘못됨"
#define MSG_ILLEGAL_USER_LIMIT "잘못된 최대 유저수값"
#define MSG_ILLEGAL_FACILITY "모르는 facility 이름"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "잘못된 LDAP 설정 파일"
#define MSG_ILLEGAL_LOAD_LIMIT "잘못된 서버부하 제한값"
#define MSG_ILLEGAL_PORTS_RANGE "잘못된 포트 범위"
#define MSG_ILLEGAL_LS_LIMITS "잘못된 'ls' 제한"
#define MSG_ILLEGAL_FORCE_PASSIVE "패시브 연결을 위한 IP 값이 설정에 문제가 있음"
#define MSG_ILLEGAL_RATIO "업/다운 비율값이 잘못됨"
#define MSG_ILLEGAL_UID_LIMIT "uid 제한값이 잘못됨"
#define MSG_ILLEGAL_OPTION "알수 없는 실행 옵션"
#define MSG_LDAP_MISSING_BASE "LDAP 설정파일에 LDAPBaseDN 값이 없음"
#define MSG_LDAP_WRONG_PARMS "잘못된 LDAP 설정"
#define MSG_NEW_CONNECTION "%s 부터 새로운 연결"
#define MSG_WELCOME_TO "어서오세요!~"
#define MSG_MAX_USERS "%lu 명 (최대 동시 접속 제한)이 이미 접속해 있습니다. 죄송합니다."
#define MSG_NB_USERS "당신은 %u 번째로 접속중입니다. 최대 %u 명"
#define MSG_WELCOME_TIME "현재 시각은 %02d:%02d, 사용중인 포트는 %u 입니다."
#define MSG_ANONYMOUS_FTP_ONLY "anonymous 유저만 접속 가능합니다."
#define MSG_RATIOS_EVERYONE "모든 유저에게 업/다운 비율이 적용됨 :"
#define MSG_RATIOS_ANONYMOUS "anonymous 유저는 업/다운 비율이 적용됨 :"
#define MSG_RATIOS_RULE "다운로드 %u Mb, 업로드 %u Mb"
#define MSG_INFO_IDLE_M "%lu 분 동안 아무것도 하지 않으면 접속이 끊어집니다."
#define MSG_INFO_IDLE_S "%lu 초 동안 아무것도 하지 않으면 접속이 끊어집니다."
#define MSG_CANT_READ_FILE "[%s] 파일을 읽을수 없습니다."
#define MSG_LS_TRUNCATED "%u 개의 결과 표시"
#define MSG_LS_SUCCESS "%u 가 일치됨"
#define MSG_LOGOUT "로그아웃."
#define MSG_AUTH_FAILED_LOG "[%s] 유저 인증 실패"
#define MSG_ILLEGAL_UMASK "잘못된 umask"
#define MSG_STANDALONE_FAILED "standalone 모드로 서버를 시작할수 없습니다."
#define MSG_NO_ANONYMOUS_LOGIN "anonymous 접속은 허용하지 않습니다."
#define MSG_ANONYMOUS_ANY_PASSWORD "아무 패스워드나 허용됨"
#define MSG_MAX_USERS_IP "(%lu) 로 부터 초과된 접속수"
#define MSG_ACTIVE_DISABLED "Active 모드는 사용 불가됨"
#define MSG_TRANSFER_SUCCESSFUL "파일이 성공적으로 전송됨"
#define MSG_NO_DISK_SPACE "디스크 용량 부족 - 나중에 업로드 해주세요"
#define MSG_OUT_OF_MEMORY "메모리 초과"
#define MSG_ILLEGAL_TRUSTED_IP "잘못된 신뢰되는 IP 주소"
#define MSG_NO_ASCII_RESUME "ASCII 모드로 재전송은 안전하지 않으니, 먼저 파일을 삭제 하세요."
#define MSG_UNKNOWN_ALTLOG "잘못된 로그 형태"
#define MSG_ACCOUNT_DISABLED "[%s] 로 로그인 불가 : 계정 사용불가"
#define MSG_SQL_WRONG_PARMS "잘못된 SQL 변수"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "SQL 설정 파일에 문제가 있음"
#define MSG_SQL_MISSING_SERVER "SQL 설정 파일에 서버가 없음"
#define MSG_SQL_DOWN "SQL 가 작동되지 않는것 같습니다."
#define MSG_ILLEGAL_QUOTA "잘못된 쿼타 설정"
#define MSG_QUOTA_FILES "%llu 개의 파일 (%d%%) - 최대: %llu files"
#define MSG_QUOTA_SIZE "%llu Kbytes 사용중 (%d%%) - 최대: %llu Kb"
#define MSG_QUOTA_EXCEEDED "쿼타가 초과되었음 : [%s] 는 저장되지 않았음"
#define MSG_AUTH_UNKNOWN "잘못된 인증 방식"
#define MSG_PDB_BROKEN "puredb 인덱스 파일을 읽을수 없음 (또는 이전 포맷을 인식하지 못함) - pure-pw mkdb 를 시도해 볼것"
#define MSG_ALIASES_ALIAS "%s은 %s의 별칭."
#define MSG_ALIASES_UNKNOWN "알 수 없는 별칭 %s."
#define MSG_ALIASES_BROKEN_FILE "손상된 별칭 파일"
#define MSG_ALIASES_LIST "다음의 별칭이 있음 :"
#define MSG_PERUSER_MAX "같은 유저로 %lu 번 이상의 연결을 허용하지 않습니다."
#define MSG_IPV6_OK "이 서버는 IPv6 연결도 허용합니다."
#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
