#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Przekroczony czas oczekiwania"
#define MSG_CAPABILITIES "Nie można przełączać capabilities"
#define MSG_CLIENT_CLOSED_CNX "Klient zamknął połączenie"
#define MSG_CLIENT_READ_ERR "Błąd odczytu danych od klienta"
#define MSG_CANT_OPEN_CNX "Nie można utworzyć połączenia"
#define MSG_CANT_CREATE_DATA_SOCKET "Nie można utworzyć gniazda dla danych"
#define MSG_DEBUG_CLIENT_IS "Adres klienta to"
#define MSG_SYNTAX_ERROR_IP "Błąd składni w adresie IP"
#define MSG_PORT_SUCCESSFUL "komenda PORT powiodła się"
#define MSG_ONLY_IPV4V6 "Tylko IPv4 oraz IPv6 są wspierane (1,2)"
#define MSG_ONLY_IPV4 "Tylko IPv4 jest wspierane (1)"
#define MSG_TIMEOUT_PARSER "Przekroczono czas oczekiwaniat - wpisuj szybciej następnym razem"
#define MSG_LINE_TOO_LONG "Linia zbyt długa"
#define MSG_LOG_OVERFLOW "Klient próbował przepełnić bufor lini poleceń"
#define MSG_GOODBYE "Żegnaj. Wgrałeś %llu oraz ściągnąłeś %llu kbajtów."
#define MSG_DEBUG_COMMAND "Komenda"
#define MSG_IS_YOUR_CURRENT_LOCATION "to Twoja aktualna lokalizacja"
#define MSG_NOT_LOGGED_IN "Nie jesteś aktualnie zalogowany"
#define MSG_AUTH_UNIMPLEMENTED "Rozszerzenia bezpieczeństwa nie zaimplementowane"
#define MSG_NO_FILE_NAME "Brak nazwy pliku"
#define MSG_NO_DIRECTORY_NAME "Brak nazwy katalogu"
#define MSG_NO_RESTART_POINT "Brak punktu z którego ponawiać"
#define MSG_ABOR_SUCCESS "Ponieważ to widzisz komenda ABOR zakończyła się sukcesem"
#define MSG_MISSING_ARG "Brakuje argumentu"
#define MSG_GARBAGE_FOUND "Znaleziono śmieci po informacji o wartości"
#define MSG_VALUE_TOO_LARGE "Wartośc zbyt duża"
#define MSG_IDLE_TIME "Czas oczekiwania ustawiony na %lu sekund"
#define MSG_SITE_HELP "Następujące komendy SITE są obsługiwane"
#define MSG_BAD_CHMOD "Nieprawidłowe prawa"
#define MSG_UNKNOWN_EXTENSION "jest nieznanym rozszerzeniem"
#define MSG_XDBG_OK "komenda XDBG powiodła się, aktualny poziom debugowania to %d"
#define MSG_UNKNOWN_COMMAND "Nieznana komenda"
#define MSG_TIMEOUT_NOOP "Przekroczony czas oczekiwania (brak operacji w ciągu %lu sekund)"
#define MSG_TIMEOUT_DATA "Przekroczony czas oczekiwania (brak nowych danych w ciągu %lu sekund)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Jesteś już zalogowany"
#define MSG_ANY_PASSWORD "Dowolne hasło zadziała"
#define MSG_ANONYMOUS_LOGGED "Anonimowy użytkownik zalogowany"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonimowy użytkownik zalogowany w wirtualnym FTP"
#define MSG_USER_OK "Użytkownik %s OK. Wymagane hasło"
#define MSG_CANT_DO_TWICE "Nie można tego zrobić w aktualnej sesji"
#define MSG_UNABLE_SECURE_ANON "Nie można uaktywnić bezpiecznego anonimowego FTP"
#define MSG_BANDWIDTH_RESTRICTED "Twoje zużycie pasma jest ograniczone"
#define MSG_NO_PASSWORD_NEEDED "Nie potrzebuję żadnego hasła, mój drogi, tchóżliwy anonimie"
#define MSG_NOTRUST "Wybacz ale nie można Ci ufać"
#define MSG_WHOAREYOU "Proszę powiedz mi kim jesteś"
#define MSG_AUTH_FAILED "Uwierzytelnienie nie powiodło się, wybacz"
#define MSG_AUTH_TOOMANY "Zbyt wiele niepowodzeń podczas uwierzytelniania"
#define MSG_NO_HOMEDIR "Katalog domowy jest niedostępny - przerywam"
#define MSG_NO_HOMEDIR2 "%s nie istnieje lub nie można go odczytać"
#define MSG_START_SLASH "Startuje w /"
#define MSG_USER_GROUP_ACCESS "Użytkownik %s ma grupowy dostęp do"
#define MSG_FXP_SUPPORT "Ten serwer wspiera transfer FXP"
#define MSG_RATIO "Musisz respektować współczynnik %u:%u (wgrane/pobrane)"
#define MSG_CHROOT_FAILED "Nie można uaktywnić bezpiecznego więzienia chroot()"
#define MSG_CURRENT_DIR_IS "OK. Aktualny katalog to %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Aktualny, ograniczony katalog to %s"
#define MSG_IS_NOW_LOGGED_IN "%s jest teraz zalogowany"
#define MSG_CANT_CHANGE_DIR "Nie można zmienić katalogu na %s"
#define MSG_PATH_TOO_LONG "Ścieżka zbyt długa"
#define MSG_CANT_PASV "Nie można utworzyć pasywnego połączenia za pomocą tej starej komendy"
#define MSG_CANT_PASSIVE "Nie można utworzyć pasywnego połączenia"
#define MSG_PORTS_BUSY "Wszystkie zarezerwowane porty TCP są zajęte"
#define MSG_GETSOCKNAME_DATA "Nie można zidentyfikować lokalnego gniazda danych"
#define MSG_GETPEERNAME "Nie można zidentyfikować lokalnego gniazda danych"
#define MSG_INVALID_IP "Wybacz, podano zły adres"
#define MSG_NO_EPSV "Proszę użyj klienta IPv6 zgodnego ze standardem obsługi EPSV"
#define MSG_BAD_PORT "Wybacz ale nie połączę się z portami < 1024"
#define MSG_NO_FXP "Otwieranie połączenia do %s zamiast do %s"
#define MSG_FXP "transfer FXP : z %s do %s"
#define MSG_NO_DATA_CONN "Połączenie danych nie istnieje"
#define MSG_ACCEPT_FAILED "Połączenie nie mogło zostać zaakceptowane"
#define MSG_ACCEPT_SUCCESS "Zaakceptowano połączenie danych"
#define MSG_CNX_PORT_FAILED "Nie można otworzyć połączenia danych do portu %d"
#define MSG_CNX_PORT "Łączenie z portem %d"
#define MSG_ANON_CANT_MKD "Wybacz, anonimowi użytkownicy nie mogą tworzyć katalogów"
#define MSG_ANON_CANT_RMD "Wybacz, anonimowi użytkownicy nie mogą usuwać katalogów"
#define MSG_ANON_CANT_RENAME "Anonimowi użytkownicy nie mogą przenosić/zmieniać nazw plików"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonimowi użytkownicy nie mogą zmieniać praw"
#define MSG_GLOB_NO_MEMORY "Zabrakło pamięci podczas rozwijania %s"
#define MSG_PROBABLY_DENIED "(To prawdopodobnie oznacza \"Brak dostępu\")"
#define MSG_GLOB_READ_ERROR "Błąd odczytu podczas rozwijania %s"
#define MSG_GLOB_NO_MATCH "Brak pasujących do %s w %s"
#define MSG_CHMOD_FAILED "Nie można zmienić praw na %s"
#define MSG_CHMOD_SUCCESS "Prawa na %s zostały zmienione"
#define MSG_CHMOD_TOTAL_FAILURE "Wybacz ale nie można było zmienić żadnego prawa"
#define MSG_ANON_CANT_DELETE "Anonimowi użytkownicy nie mogą kasować plików"
#define MSG_ANON_CANT_OVERWRITE "Anonimowi użytkownicy nie mogą nadpisywać istniejących plików"
#define MSG_DELE_FAILED "Nie można skasować %s"
#define MSG_DELE_SUCCESS "Skasowano %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "Nie skasowano żadnego pliku"
#define MSG_LOAD_TOO_HIGH \
    "Obciążenie systemu wynnosiło %3.2f w momencie Twojego zalogowania. Nie pozwalamy\n" \
    "anonimowym użytkownikom na pobieranie plików przy tak dużym obciążeniu systemu.\n" \
    "Wgrywanie jest zawsze dozwolone."
#define MSG_OPEN_FAILURE "Nie można otworzyć %s"
#define MSG_OPEN_FAILURE2 "Nie można otworzyć tego pliku"
#define MSG_STAT_FAILURE "Nie można uzyskać wielkości pliku"
#define MSG_STAT_FAILURE2 "Nie można sprawdzić czy plik istnieje"
#define MSG_REST_TOO_LARGE_FOR_FILE "Przesunięcie podczas wznawiania %lld jest zbyt duże dla pliku o wielkości %lld."
#define MSG_REST_RESET "Przesunięcie podczas wznawiania ustawione na 0"
#define MSG_NOT_REGULAR_FILE "Można przesyłać wyłącznie regularne pliki"
#define MSG_NOT_MODERATED \
    "Ten plik został wgrany przez anonimowego użytkownika i nie został zatwierdzony\n" \
    "przez administratora do ściągania."
#define MSG_RATIO_DENIAL \
    "Wybacz ale współczynnik wgrywania/ściągania to %u:%u .\n" \
    "Aktualnie wgrałeś %llu Kb i ściągnąłeś %llu Kb.\n" \
    "Proszę wgraj jakieś dane i spróbuj ściągnąć później."
#define MSG_NO_MORE_TO_DOWNLOAD "Nie pozostało nic do ściągania"
#define MSG_WINNER "Komputer jest Twoim przyjacielem. Zaufaj mu"
#define MSG_KBYTES_LEFT "%.1f kbajtów do ściągnięcia"
#define MSG_ABORTED "Transfer przerwano"
#define MSG_DATA_WRITE_FAILED "Błąd podczas pisania danych do połączenia dla danych"
#define MSG_DATA_READ_FAILED "Błąd podczas odczytu danych z połączenia dla danych"
#define MSG_MMAP_FAILED "Nie można zmapować pliku do pamięci"
#define MSG_WRITE_FAILED "Błąd podczas zapisu do pliku"
#define MSG_TRANSFER_RATE_M "%.3f sekund (zmierzonych tutaj), %.2f Mbajtów na sekundę"
#define MSG_TRANSFER_RATE_K "%.3f sekund (zmierzonych tutaj), %.2f Kbajtów na sekundę"
#define MSG_TRANSFER_RATE_B "%.3f sekund (zmierzonych tutaj), %.2f bajtów na sekundę"
#define MSG_SPACE_FREE_M "%.1f Mbajtów wolnej przestrzeni dyskowej"
#define MSG_SPACE_FREE_K "%f Kbajtów wolnej przestrzeni dyskowej"
#define MSG_DOWNLOADED "ściągnięto"
#define MSG_REST_NOT_NUMERIC "REST wymaga numerycznego parametru"
#define MSG_REST_ASCII_STRICT "Znacznik odpowiedzi musi być ustawiony na 0 w trybie ASCII"
#define MSG_REST_ASCII_WORKAROUND "Wznawiam od %lld ale jesteśmy w trybie ASCII"
#define MSG_REST_SUCCESS "Wznawiam od %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Niedozwolona nazwa katalogu"
#define MSG_SANITY_FILE_FAILURE "Niedozwolona nazwa pliku: %s"
#define MSG_MKD_FAILURE "Nie można utworzyć katalogu"
#define MSG_MKD_SUCCESS "Utworzono katalog"
#define MSG_RMD_FAILURE "Nie można usunąć katalogu"
#define MSG_RMD_SUCCESS "Katalog został usunięty"
#define MSG_TIMESTAMP_FAILURE "Nie można uzyskać znacznika czasu"
#define MSG_MODE_ERROR "Tylko tryby ASCII i binarny są wspierane"
#define MSG_CREATE_FAILURE "Nie można utworzyć pliku"
#define MSG_ABRT_ONLY "ABRT jest prawidłową komendą tylko podczas wgrywania"
#define MSG_UPLOAD_PARTIAL "częściowo wgrano"
#define MSG_REMOVED "zmieniono nazwę"
#define MSG_UPLOADED "wgrano"
#define MSG_GMTIME_FAILURE "Nie można uzyskać lokalnego czasu"
#define MSG_TYPE_8BIT_FAILURE "Tylko 8-bitowe bajty są wspierane, nie żyjemy 10 lat temu"
#define MSG_TYPE_UNKNOWN "Nieznany TYP"
#define MSG_TYPE_SUCCESS "TYP to aktualnie"
#define MSG_STRU_FAILURE "Tylko Pliki (\"F\"iles) są wspierane"
#define MSG_MODE_FAILURE "Proszę użyj trybu S(trumieniowego)"
#define MSG_RENAME_ABORT "Anulowanie poprzedniej operacji zmiany nazwy"
#define MSG_RENAME_RNFR_SUCCESS "RNFR zaakceptowane - plik istnieje, gotów do przeznaczenia"
#define MSG_FILE_DOESNT_EXIST "Wybacz ale taki plik nie istnieje"
#define MSG_RENAME_ALREADY_THERE "RENAME Niepowiodło się - plik docelowy już istnieje"
#define MSG_RENAME_NORNFR "Potrzeba RNFR przed RNTO"
#define MSG_RENAME_FAILURE "Usuwanie/zmiana nazwy nie powiodła się"
#define MSG_RENAME_SUCCESS "Zmieniono lub przeniesiono plik"
#define MSG_NO_SUPERSERVER "Proszę uruchom pure-ftpd z serwerem nadrzędnym (takim jak tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nie można znaleść konta 'ftp'"
#define MSG_CONF_ERR "Błąd konfiguracji"
#define MSG_NO_VIRTUAL_FILE "Brakuje nazwy pliku wirtualnych użytkowników"
#define MSG_ILLEGAL_THROTTLING "Nieprawidłowa wartość dla limitu pasma"
#define MSG_ILLEGAL_TRUSTED_GID "Nieprawidłowy zaufany gid dla chroota"
#define MSG_ILLEGAL_USER_LIMIT "Nieprawidłowy limit użytkowników"
#define MSG_ILLEGAL_FACILITY "Nieznana nazwa facility"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Nieprawidłowy plik konfiguracyjny LDAP"
#define MSG_ILLEGAL_LOAD_LIMIT "Nieprawidłowy limit load"
#define MSG_ILLEGAL_PORTS_RANGE "Nieprawidłowy przedział portów"
#define MSG_ILLEGAL_LS_LIMITS "Nieprawidłowy limit 'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "Niepdawidłowe IP wymuszone dla pasywnych połączeń"
#define MSG_ILLEGAL_RATIO "Nieprawidłowy współczynnik dotyczący ściągania/wgrywania"
#define MSG_ILLEGAL_UID_LIMIT "Nieprawidłowy limit uid"
#define MSG_ILLEGAL_OPTION "Nieznana opcja"
#define MSG_LDAP_MISSING_BASE "Brakuje LDAPBaseDN w pliku konfiguracyjnym LDAP"
#define MSG_LDAP_WRONG_PARMS "Błędne parametry LDAP"
#define MSG_NEW_CONNECTION "Nowe połączenie z %s"
#define MSG_WELCOME_TO "Witaj na"
#define MSG_MAX_USERS "%lu użytkowników (maksimum) już zalogowanych, wybacz"
#define MSG_NB_USERS "Jesteś %u użytkownikiem z %u możliwych"
#define MSG_WELCOME_TIME "Lokalny czas: %02d:%02d. Port serwera: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Wyłącznie anonimowe FTP jest dozwolone"
#define MSG_RATIOS_EVERYONE "WSPÓŁCZYNNIK OBEJMUJE WSZYSTKICH UŻYTKOWNIKÓW :"
#define MSG_RATIOS_ANONYMOUS "ANONIMOWYCH UŻYTKOWNIKÓW OBEJMUJE WSPÓŁCZYNNIK UL/DL :"
#define MSG_RATIOS_RULE "by ściągnąć %u Mb, musisz wgrać %u Mb danych."
#define MSG_INFO_IDLE_M "Zostaniesz rozłączony po %lu minutach nieaktywności."
#define MSG_INFO_IDLE_S "Zostaniesz rozłączony po %lu sekundach nieaktywności."
#define MSG_CANT_READ_FILE "Niestety, nie można było przeczytać [%s]"
#define MSG_LS_TRUNCATED "Wyjście obcięte do %u pasujących"
#define MSG_LS_SUCCESS "%u w sumie pasujących"
#define MSG_LOGOUT "Wylogowywanie."
#define MSG_AUTH_FAILED_LOG "Autentyfikacja nie powiodła się dla użytkownika [%s]"
#define MSG_ILLEGAL_UMASK "Nieprawidłowa umask"
#define MSG_STANDALONE_FAILED "Nie można wystartować w trybie standalone"
#define MSG_NO_ANONYMOUS_LOGIN "To jest prywatny system - Bez anonimowych logowań"
#define MSG_ANONYMOUS_ANY_PASSWORD "Dowolne hasło zadziała"
#define MSG_MAX_USERS_IP "Zbyt wiele połączeń (%lu) z tego IP"
#define MSG_ACTIVE_DISABLED "Tryb aktywny jest zablokowany"
#define MSG_TRANSFER_SUCCESSFUL "Przesył pliku zakończony sukcesem"
#define MSG_NO_DISK_SPACE "Dysk pełny - proszę wgraj później"
#define MSG_OUT_OF_MEMORY "Zabrakło pamięci"
#define MSG_SQL_WRONG_PARMS "Błędne parametry SQL"
#define MSG_ILLEGAL_TRUSTED_IP "Nieprawidłowy zaufany adres IP"
#define MSG_NO_ASCII_RESUME "Wznawianie transferu ASCII nie jest bezpieczne, proszę najpierw usuń plik"
#define MSG_UNKNOWN_ALTLOG "Nieznany format logów"
#define MSG_ACCOUNT_DISABLED "Nie można zalogować się jako [%s] : konto zablokowane"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Nieprawidłowy plik konfiguracji SQL"
#define MSG_SQL_MISSING_SERVER "W konfiguracji SQL brakuje serwera"
#define MSG_SQL_DOWN "Serwer SQL jest prawdopodobnie niedostępny" 
#define MSG_ILLEGAL_QUOTA "Nieprawidłowa quota"
#define MSG_QUOTA_FILES "%llu plików użytych (%d%%) - autoryzowano: %llu plików"
#define MSG_QUOTA_SIZE "%llu Kbajtów użytych (%d%%) - autoryzowano: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Przekroczona quota: [%s] nie zostanie zapisany"
#define MSG_AUTH_UNKNOWN "Nieznana metoda autentyfikacji"
#define MSG_PDB_BROKEN "Nie udało się odczytać indeksowanego pliku puredb (lub wykryto stary format) - Spróbuj uruchomić pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s is an alias for %s."
#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
#define MSG_ALIASES_LIST "The following aliases are available :"
#define MSG_PERUSER_MAX "I can't accept more than %lu connections from the same user"
#define MSG_IPV6_OK "IPv6 connections are also welcome on this server"
#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
