#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Tempo expirado"
#define MSG_CAPABILITIES "Não foi possível trocar capacidades"
#define MSG_CLIENT_CLOSED_CNX "Cliente encerrou a conexão"
#define MSG_CLIENT_READ_ERR "Erro de leitura do cliente"
#define MSG_CANT_OPEN_CNX "Não foi possível abrir conexão"
#define MSG_CANT_CREATE_DATA_SOCKET "Não foi possível criar socket de dados"
#define MSG_DEBUG_CLIENT_IS "Endereço do cliente é"
#define MSG_SYNTAX_ERROR_IP "Erro de sintaxe no endereço IP"
#define MSG_PORT_SUCCESSFUL "Comando PORT bem sucedido"
#define MSG_ONLY_IPV4V6 "Somente IPv4 e IPv6 são suportados (1,2)"
#define MSG_ONLY_IPV4 "Somente IPv4 é suportado (1)"
#define MSG_TIMEOUT_PARSER "Tempo expirado - experimente digitar um pouco mais rápido na próxima vez"
#define MSG_LINE_TOO_LONG "Linha muito comprida"
#define MSG_LOG_OVERFLOW "O cliente tentou estourar o buffer da linha de comando"
#define MSG_GOODBYE "Adeus. Você enviou %llu e recebeu %llu kbytes."
#define MSG_DEBUG_COMMAND "Comando"
#define MSG_IS_YOUR_CURRENT_LOCATION "é a sua localização atual"
#define MSG_NOT_LOGGED_IN "Você não está logado"
#define MSG_AUTH_UNIMPLEMENTED "Extensões de segurança não implementadas"
#define MSG_NO_FILE_NAME "Nome do arquivo não informado"
#define MSG_NO_DIRECTORY_NAME "Nome do diretório não informado"
#define MSG_NO_RESTART_POINT "Não existe um ponto de reinício"
#define MSG_ABOR_SUCCESS "Comando ABOR bem sucedido"
#define MSG_MISSING_ARG "Falta argumento"
#define MSG_GARBAGE_FOUND "Sujeira encontrada depois do valor"
#define MSG_VALUE_TOO_LARGE "Valor muito grande"
#define MSG_IDLE_TIME "Tempo ocioso configurado para %lu segundos"
#define MSG_SITE_HELP "Os seguintes comandos SITE são reconhecidos"
#define MSG_BAD_CHMOD "Permissões inválidas"
#define MSG_UNKNOWN_EXTENSION "é uma extensão desconhecida"
#define MSG_XDBG_OK "Comando XDBG foi bem sucedido, nível de depuração agora é %d"
#define MSG_UNKNOWN_COMMAND "Comando desconhecido"
#define MSG_TIMEOUT_NOOP "Tempo expirado (nenhuma operação durante %lu segundos)"
#define MSG_TIMEOUT_DATA "Tempo expirado (nenhum dado novo durante %lu segundos)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Você já está logado"
#define MSG_ANY_PASSWORD "Qualquer senha funcionará"
#define MSG_ANONYMOUS_LOGGED "Usuário anônimo logado"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Usuário anônimo logado no FTP virtual"
#define MSG_USER_OK "Usuário %s OK. Senha requerida"
#define MSG_CANT_DO_TWICE "Não é possível realizar isto na sessão atual"
#define MSG_UNABLE_SECURE_ANON "Não é possível configurar FTP anônimo seguro"
#define MSG_BANDWIDTH_RESTRICTED "Seu uso de largura de banda está restrito"
#define MSG_NO_PASSWORD_NEEDED "Senha não requerida"
#define MSG_NOTRUST "Desculpe, não posso confiar em você"
#define MSG_WHOAREYOU "Por favor informe quem você é"
#define MSG_AUTH_FAILED "Autenticação falhou, desculpe"
#define MSG_AUTH_TOOMANY "Muitas falhas de autenticação"
#define MSG_NO_HOMEDIR "Diretório pessoal não disponível - cancelando"
#define MSG_NO_HOMEDIR2 "%s não existe ou é inalcançável"
#define MSG_START_SLASH "Iniciando em /"
#define MSG_USER_GROUP_ACCESS "Usuário %s tem acesso de grupo a"
#define MSG_FXP_SUPPORT "Este servidor suporta transferência FXP"
#define MSG_RATIO "A proporção %u:%u (UL/DL) deve ser respeitada"
#define MSG_CHROOT_FAILED "Não foi possível configurar uma jaula chroot() segura"
#define MSG_CURRENT_DIR_IS "OK. Diretório atual é %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Diretório restrito atual é %s"
#define MSG_IS_NOW_LOGGED_IN "%s agora está logado"
#define MSG_CANT_CHANGE_DIR "Não foi possível entrar no diretório %s"
#define MSG_PATH_TOO_LONG "Path muito comprido"
#define MSG_CANT_PASV "Não é possível usar PASV em conexões IPv6 (comando obsoleto). Use o comando EPSV."
#define MSG_CANT_PASSIVE "Não foi possível abrir uma conexão passiva"
#define MSG_PORTS_BUSY "Todas as portas TCP reservadas estão ocupadas"
#define MSG_GETSOCKNAME_DATA "Não foi possível identificar o socket de dados local"
#define MSG_GETPEERNAME "Não foi possível identificar o socket local"
#define MSG_INVALID_IP "Desculpe, endereço fornecido inválido"
#define MSG_NO_EPSV "Favor utilizar um cliente compatível com IPv6, com suporte a EPSV"
#define MSG_BAD_PORT "Desculpe, não me conectarei a portas < 1024"
#define MSG_NO_FXP "Não abrirei uma conexão para %s (somente para %s)"
#define MSG_FXP "Transferência FXP : de %s para %s"
#define MSG_NO_DATA_CONN "Não existe conexão de dados"
#define MSG_ACCEPT_FAILED "A conexão não pôde ser aceita"
#define MSG_ACCEPT_SUCCESS "Conexão de dados aceita"
#define MSG_CNX_PORT_FAILED "Não foi possível abrir conexão de dados com a porta %d"
#define MSG_CNX_PORT "Conectando com a porta %d"
#define MSG_ANON_CANT_MKD "Desculpe, usuários anônimos não têm permissão para criar diretórios"
#define MSG_ANON_CANT_RMD "Desculpe, usuários anônimos não têm permissão para remover diretórios"
#define MSG_ANON_CANT_RENAME "Usuários anônimos não têm permissão para mover/renomear arquivos"
#define MSG_ANON_CANT_CHANGE_PERMS "Usuários anônimos não podem alterar permissões"
#define MSG_GLOB_NO_MEMORY "Sem memória (devido expansão de %s)"
#define MSG_PROBABLY_DENIED "(Isto provavelmente significa \"Permissão negada\")"
#define MSG_GLOB_READ_ERROR "Erro de leitura durante expansão de %s"
#define MSG_GLOB_NO_MATCH "Nenhuma ocorrência de %s em %s"
#define MSG_CHMOD_FAILED "Não foi possível alterar permissões em %s"
#define MSG_CHMOD_SUCCESS "Permissões alteradas em %s"
#define MSG_CHMOD_TOTAL_FAILURE "Desculpe, não foi possível alterar nenhuma permissão"
#define MSG_ANON_CANT_DELETE "Usuários anônimos não têm permissão para remover arquivos"
#define MSG_ANON_CANT_OVERWRITE "Usuários anônimos não têm permissão para sobrescrever arquivos existentes"
#define MSG_DELE_FAILED "Não foi possível remover %s"
#define MSG_DELE_SUCCESS "%s%s%s%s foi removido"
#define MSG_DELE_TOTAL_FAILURE "Nenhum arquivo foi removido"
#define MSG_LOAD_TOO_HIGH \
    "A carga era %3.2f quando a conexão foi realizada. Não é permitido recebimento\n" \
    "de arquivos por usuários anônimos quando a carga estiver tão alta.\n" \
    "Envio de arquivos é sempre permitido."
#define MSG_OPEN_FAILURE "Não foi possível abrir %s"
#define MSG_OPEN_FAILURE2 "Não foi possível abrir esse arquivo"
#define MSG_STAT_FAILURE "Não foi possível determinar o tamanho do arquivo"
#define MSG_STAT_FAILURE2 "Não foi possível verificar a existência do arquivo"
#define MSG_REST_TOO_LARGE_FOR_FILE "Restart offset %lld é muito grande para tamanho de arquivo %lld."
#define MSG_REST_RESET "Restart offset reinicializado em 0"
#define MSG_NOT_REGULAR_FILE "Somente arquivos comuns podem ser recebidos"
#define MSG_NOT_MODERATED \
    "Este arquivo foi enviado por um usuário anônimo. Porém ainda não\n" \
    "foi aprovado pelos administradores do site para poder ser recebido."
#define MSG_RATIO_DENIAL \
    "Desculpe, a proporção de envio/recebimento é %u:%u .\n" \
    "Até o momento você enviou %llu Kb e recebeu %llu Kb.\n" \
    "Por favor envie mais arquivos e tente fazer o recebimento posteriormente."
#define MSG_NO_MORE_TO_DOWNLOAD "Não há mais nada para receber"
#define MSG_WINNER "O computador é seu amigo. Confie nele"
#define MSG_KBYTES_LEFT "%.1f kbytes para receber"
#define MSG_ABORTED "Transferência cancelada"
#define MSG_DATA_WRITE_FAILED "Erro durante escrita à conexão de dados"
#define MSG_DATA_READ_FAILED "Erro durante leitura da conexão de dados"
#define MSG_MMAP_FAILED "Não foi possível mapear o arquivo na memória"
#define MSG_WRITE_FAILED "Erro durante escrita a arquivo"
#define MSG_TRANSFER_RATE_M "%.3f segundos (medidos aqui), %.2f Mbytes por segundo"
#define MSG_TRANSFER_RATE_K "%.3f segundos (medidos aqui), %.2f Kbytes por segundo"
#define MSG_TRANSFER_RATE_B "%.3f segundos (medidos aqui), %.2f bytes por segundo"
#define MSG_SPACE_FREE_M "%.1f Mbytes de espaço livre em disco"
#define MSG_SPACE_FREE_K "%f Kbytes de espaço livre em disco"
#define MSG_DOWNLOADED "recebido"
#define MSG_REST_NOT_NUMERIC "REST requer um parâmetro numérico"
#define MSG_REST_ASCII_STRICT "Marca de resposta deve ser 0 no modo ASCII"
#define MSG_REST_ASCII_WORKAROUND "Reiniciando em %lld. Porém estamos no modo ASCII"
#define MSG_REST_SUCCESS "Reiniciando em %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Nome de diretório proibido"
#define MSG_SANITY_FILE_FAILURE "Nome de arquivo proibido: %s"
#define MSG_MKD_FAILURE "Não foi possível criar diretório"
#define MSG_MKD_SUCCESS "O diretório foi criado com sucesso"
#define MSG_RMD_FAILURE "Não foi possível remover diretório"
#define MSG_RMD_SUCCESS "O diretório foi removido com sucesso"
#define MSG_TIMESTAMP_FAILURE "Não foi possível obter uma marca de tempo"
#define MSG_MODE_ERROR "Somente modos ASCII e binário são suportados"
#define MSG_CREATE_FAILURE "Não foi possível criar arquivo"
#define MSG_ABRT_ONLY "ABRT é o único comando válido durante transmissão"
#define MSG_UPLOAD_PARTIAL "parcialmente enviado"
#define MSG_REMOVED "removido"
#define MSG_UPLOADED "enviado"
#define MSG_GMTIME_FAILURE "Não foi possível obter a hora local"
#define MSG_TYPE_8BIT_FAILURE "Somente bytes de 8 bits são suportados. Não estamos há 10 anos atrás"
#define MSG_TYPE_UNKNOWN "TYPE desconhecido"
#define MSG_TYPE_SUCCESS "TYPE agora é"
#define MSG_STRU_FAILURE "Somente File (arquivo) é suportado"
#define MSG_MODE_FAILURE "Utilize modo Stream (fluxo)"
#define MSG_RENAME_ABORT "Cancelando comando de renomeação anterior"
#define MSG_RENAME_RNFR_SUCCESS "RNFR aceito - arquivo existe, pronto para destino"
#define MSG_FILE_DOESNT_EXIST "Desculpe, esse arquivo não existe"
#define MSG_RENAME_ALREADY_THERE "RENAME falhou - arquivo de destino já existe"
#define MSG_RENAME_NORNFR "É necessário RNFR antes de RNTO"
#define MSG_RENAME_FAILURE "Falha em renomear/mover"
#define MSG_RENAME_SUCCESS "Arquivo renomeado ou movido com sucesso"
#define MSG_NO_SUPERSERVER "Por favor execute pure-ftpd dentro de um super-servidor (como tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Não foi possível encontrar a conta 'ftp'"
#define MSG_CONF_ERR "Erro de configuração"
#define MSG_NO_VIRTUAL_FILE "Está faltando arquivo de usuários virtuais"
#define MSG_ILLEGAL_THROTTLING "Valor ilegal para limite de transferência"
#define MSG_ILLEGAL_TRUSTED_GID "GID de confiança para chroot ilegal"
#define MSG_ILLEGAL_USER_LIMIT "Limite de usuário ilegal"
#define MSG_ILLEGAL_FACILITY "Nome de facilidade desconhecido"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Arquivo de configuração de LDAP inválido"
#define MSG_ILLEGAL_LOAD_LIMIT "Limite de carga ilegal"
#define MSG_ILLEGAL_PORTS_RANGE "Faixa de portas ilegal"
#define MSG_ILLEGAL_LS_LIMITS "Limite de 'ls' ilegal"
#define MSG_ILLEGAL_FORCE_PASSIVE "IP forçado para conexões passivas ilegal"
#define MSG_ILLEGAL_RATIO "Proporção de envio/recebimento ilegal"
#define MSG_ILLEGAL_UID_LIMIT "Limite de uid ilegal"
#define MSG_ILLEGAL_OPTION "Opção de execução desconhecida"
#define MSG_LDAP_MISSING_BASE "Está faltando LDAPBaseDN no arquivo de configuração LDAP"
#define MSG_LDAP_WRONG_PARMS "Parâmetros LDAP incorretos"
#define MSG_NEW_CONNECTION "Nova conexão a partir de %s"
#define MSG_WELCOME_TO "Bem-vindo a"
#define MSG_MAX_USERS "%lu usuários (o máximo) já estão conectados, desculpe"
#define MSG_NB_USERS "Você é o usuário número %u de %u permitidos"
#define MSG_WELCOME_TIME "Hora local agora é %02d:%02d. Porta do servidor: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Somente FTP anônimo é permitido aqui"
#define MSG_RATIOS_EVERYONE "PROPORÇÕES ESTÃO HABILITADAS PARA TODOS :"
#define MSG_RATIOS_ANONYMOUS "USUÁRIOS ANÔNIMOS ESTÃO SUJEITOS A UMA PROPORÇÃO DE UL/DL :"
#define MSG_RATIOS_RULE "para receber %u Mb, é obrigatório enviar %u Mb de arquivos."
#define MSG_INFO_IDLE_M "Você será desconectado após %lu minutos de inatividade."
#define MSG_INFO_IDLE_S "Você será desconectado após %lu segundos de inatividade."
#define MSG_CANT_READ_FILE "Desculpe, não foi possível ler [%s]"
#define MSG_LS_TRUNCATED "Resultado truncado em %u ocorrências"
#define MSG_LS_SUCCESS "%u ocorrências no total"
#define MSG_LOGOUT "Fim de sessão."
#define MSG_AUTH_FAILED_LOG "Autenticação falhou para usuário [%s]"
#define MSG_ILLEGAL_UMASK "Umask inválida"
#define MSG_STANDALONE_FAILED "Não foi possível iniciar um servidor independente"
#define MSG_NO_ANONYMOUS_LOGIN "Este é um sistema privado - Não é permitido usuário anônimo"
#define MSG_ANONYMOUS_ANY_PASSWORD "Qualquer senha funcionará"
#define MSG_MAX_USERS_IP "Conexões demais (%lu) a partir deste IP"
#define MSG_ACTIVE_DISABLED "Modo ativo está desabilitado"
#define MSG_TRANSFER_SUCCESSFUL "Arquivo transferido com sucesso"
#define MSG_NO_DISK_SPACE "Disco cheio - por favor envie arquivo mais tarde"
#define MSG_OUT_OF_MEMORY "Sem memória"
#define MSG_ILLEGAL_TRUSTED_IP "Endereço IP de confiança ilegal"
#define MSG_NO_ASCII_RESUME "Reiniciar em modo ASCII é inseguro, por favor remova o arquivo antes"
#define MSG_UNKNOWN_ALTLOG "Formato de log desconhecido"
#define MSG_ACCOUNT_DISABLED "Não é possível conectar como [%s] : conta desabilitada"
#define MSG_SQL_WRONG_PARMS "Parâmetros SQL incorretos"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Arquivo de configuração SQL inválido"
#define MSG_SQL_MISSING_SERVER "Está faltando o servidor no arquivo de configuração SQL"
#define MSG_SQL_DOWN "O servidor SQL aparenta estar fora de operação"
#define MSG_ILLEGAL_QUOTA "Cota inválida"
#define MSG_QUOTA_FILES "%llu arquivos usados (%d%%) - autorizado: %llu arquivos"
#define MSG_QUOTA_SIZE "%llu Kbytes usados (%d%%) - autorizado: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Cota excedida : [%s] não será armazenado"
#define MSG_AUTH_UNKNOWN "Método de autenticação desconhecido"
#define MSG_PDB_BROKEN "Não foi possível ler o arquivo indexado do puredb (ou um formato antigo foi detectado) - Experimente pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s é um apelido para %s."
#define MSG_ALIASES_UNKNOWN "Apelido %s desconhecido."
#define MSG_ALIASES_BROKEN_FILE "Arquivo de apelidos danificado"
#define MSG_ALIASES_LIST "Os seguintes apelidos estão disponíveis :"
#define MSG_PERUSER_MAX "Não posso aceitar mais do que %lu conexões do mesmo usuário"
#define MSG_IPV6_OK "Conexões IPv6 também são bem-vindas neste servidor"
#define MSG_TLS_INFO "TLS: Habilitado %s com %s, criptografia de %d bits"
#define MSG_TLS_WEAK "TLS: Criptografia muito fraca"
#define MSG_TLS_NEEDED "Desculpe, sessões sem criptografia não são aceitas neste servidor.\n" \
    "Por favor reconecte-se usando mecanismos de segurança TLS."
#define MSG_ILLEGAL_CHARSET "Conjunto de caracteres ilegal"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
