#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Cas vyprsal"
#define MSG_CAPABILITIES "Nemozem zmenit privilegia"
#define MSG_CLIENT_CLOSED_CNX "Klient zavrel spojenie"
#define MSG_CLIENT_READ_ERR "Chyba pri citani od klienta"
#define MSG_CANT_OPEN_CNX "Nemozem vytvorit spojenie"
#define MSG_CANT_CREATE_DATA_SOCKET "Nemozem vytvorit datovy socket"
#define MSG_DEBUG_CLIENT_IS "Klientova adresa je"
#define MSG_SYNTAX_ERROR_IP "Syntakticka chyba v IP adrese"
#define MSG_PORT_SUCCESSFUL "Prikaz PORT uspesne vykonany"
#define MSG_ONLY_IPV4V6 "Iba IPv4 a IPv6 su podporovane (1,2)"
#define MSG_ONLY_IPV4 "Iba IPv4 je podporovany (1)"
#define MSG_TIMEOUT_PARSER "Cas vyprsal, nabuduce skuste pisat trosku rychlejsie"
#define MSG_LINE_TOO_LONG "Riadok je privelmi dlhy"
#define MSG_LOG_OVERFLOW "Klient sa pokusil preplnit buffer na prikazovy riadok"
#define MSG_GOODBYE "Dovidenia. Uploadli ste %llu a downloadli %llu kilobajtov."
#define MSG_DEBUG_COMMAND "Prikaz"
#define MSG_IS_YOUR_CURRENT_LOCATION "je vasa terajsia location"
#define MSG_NOT_LOGGED_IN "Nieste prihlaseny"
#define MSG_AUTH_UNIMPLEMENTED "Bezpecnostne rozsirenia niesu implementovane"
#define MSG_NO_FILE_NAME "Ziadne meno suboru"
#define MSG_NO_DIRECTORY_NAME "Ziadne meno adresara"
#define MSG_NO_RESTART_POINT "Ziaden zaciatok restartu"
#define MSG_ABOR_SUCCESS "Prikaz ABOR bol uspesny"
#define MSG_MISSING_ARG "Chybajuci argument"
#define MSG_GARBAGE_FOUND "Smetie najdene po hodnote"
#define MSG_VALUE_TOO_LARGE "Hodnota prilis vysoka"
#define MSG_IDLE_TIME "Cas necinnosti nastaveny na %lu sekund"
#define MSG_SITE_HELP "Nasledovne prikazy SITE su rozoznane"
#define MSG_BAD_CHMOD "Chybne pristupove prava"
#define MSG_UNKNOWN_EXTENSION "je nezname rozsirenie"
#define MSG_XDBG_OK "Prikaz XDBG bol uspesny, debug uroven je teraz %d"
#define MSG_UNKNOWN_COMMAND "Neznamy prikaz"
#define MSG_TIMEOUT_NOOP "Cas vyprsal (ziadna operacia za %lu sekund)"
#define MSG_TIMEOUT_DATA "Cas vyprsal (ziadne nove data za %lu sekund)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Uz ste prihlaseny"
#define MSG_ANY_PASSWORD "Lubovolne heslo bude fungovat"
#define MSG_ANONYMOUS_LOGGED "Prihlasny ako anonymny pouzivatel"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonymny pouzivatel sa prihlasil vo virtualnom FTP"
#define MSG_USER_OK "Pouzivatel %s je OK. Heslo je potrebne"
#define MSG_CANT_DO_TWICE "Nemozme to spravit pocas tohto sedenia"
#define MSG_UNABLE_SECURE_ANON "Nemozem nastavit bezpecne anonymne FTP"
#define MSG_BANDWIDTH_RESTRICTED "Vasa prenosova rychlost je obmedzena"
#define MSG_NO_PASSWORD_NEEDED MSG_ANY_PASSWORD
#define MSG_NOTRUST "Lutujem, ale nemozem vam doverovat"
#define MSG_WHOAREYOU "Prosim povedzte mi, kto ste"
#define MSG_AUTH_FAILED "Lutujem, ale autentifikacia zlyhala"
#define MSG_AUTH_TOOMANY "Privela zlyhani autentifikacie"
#define MSG_NO_HOMEDIR "Domovsky adresar nieje pristupny - rusim"
#define MSG_NO_HOMEDIR2 "%s neexistuje alebo je nedosiahnutelny"
#define MSG_START_SLASH "Zacinam v /"
#define MSG_USER_GROUP_ACCESS "Pouzivatel %s ma skupinovy pristup do"
#define MSG_FXP_SUPPORT "Tento server podporuje FXP prenosy"
#define MSG_RATIO "Musite dodriavat %u:%u (UL/DL) pomer"
#define MSG_CHROOT_FAILED "Nemozem vytvorit bezpecny chroot()"
#define MSG_CURRENT_DIR_IS "OK. Aktualny adresar je %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Aktualny obmedzeny adresar je %s"
#define MSG_IS_NOW_LOGGED_IN "%s je prave prihlaseny"
#define MSG_CANT_CHANGE_DIR "Nemozem prejst do adresara %s"
#define MSG_PATH_TOO_LONG "Cesta je prilis dlha"
#define MSG_CANT_PASV "Nemozte pouzivat PASV na IPv4 presosoch. Pouzite EPSV."
#define MSG_CANT_PASSIVE "Nemozem vytvorit pasivne spojenie"
#define MSG_PORTS_BUSY "Vsetky rezervovane TCP porty su pouzivane"
#define MSG_GETSOCKNAME_DATA "Nemozem identifikovat lokalny datovy socket"
#define MSG_GETPEERNAME "Nemozzem identifikovat lokalny socket"
#define MSG_INVALID_IP "Lutujem, zadali ste chybnu adresu"
#define MSG_NO_EPSV "Prosi pouzivajte klient kompatiblny s IPv6 s podporou EPSV"
#define MSG_BAD_PORT "Lutujem, ale nepripojim sa na port nizsi ako 1024"
#define MSG_NO_FXP "Neotvorim spojenie na %s (len po %s)"
#define MSG_FXP "FXP prenos : z %s na %s"
#define MSG_NO_DATA_CONN "Ziadne datove spojenie"
#define MSG_ACCEPT_FAILED "Spojenie nemohlo byt akceptovane"
#define MSG_ACCEPT_SUCCESS "Datove spojenie prijate"
#define MSG_CNX_PORT_FAILED "Nemozem vytvorit datove spojenie na port %d"
#define MSG_CNX_PORT "Pripajam sa na port %d"
#define MSG_ANON_CANT_MKD "Lutujem, ale anonymni pouzivatelia nemozu vytvarat adresare"
#define MSG_ANON_CANT_RMD "Lutujem, ale anonymni pouzivatelia nemozu mazat adresare"
#define MSG_ANON_CANT_RENAME "Anonymni pouzivatelia nemozu presuvat/premenuvavat subory"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymni pouzivatelia nemozu menit pristupove prava"
#define MSG_GLOB_NO_MEMORY "Pocas globbingu %s dosla pamat"
#define MSG_PROBABLY_DENIED "(Toto pravdepodobne znamena \"Odmietnuty pristup\")"
#define MSG_GLOB_READ_ERROR "Chyba citania pri globbovani %s"
#define MSG_GLOB_NO_MATCH "Zaidna zhoda medzi %s v %s"
#define MSG_CHMOD_FAILED "Nemozem zmenit pristupove prava na %s"
#define MSG_CHMOD_SUCCESS "Pristupove prava zmene na %s"
#define MSG_CHMOD_TOTAL_FAILURE "Lutujem, ale nemohol som zmenit ziadne pristupove prava"
#define MSG_ANON_CANT_DELETE "Anonymni pouzivatelia nemozu mazat subory"
#define MSG_ANON_CANT_OVERWRITE "Anonymni pouzivatelia nemozu prepisovat existujuce subory"
#define MSG_DELE_FAILED "Nemozem zmazat %s"
#define MSG_DELE_SUCCESS "Subor %s%s%s%s zmazany"
#define MSG_DELE_TOTAL_FAILURE "Ziadny subor nebol zmazany"
#define MSG_LOAD_TOO_HIGH \
     "Zataz systemu bola%3.2f ked ste sa prihlasili. Nedovolujeme dowloady\n" \
     "anonymnym pouzivatelom pri tak vysokej zatazi. Uploady su vzdy povolene\n"

#define MSG_OPEN_FAILURE "Nemozem otvorit %s"
#define MSG_OPEN_FAILURE2 "Nemozem otvorit ten subor"
#define MSG_STAT_FAILURE "Nemozem zistit velkost suboru"
#define MSG_STAT_FAILURE2 "Nemozem overit existenciu suboru"
#define MSG_REST_TOO_LARGE_FOR_FILE "Zaciatok restartu %lld je prilis velky pre subor dlhy len %lld."
#define MSG_REST_RESET "Zaciatok restartu nastaveny na 0"
#define MSG_NOT_REGULAR_FILE "Mozem poskytovat len normalne subory"
#define MSG_NOT_MODERATED \
     "Tento subor bol uploadnuty anonymnym pouzivatelo. Este nebol" \
     "schvaleny na download admistratormi servera."
#define MSG_RATIO_DENIAL \
     "Lutujen, ale pomer upload/download je %u:%u .\n" \
     "Zatial ste uploadli %llu kilobajtov  downloadli %llu kilobajtov.\n" \
     "Nieco pekne nam sem uploadnite a potom si nieco skvele mozete stiahnut."
#define MSG_NO_MORE_TO_DOWNLOAD "Na download tu uz nic nieje"
#define MSG_WINNER "Pocitac je tvoj priatel. Doveruj pocitacu"
#define MSG_KBYTES_LEFT "%.1f kilobajtov na download"
#define MSG_ABORTED "Prenos preruseny"
#define MSG_DATA_WRITE_FAILED "Chyba pocas zapisu do datoveho spojenia"
#define MSG_DATA_READ_FAILED "Chyba pocas citania z datove spojenia"
#define MSG_MMAP_FAILED "Nemozem namapovat subor do pamate"
#define MSG_WRITE_FAILED "Chyba pocas zapisu do suboru"
#define MSG_TRANSFER_RATE_M "%.3f sekund (merane tu), %.2f megabajtov za sekundu"
#define MSG_TRANSFER_RATE_K "%.3f sekund (merane tu), %.2f kilobajtov za sekundu"
#define MSG_TRANSFER_RATE_B "%.3f sekund (merane tu), %.2f bajtov za sekundu"
#define MSG_SPACE_FREE_M "%.1f megabajtov volneho diskoveho priestoru"
#define MSG_SPACE_FREE_K "%f kilobjatov volneho diskoveho priestoru"
#define MSG_DOWNLOADED "downloadnuty"
#define MSG_REST_NOT_NUMERIC "REST vyzaduje ciselny parameter"
#define MSG_REST_ASCII_STRICT "Oznacenie odpovede musi byt 0 v ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "Pokracujem od %lld. Ale sme ASCII mode"
#define MSG_REST_SUCCESS "Pokracujem od %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Zakazany nazov adresaru"
#define MSG_SANITY_FILE_FAILURE "Zakazany nazov suboru: %s"
#define MSG_MKD_FAILURE "Nemozem vytvorit adresar"
#define MSG_MKD_SUCCESS "Adresar bol uspesne vytvoreny"
#define MSG_RMD_FAILURE "Nemozem zmazat adresar"
#define MSG_RMD_SUCCESS "Adresar bol uspesne vytvoreny"
#define MSG_TIMESTAMP_FAILURE "Nemozem ziskat casovu znacku"
#define MSG_MODE_ERROR "Len ASCII a binarny mod su podporovane"
#define MSG_CREATE_FAILURE "Nemozem vytvorit subor"
#define MSG_ABRT_ONLY "Prikaz ABRT je mozne pouzit len pocas uploadu."
#define MSG_UPLOAD_PARTIAL "ciastocne uploadnuty"
#define MSG_REMOVED "odstraneny"
#define MSG_UPLOADED "uploadnuty"
#define MSG_GMTIME_FAILURE "Nemozem zistit lokalny cas"
#define MSG_TYPE_8BIT_FAILURE "Podporujem len 8 bitove bajty, niesme spred desiatich rokov"
#define MSG_TYPE_UNKNOWN "Neznamy TYPE"
#define MSG_TYPE_SUCCESS "TYPE je teraz"
#define MSG_STRU_FAILURE "Iba F(ile) je podporovany"
#define MSG_MODE_FAILURE "Prosim pouzite S(tream) mod"
#define MSG_RENAME_ABORT "Prerusujem predchadzajuce premenovanie"
#define MSG_RENAME_RNFR_SUCCESS "Prikaz RNFR akceptovany, subor existuje, ocakavam ciel"
#define MSG_FILE_DOESNT_EXIST "Lutujem, ale zadany subor neexistuje"
#define MSG_RENAME_ALREADY_THERE "Prikaz RENAME zlyhal - cielovy subor uz existuje"
#define MSG_RENAME_NORNFR "Potrebujem RNFR pred RNTO"
#define MSG_RENAME_FAILURE "Chyba premenovania/presunu"
#define MSG_RENAME_SUCCESS "Subor uspnesne presunuty/premenovany"
#define MSG_NO_SUPERSERVER "Prosim spustajte pure-ftpd zo super-servera (napriklad tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nemozem najst konto 'ftp'"
#define MSG_CONF_ERR "Chyba konfiguracie"
#define MSG_NO_VIRTUAL_FILE "Chybajuci subor virtualnych pouzivatelov"
#define MSG_ILLEGAL_THROTTLING "Chybna hodnota obmedzovania rychlosti prenosu"
#define MSG_ILLEGAL_TRUSTED_GID "Chybna doverovana gid pre chroot"
#define MSG_ILLEGAL_USER_LIMIT "Chybny limit pouzivatelov"
#define MSG_ILLEGAL_FACILITY "Nezname meno sluzby"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Chybny konfiguracny subor LDAPu"
#define MSG_ILLEGAL_LOAD_LIMIT "Chyny limit na systemu zataz"
#define MSG_ILLEGAL_PORTS_RANGE "Chybny rozsah portov"
#define MSG_ILLEGAL_LS_LIMITS "Chybny limit na 'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "Chybna vnutena IP pre pasivne prenosy"
#define MSG_ILLEGAL_RATIO "Chybny pomer upload/download "
#define MSG_ILLEGAL_UID_LIMIT "Chybny limit na uid"
#define MSG_ILLEGAL_OPTION "Neznama run-time volba"
#define MSG_LDAP_MISSING_BASE "Chybajuci LDAPBaseDN v konfiguracnom subore LDAPu"
#define MSG_LDAP_WRONG_PARMS "Chybne LDAP parametre"
#define MSG_NEW_CONNECTION "Nove spojenie z %s"
#define MSG_WELCOME_TO "Vitajte na"
#define MSG_MAX_USERS "Lutujem, ale %lu (maximum) pouzivatelov je uz prihlasenych"
#define MSG_NB_USERS "Ste pouzivatel cislo %u z %u povolenych"
#define MSG_WELCOME_TIME "Lokalny cas je teraz %02d:%02d. Serverovy port: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Tu je povoleny len anonymny pristup"
#define MSG_RATIOS_EVERYONE "VSETCI POUZIVATELIA MUSIA DODRZAT POMER UL/DL :"
#define MSG_RATIOS_ANONYMOUS "ANONYMNI POUZIVATELIA MUSIA DODRZAT POMER UL/DL :"
#define MSG_RATIOS_RULE "na download %u megabajtov musite uploadnut %u Mb."
#define MSG_INFO_IDLE_M "Budete odpojeny po %lu minutach neaktivity."
#define MSG_INFO_IDLE_S "Budete odpojeny po %lu sekundach neaktivity."
#define MSG_CANT_READ_FILE "Lutujem, nebol som schopny precitat [%s]"
#define MSG_LS_TRUNCATED "Vystup skrateny na %u zhod"
#define MSG_LS_SUCCESS "Spolu %u zhod"
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Autentifikacia uzivatela zlyhala [%s]"
#define MSG_ILLEGAL_UMASK "Neplatna maska"
#define MSG_STANDALONE_FAILED "Nemozem spustit samostatny server"
#define MSG_NO_ANONYMOUS_LOGIN "Toto je privatny system - Anonymni uzivatelia su zakazani"
#define MSG_ANONYMOUS_ANY_PASSWORD "Mozte zadat lubovolne heslo"
#define MSG_MAX_USERS_IP "Privela aktivnych spojeni (%lu) z vasej IP"
#define MSG_ACTIVE_DISABLED "Aktivny mod je vypnuty"
#define MSG_TRANSFER_SUCCESSFUL "Subor bol uspesne preneseny"
#define MSG_NO_DISK_SPACE "Disk je plny, skuste neskor"
#define MSG_OUT_OF_MEMORY "Nedostatok pamate"
#define MSG_ILLEGAL_TRUSTED_IP "Neplatna doverovana IP adresa"
#define MSG_NO_ASCII_RESUME "Pokracovanie prenosu v ASCII mode nieje bezpecne, subor najskor zmate, prosim"
#define MSG_UNKNOWN_ALTLOG "Neznamy logovaci format"
#define MSG_ACCOUNT_DISABLED "Nemozte sa prihlasit ako [%s] : konto je deaktivovane"
#define MSG_SQL_WRONG_PARMS "Chybne SQL parametre"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Chybny konfiguracny subor SQL"
#define MSG_SQL_MISSING_SERVER "V konfiguracnom subore chyba SQL server"
#define MSG_SQL_DOWN "SQL server vyzera byt spadnuty"
#define MSG_ILLEGAL_QUOTA "Chybna kvota"
#define MSG_QUOTA_FILES "%llu suborov pouzitych (%d%%) - autorizovanych: %llu suborov"
#define MSG_QUOTA_SIZE "%llu kilobajtov pouzitych (%d%%) - autorizovanych: %llu kilobajtov"
#define MSG_QUOTA_EXCEEDED "Kvota prekrocena : [%s] nebude ulozeny"
#define MSG_AUTH_UNKNOWN "Neznama autentifikacna metoda"
#define MSG_PDB_BROKEN "Nebolo mozne precitat indexovany subor puredb (alebo bola detekovana stara verzia) - Vyskusajte spustit pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s je aliasom pre %s."
#define MSG_ALIASES_UNKNOWN "Neznamy alias %s."
#define MSG_ALIASES_BROKEN_FILE "Poskodeny subor aliasov"
#define MSG_ALIASES_LIST "Nasledovne aliasy su dostupne :"
#define MSG_PERUSER_MAX "Nemozem akceptovat viac ako %lu pripojeni od toho isteho pouzivatela"
#define MSG_IPV6_OK "Pripojenia pomocou IPv6 su tiez vitane na tomto serveri"
#define MSG_TLS_INFO "TLS: Zapnute %s pouziva sifru %s, %d tajnych bitov"
#define MSG_TLS_WEAK "TLS: Sifra je prilis slaba"
#define MSG_TLS_NEEDED "Prepacte, ale nesifrovane spojenia nie su povolene na tomto serveri.\n" \
    "Pri najblizsom spojeni pouzite zabezpecovacie mechanizmy TLS."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
