#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Zaman Aşımı"
#define MSG_CAPABILITIES "Anahtar destekleri yapılamıyor"
#define MSG_CLIENT_CLOSED_CNX "Kullanıcı bağlantıyı kapattı"
#define MSG_CLIENT_READ_ERR "Kullanıcıdan okuma hatası"
#define MSG_CANT_OPEN_CNX "Bağlantı açılamıyor"
#define MSG_CANT_CREATE_DATA_SOCKET "Data kapısı oluşturulamadı"
#define MSG_DEBUG_CLIENT_IS "Kullanıcı IP adresi"
#define MSG_SYNTAX_ERROR_IP "IP adresinde sıralama hatası"
#define MSG_PORT_SUCCESSFUL "PORT komutu gerçekleşti"
#define MSG_ONLY_IPV4V6 "Sadece IPv4 ve IPv6 desteklenmektedir (1,2)"
#define MSG_ONLY_IPV4 "Sadece IPv4 desteklenmektedir (1)"
#define MSG_TIMEOUT_PARSER "Zaman Aşımı - bi sonraki sefere daha hızlı yazıp deneyiniz"
#define MSG_LINE_TOO_LONG "Satır çok uzun"
#define MSG_LOG_OVERFLOW "Kullanıcı güvenli komut satırı taşmasına sebep oldu"
#define MSG_GOODBYE "Hoşçakalın. Güncellemeleriniz %llu ve indirdikleriniz %llu kbytes."
#define MSG_DEBUG_COMMAND "Komut"
#define MSG_IS_YOUR_CURRENT_LOCATION "şuanki yeriniz"
#define MSG_NOT_LOGGED_IN "Giriş yapamadınız"
#define MSG_AUTH_UNIMPLEMENTED "Güvenlik eklentileri tamamlanamadı"
#define MSG_NO_FILE_NAME "Dosya adı yok"
#define MSG_NO_DIRECTORY_NAME "Klasör adı yok"
#define MSG_NO_RESTART_POINT "Yeniden başlatma noktası yok"
#define MSG_ABOR_SUCCESS "ABOR dan önce gördükleriniz başarı ile tamamlandı"
#define MSG_MISSING_ARG "Eksik girdi"
#define MSG_GARBAGE_FOUND "Değerden sonra gereksizlik bulundu"
#define MSG_VALUE_TOO_LARGE "Değer çok uzun"
#define MSG_IDLE_TIME "Haraketsiz bekleme süresi %lu saniye"
#define MSG_SITE_HELP "Belirtilen SITE komutu onaylandı"
#define MSG_BAD_CHMOD "Yanlış erişim"
#define MSG_UNKNOWN_EXTENSION "bilinmeyen uzantı"
#define MSG_XDBG_OK "XDBG komutu başarılı, yeni debug düzeyi %d"
#define MSG_UNKNOWN_COMMAND "Bilinmeyen komut"
#define MSG_TIMEOUT_NOOP "Zaman Aşımı (%lu saniyedir hareket olmadı)"
#define MSG_TIMEOUT_DATA "Zaman Aşımı (%lu saniyedir yeni data yok)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Zaten giriş yaptınız"
#define MSG_ANY_PASSWORD "Şifre yok"
#define MSG_ANONYMOUS_LOGGED "Misafir kullanıcı giriş yaptı"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Sanal FTP olarak misafir kullanıcı giriş yaptı"
#define MSG_USER_OK "Kullanıcı %s OK. Şifreyi giriniz"
#define MSG_CANT_DO_TWICE "Bu oturumda yapılamıyor"
#define MSG_UNABLE_SECURE_ANON "Güvenli Misafir FTP ayarlanmadı"
#define MSG_BANDWIDTH_RESTRICTED "Trafik kullanımınız sınırlı"
#define MSG_NO_PASSWORD_NEEDED "Şifre yok"
#define MSG_NOTRUST "Üzgünüz, güven sağlayamadınız"
#define MSG_WHOAREYOU "Lütfen kim olduğunuzu soyleyiniz."
#define MSG_AUTH_FAILED "Yetkiniz hatalı, üzgünüz"
#define MSG_AUTH_TOOMANY "Çok fazla yetki isteği hatası"
#define MSG_NO_HOMEDIR "Ana klasörünüz bulunamadı - çıkılıyor"
#define MSG_NO_HOMEDIR2 "%s bulunamadı veya okunamıyor"
#define MSG_START_SLASH "Başlangıç /"
#define MSG_USER_GROUP_ACCESS "Kullanıcı %s grup erişim sağladı"
#define MSG_FXP_SUPPORT "Bu sunucu FXP transferini desteklemektedir"
#define MSG_RATIO "Bakım oranı %u:%u (GÜN/İND)"
#define MSG_CHROOT_FAILED "Güvenli chroot() ayarlanamadı"
#define MSG_CURRENT_DIR_IS "OK. Şuanki klasör %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Şuanki sınırlı klasör %s"
#define MSG_IS_NOW_LOGGED_IN "%s giriş yaptı"
#define MSG_CANT_CHANGE_DIR "Klasör değiştirilemedi %s"
#define MSG_PATH_TOO_LONG "Yol çok uzun"
#define MSG_CANT_PASV "PASV komutunu IPv6 bağlantısında kullanamazsınız.Yerine EPSV kullanınız."
#define MSG_CANT_PASSIVE "Pasif bağlantı açılamıyor"
#define MSG_PORTS_BUSY "Tüm ayrılmış TCP kapıları meşgul"
#define MSG_GETSOCKNAME_DATA "Lokal data girişi tanınamadı"
#define MSG_GETPEERNAME "Lokal giriş tanınamadı"
#define MSG_INVALID_IP "Üzgünüz, yanlış adres belirlenmiş"
#define MSG_NO_EPSV "Lütfen EPSV destekli bir IPv6-conformant kullanıcı kullanınız"
#define MSG_BAD_PORT "Üzgünüz, 1024 den küçük portlarla bağalanamayız "
#define MSG_NO_FXP "%s bağlantısı açılamıyor(sadece %s)"
#define MSG_FXP "FXP transfer: %s den %s 'ye"
#define MSG_NO_DATA_CONN "Data bağlantısı yok"
#define MSG_ACCEPT_FAILED "Bağlantı kabul edilmedi"
#define MSG_ACCEPT_SUCCESS "Data bağlantı kabul edildi"
#define MSG_CNX_PORT_FAILED "%d kapısından data bağlantısı açılamıyor"
#define MSG_CNX_PORT "%d bağlantısından bağlanıyor"
#define MSG_ANON_CANT_MKD "Üzgünüz, misafir kullanıcısının klasör oluşturma yetkisi yok"
#define MSG_ANON_CANT_RMD "Üzgünüz, misafir kullanıcısının klasör silme yetkisi yok"
#define MSG_ANON_CANT_RENAME "Misafir kullanıcısının dosya taşıma/isim değiştirme yetkisi yok"
#define MSG_ANON_CANT_CHANGE_PERMS "Misafir kullanıcısının izinleri değiştirme yetkisi yok"
#define MSG_GLOB_NO_MEMORY "%s esnasında bellek taşması oluştu"
#define MSG_PROBABLY_DENIED "(Bu yöntem muhtelemen \"İzin engellendi\")"
#define MSG_GLOB_READ_ERROR "%s esnasında  okuma hatası"
#define MSG_GLOB_NO_MATCH "%s içinde %s bulunamadı"
#define MSG_CHMOD_FAILED "%s için izinler değiştirilemedi"
#define MSG_CHMOD_SUCCESS "%s için izinler değiştirildi"
#define MSG_CHMOD_TOTAL_FAILURE "Üzgünüz, izinler değiştirilemedi"
#define MSG_ANON_CANT_DELETE "Misafir kullanıcı dosyaları silimez"
#define MSG_ANON_CANT_OVERWRITE "Misafir kullanıcı varolan dosya üzerine yazamaz"
#define MSG_DELE_FAILED "%s silinemiyor"
#define MSG_DELE_SUCCESS "%s%s%s%s silindi"
#define MSG_DELE_TOTAL_FAILURE "Silinen dosya yok"
#define MSG_LOAD_TOO_HIGH \
    "Bağlantınızdan sonra yük %3.2f . Aşırı yüklenme esnasında misafir İndirmelere izin veremiyoruz.\n" \
    "Bu durmda sadece gönderim izinlidir.\n"

#define MSG_OPEN_FAILURE "%s açılmadı"
#define MSG_OPEN_FAILURE2 "Dosya açılamadı"
#define MSG_STAT_FAILURE "Dosya boyutu bulunamadı"
#define MSG_STAT_FAILURE2 "Dosya oluşturma kontrol edilemedi"
#define MSG_REST_TOO_LARGE_FOR_FILE "%lld için yeniden başlayın %lld den dosya büyüklülüğü çok büyük ."
#define MSG_REST_RESET "Yeniden başlayın yenileme 0"
#define MSG_NOT_REGULAR_FILE "Sadece düzgün dosyalar geri alabiliriz"
#define MSG_NOT_MODERATED \
    "Bu dosya misafir kullanıcı tarafından yüklendi. Sistem Yöneticisi\n" \
    "bunun inidirilmesi için henüz onay vermedi"
#define MSG_RATIO_DENIAL \
    "Üzgünüz, gönderme/indirme oranı %u:%u .\n" \
    "Şuanki göndermeniz %llu Kb ve indirmeniz %llu Kb.\n" \
    "Lütfen daha sonra tekrar deneyiniz."
#define MSG_NO_MORE_TO_DOWNLOAD "İndirme kalmadı"
#define MSG_WINNER "Bilgisayar arkadaşınız. Bilgisayara güvenin."
#define MSG_KBYTES_LEFT "%.1f kbytes indirme"
#define MSG_ABORTED "Transferden vazgeçildi"
#define MSG_DATA_WRITE_FAILED "Data bağlantısında yazma sırasında hata"
#define MSG_DATA_READ_FAILED "Data bağlantısında okuma sırasında hata"
#define MSG_MMAP_FAILED "Dosyadanın hafızadaki yeri açılamadı"
#define MSG_WRITE_FAILED "Dosyaya yazma sırasında hata"
#define MSG_TRANSFER_RATE_M "%.3f saniye (burdaki ölçü), saniyede %.2f Mbytes "
#define MSG_TRANSFER_RATE_K "%.3f saniye (burdaki ölçü), saniyede %.2f Kbytes "
#define MSG_TRANSFER_RATE_B "%.3f saniye (burdaki ölçü), saniyede %.2f bytes "
#define MSG_SPACE_FREE_M "Boş disk alanı %.1f Mbytes "
#define MSG_SPACE_FREE_K "Boş disk alanı %f Kbytes "
#define MSG_DOWNLOADED "indirildi"
#define MSG_REST_NOT_NUMERIC "REST de rakamsal paremetre gerekli"
#define MSG_REST_ASCII_STRICT "İşareti ASCII modda 0 ile cevaplayınız "
#define MSG_REST_ASCII_WORKAROUND "%lld Yeniden başlatılıyor. ASCII mod içinde"
#define MSG_REST_SUCCESS "%lld yeniden başlatılıyor"
#define MSG_SANITY_DIRECTORY_FAILURE "Yasak klasör adı"
#define MSG_SANITY_FILE_FAILURE "Yasak dosya adı: %s"
#define MSG_MKD_FAILURE "Klasör oluşturalamadı"
#define MSG_MKD_SUCCESS "Klasör başarıyla oluşturuldu"
#define MSG_RMD_FAILURE "Klasör kaldırılamadı"
#define MSG_RMD_SUCCESS "Klasör başarıyla kaldırıldı"
#define MSG_TIMESTAMP_FAILURE "Zaman biçimi alınamadı"
#define MSG_MODE_ERROR "Sadece ASCII ve binary mod desteklenmektedir"
#define MSG_CREATE_FAILURE "Dosya oluşturulamadı"
#define MSG_ABRT_ONLY "ABRT sadece güncelleme süresinde kullanılır"
#define MSG_UPLOAD_PARTIAL "kısmen güncelendi"
#define MSG_REMOVED "kaldırıldı"
#define MSG_UPLOADED "güncellendi"
#define MSG_GMTIME_FAILURE "Lokal zaman alınamadı"
#define MSG_TYPE_8BIT_FAILURE "Sadece 8-bit bytelar desteklenir, 10 yaşında değilim ki."
#define MSG_TYPE_UNKNOWN "Bilinmeyen TYPE"
#define MSG_TYPE_SUCCESS "TYPE şuan"
#define MSG_STRU_FAILURE "Sadece D(osya) desteklenmektedir"
#define MSG_MODE_FAILURE "Lütfen S(tream) mod kullanın"
#define MSG_RENAME_ABORT "Önceki isim değiştirmeden vazgeçiliyor"
#define MSG_RENAME_RNFR_SUCCESS "RNFR kabul edildi - belirtilen yerde dosya var, "
#define MSG_FILE_DOESNT_EXIST "Üzgünüz, dosya bulunamadı"
#define MSG_RENAME_ALREADY_THERE "RENAME Hatalı - belirtilen dosya adı zaten var"
#define MSG_RENAME_NORNFR "RNTO önce RNFR gerekli"
#define MSG_RENAME_FAILURE "İsim Değiştirme/Taşıma hatalı"
#define MSG_RENAME_SUCCESS "Dosya ismi değiştirme/taşıma başarılı"
#define MSG_NO_SUPERSERVER "Lütfen pure-ftpd yi super-server ile çalıştırınız (tcpserver gerekli)"
#define MSG_NO_FTP_ACCOUNT "'ftp' hesabı bulunamadı"
#define MSG_CONF_ERR "Konfigürasyon hatası"
#define MSG_NO_VIRTUAL_FILE "Sanal kullanıcı dosyası eksik"
#define MSG_ILLEGAL_THROTTLING "Azaltma için geçersiz değer"
#define MSG_ILLEGAL_TRUSTED_GID "chroot için geçersiz gid"
#define MSG_ILLEGAL_USER_LIMIT "Geçersiz kullanıcı limiti"
#define MSG_ILLEGAL_FACILITY "Bilinmeyen olanak adı"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Bilinmeyen LDAP konfigürasyon dosyası"
#define MSG_ILLEGAL_LOAD_LIMIT "Geçersiz yükleme limiti"
#define MSG_ILLEGAL_PORTS_RANGE "Geçersiz kapı sırası"
#define MSG_ILLEGAL_LS_LIMITS "Geçersiz 'ls' limiti"
#define MSG_ILLEGAL_FORCE_PASSIVE "Pasif bağlantı için geçersiz zorunlu IP "
#define MSG_ILLEGAL_RATIO "Geçersiz güncelleme/indirme oranı"
#define MSG_ILLEGAL_UID_LIMIT "Geçersiz uid limiti"
#define MSG_ILLEGAL_OPTION "Bilinmeyen gerçek zamanlı seçim"
#define MSG_LDAP_MISSING_BASE "LDAP konfigürasyon dosyasında LDAPBaseDN eksik"
#define MSG_LDAP_WRONG_PARMS "Yanlış LDAP parametresi"
#define MSG_NEW_CONNECTION "%s den yeni bağlantı"
#define MSG_WELCOME_TO "Hoşgeldiniz"
#define MSG_MAX_USERS "%lu kullanıcı (maksimum) zaten giriş yaptı, üzgünüz"
#define MSG_NB_USERS "Kullanıcı numaranız %u den %u kabul edildi."
#define MSG_WELCOME_TIME "Lokal zaman şuan %02d:%02d. Sunucu kapısı: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Sadece Misafir FTP kabul edilir"
#define MSG_RATIOS_EVERYONE "HERKES İÇİN ORAN AÇIK:"
#define MSG_RATIOS_ANONYMOUS "MİSAFİR KULLANICIYA BAĞLI GUN/IND ORANI:"
#define MSG_RATIOS_RULE "indirme %u Mb, güncelleme %u Mb zorunlu."
#define MSG_INFO_IDLE_M "%lu dakikadan sonra hareket olmazsa bağlantı kapanır."
#define MSG_INFO_IDLE_S "%lu saniyeden sonra hareket olmazsa bağlantı kapanır."
#define MSG_CANT_READ_FILE "Üzgünüz, [%s] okunamadı"
#define MSG_LS_TRUNCATED "Çıktı kısaltması %u uygun"
#define MSG_LS_SUCCESS "Uygun toplamı %u"
#define MSG_LOGOUT "Çıkış."
#define MSG_AUTH_FAILED_LOG "[%s] kullanıcısı için giriş hatalı"
#define MSG_ILLEGAL_UMASK "Geçersiz umask"
#define MSG_STANDALONE_FAILED "Standalone sunucu başlatılamadı"
#define MSG_NO_ANONYMOUS_LOGIN "Bu özel sistem - Misafir girişi olamaz"
#define MSG_ANONYMOUS_ANY_PASSWORD "Şifre boş"
#define MSG_MAX_USERS_IP "Bu (%lu) IP den çok fazla bağlantı"
#define MSG_ACTIVE_DISABLED "Aktif mod kapalı"
#define MSG_TRANSFER_SUCCESSFUL "Dosya başarı ile transfer edildi"
#define MSG_NO_DISK_SPACE "Disk dolu - lütfen daha sonra güncelleyiniz"
#define MSG_OUT_OF_MEMORY "Hafıza Taşması"
#define MSG_ILLEGAL_TRUSTED_IP "Geçersiz IP adresi"
#define MSG_NO_ASCII_RESUME "ASCII yenilenmesi güvensiz, lütfen daha önce dosyayı siliniz"
#define MSG_UNKNOWN_ALTLOG "Bilinmeyen log biçimi"
#define MSG_ACCOUNT_DISABLED "[%s] girişine izin yok: hesap kapalı"
#define MSG_SQL_WRONG_PARMS "Yanlış SQL parametresi"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Yanlış SQL konfigürasyon dosyası"
#define MSG_SQL_MISSING_SERVER "SQL konfigürasyon dosyası içinde sunucu eksik"
#define MSG_SQL_DOWN "SQL sunucusu kapalı görünüyor"
#define MSG_ILLEGAL_QUOTA "Geçersiz kota"
#define MSG_QUOTA_FILES "%llu dosya kullanım (%d%%) - yetki: %llu dosya"
#define MSG_QUOTA_SIZE "%llu Kbytes kullanım (%d%%) - yetki: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Kota aşımı: [%s] kaydedilemedi"
#define MSG_AUTH_UNKNOWN "Bilinmeyen yetkilendirme metodu"
#define MSG_PDB_BROKEN "puredb dosyasından indexlenme okunamadı (veya eski biçim algılandı) - pure-pw mkdb yi deneyiniz"
#define MSG_ALIASES_ALIAS "%s takma adı %s ."
#define MSG_ALIASES_UNKNOWN "Bilinmeyen takmaad %s."
#define MSG_ALIASES_BROKEN_FILE "Hasarlı takma ad dosyası"
#define MSG_ALIASES_LIST "Belirtilen takma ad kullanılabilir :"
#define MSG_PERUSER_MAX "%lu den aynı kullanıcı kabul edemiyoruz"
#define MSG_IPV6_OK "IPv6 bağlantısı kabul edildi, Hoşgeldiniz."
#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
