#define MSG_TLS_CIPHER_FAILED "TLS: Keni specifikuar gabim TLSCipherSuite '%s'"
#define MSG_TIMEOUT "Jashte Kohe"
#define MSG_CAPABILITIES "Nuk mund te shkembehen aftesite"
#define MSG_CLIENT_CLOSED_CNX "Klienti e mbylli lidhjen"
#define MSG_CLIENT_READ_ERR "Gabim leximi nga klienti"
#define MSG_CANT_OPEN_CNX "Nuk mund te hapet lidhja"
#define MSG_CANT_CREATE_DATA_SOCKET "Nuk krijoj dot data socket"
#define MSG_DEBUG_CLIENT_IS "Adresa e klientit eshte"
#define MSG_SYNTAX_ERROR_IP "Gabim shkrimi ne adresen IP"
#define MSG_PORT_SUCCESSFUL "Komanda PORT doli me sukses"
#define MSG_ONLY_IPV4V6 "Vetem IPv4 dhe IPv6 jane te suportuara (1,2)"
#define MSG_ONLY_IPV4 "Vetem IPv4 eshte i suportuar(1)"
#define MSG_TIMEOUT_PARSER "Jashte Kohe - shkruaj me shpejt heres tjeter"
#define MSG_LINE_TOO_LONG "Vija eshte shume e gjate"
#define MSG_LOG_OVERFLOW "Klienti kerkoi te mbingarkoje buffer te vijes se komandes"
#define MSG_GOODBYE "Mirupafshim. Ju ngarkuat %llu dhe shkarkuar %llu kBytes."
#define MSG_DEBUG_COMMAND "Komand"
#define MSG_IS_YOUR_CURRENT_LOCATION "eshte vendodhja juaj aktuale"
#define MSG_NOT_LOGGED_IN "Ju nuk jeni i loguar"
#define MSG_AUTH_UNIMPLEMENTED "Kjo skeme sigurie nuk eshte e zhvilluar"
#define MSG_NO_FILE_NAME "Nuk ka emer file"
#define MSG_NO_DIRECTORY_NAME "Nuk ka emer direktorie"
#define MSG_NO_RESTART_POINT "Nuk ka pike rinisje"
#define MSG_ABOR_SUCCESS "Duke qene se shikoni kete ABOR ka dale me sukses"
#define MSG_MISSING_ARG "Mungon argumenti"
#define MSG_GARBAGE_FOUND "Mbeturina u gjenden pas vleres"
#define MSG_VALUE_TOO_LARGE "Vlera eshte shume e madhe"
#define MSG_IDLE_TIME "Koha boshe eshte %lu sekonda"
#define MSG_SITE_HELP "Komandat SITE ne vijim jane te njohura"
#define MSG_BAD_CHMOD "Te drejta te gabuara"
#define MSG_UNKNOWN_EXTENSION "eshte nje prapashtese e panjohur"
#define MSG_XDBG_OK "Komanda XDBG e suksesshme, niveli debug eshte %d"
#define MSG_UNKNOWN_COMMAND "Komande e panjohur"
#define MSG_TIMEOUT_NOOP "Jashte Kohe (pa veprime per for %lu sekonda)"
#define MSG_TIMEOUT_DATA "Jashte Kohe (pa te dhena te reja per %lu sekonda)"
#define MSG_SLEEPING "Po fle gjum..."
#define MSG_ALREADY_LOGGED "Je loguar nje here or mik"
#define MSG_ANY_PASSWORD "C'do password ben pune"
#define MSG_ANONYMOUS_LOGGED "Perdorues anonim i loguar"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Perdorues anonim i loguar ne virtual FTP"
#define MSG_USER_OK "Perdoruesi %s OK. Duhet dhe passwordi"
#define MSG_CANT_DO_TWICE "Nuk mund ta bejme ne kete sesion"
#define MSG_UNABLE_SECURE_ANON "E pamundur te ngrihet FTP anonime dhe e sigurte"
#define MSG_BANDWIDTH_RESTRICTED "Gjeresia brezit tuaj eshte e kufizuar"
#define MSG_NO_PASSWORD_NEEDED "C'do password ben pune"
#define MSG_NOTRUST "Me fal po nuk te besoj dot"
#define MSG_WHOAREYOU "Me thuaj kush je"
#define MSG_AUTH_FAILED "Njohja ne hyrje deshtoi"
#define MSG_AUTH_TOOMANY "Shume deshtime ne hyrje"
#define MSG_NO_HOMEDIR "Direktoria baze nuk gjendet - po e mbyll"
#define MSG_NO_HOMEDIR2 "%s nuk ekziston ose e paarriteshme"
#define MSG_START_SLASH "Fillon ne /"
#define MSG_USER_GROUP_ACCESS "Perdoruesi %s ka akses grupi ne"
#define MSG_FXP_SUPPORT "Ky server mundeson transferime FXP"
#define MSG_RATIO "Duhet te respektoni nje raport %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "E pamunduer te sigurohet nje chroot() burgosje"
#define MSG_CURRENT_DIR_IS "OK. Direktoria aktuale eshte %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Direktoria aktuale e kufizuar eshte %s"
#define MSG_IS_NOW_LOGGED_IN "%s eshte i loguar"
#define MSG_CANT_CHANGE_DIR "Nuk mund te nderrohet direktoria ne %s"
#define MSG_PATH_TOO_LONG "Shtegu eshte shume e gjate"
#define MSG_CANT_PASV "Nuk mund te perdoresh PASV ne lidhje IPv6. Ne vend te saj perdor EPSV."
#define MSG_CANT_PASSIVE "E pamundur te hapet nje lidhje pasive"
#define MSG_PORTS_BUSY "Te gjitha portat TCP te rezervuara jane te zena"
#define MSG_GETSOCKNAME_DATA "E pamundur te identifikohet data socket lokal"
#define MSG_GETPEERNAME "E pamundur te identifikohet socket lokal"
#define MSG_INVALID_IP "Me vjen keq, keni dhene adrese te gabuar"
#define MSG_NO_EPSV "Ju lutemi te perdorni nje klient sipas IPv6 qe suporton EPSV"
#define MSG_BAD_PORT "Me vjen keq, nuk mund te lidhem me portat < 1024"
#define MSG_NO_FXP "Nuk do cel nje lidhje me %s (vetem me %s)"
#define MSG_FXP "Transferim FXP : nga %s ne %s"
#define MSG_NO_DATA_CONN "Nuk ka lidhje data"
#define MSG_ACCEPT_FAILED "Lidhja nuk u pranua"
#define MSG_ACCEPT_SUCCESS "Lidhja data u pranua"
#define MSG_CNX_PORT_FAILED "Nuk u hap lidhja data ne port %d"
#define MSG_CNX_PORT "Po lidhem me porten %d"
#define MSG_ANON_CANT_MKD "Me vjen keq, perdorueseve anonim nuk u lejohet te krijojne direktori"
#define MSG_ANON_CANT_RMD "Me vjen keq, perdorueseve anonim nuk u lejohet te heqin direktori"
#define MSG_ANON_CANT_RENAME "Perdoruesit anonim nuk mund te levizin/heqin file"
#define MSG_ANON_CANT_CHANGE_PERMS "Perdoruesit anonim nuk mund te ndryshojne te drejtat"
#define MSG_GLOB_NO_MEMORY "Mbaroi memoria gjate globbing-ut te %s"
#define MSG_PROBABLY_DENIED "(Me siguri do te thote \"Nuk te lejohet te hysh\")"
#define MSG_GLOB_READ_ERROR "Gabim leximi gjate globbing-ut te %s"
#define MSG_GLOB_NO_MATCH "Nuk ka %s ne %s"
#define MSG_CHMOD_FAILED "Nuk u ndryshuan te drejtat mbi %s"
#define MSG_CHMOD_SUCCESS "U ndryshuan te drejtat mbi %s"
#define MSG_CHMOD_TOTAL_FAILURE "Me vjen keq, por nuk munda te ndryshoja asnje te drejte"
#define MSG_ANON_CANT_DELETE "Perdoruesit anonim nuk mund te fshijne file"
#define MSG_ANON_CANT_OVERWRITE "Perdoruesit anonim nuk mund te mbishkruajne file ekzistues"
#define MSG_DELE_FAILED "Nuk munda te fshij %s"
#define MSG_DELE_SUCCESS "U fshi %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "Asnje file nuk u fshi"
#define MSG_LOAD_TOO_HIGH \
    "Ngarkesa ishte %3.2f Kur u lidhe. Ne nuk lejojme shkarkime\n" \
    "nga perdorues anonim kur ngarkesa eshte aq e madhe. Ngarkime jane perhere\n" \
    "te pranuar."
#define MSG_OPEN_FAILURE "Nuk hap dot %s"
#define MSG_OPEN_FAILURE2 "Nuk hap dot ate file"
#define MSG_STAT_FAILURE "Nuk gjende kjo madhesi file"
#define MSG_STAT_FAILURE2 "Nuk kontrolloj dot ekzistencen e file"
#define MSG_REST_TOO_LARGE_FOR_FILE "Zhvendosja fillimit %lld eshte shume e madhe per file me kete madhesi %lld."
#define MSG_REST_RESET "Zhvendosja fillimit u kthye ne 0"
#define MSG_NOT_REGULAR_FILE "Mund te terheq vetem file te rregullta"
#define MSG_NOT_MODERATED \
    "Ky file eshte ngarkuar nga nje perdorues anonim. Nuk ka\n" \
    "marre lejen per shkarkim nga administratoret e sherbimit."
#define MSG_RATIO_DENIAL \
    "Me falni po raporti ngarkim/shkarkim eshte %u:%u .\n" \
    "Ju sapo bete ngarkim %llu Kb dhe bete shkarkime %llu Kb.\n" \
    "Ju lutemi beni ngarkim ndonje gje dhe rrini kot me vone."
#define MSG_NO_MORE_TO_DOWNLOAD "Nuk ka ngelur gje per tu shkarkuar"
#define MSG_WINNER "Kompjuteri eshte miku juaj. Besojini kompjuterit"
#define MSG_KBYTES_LEFT "%.1f kbytes jane per shkarkim"
#define MSG_ABORTED "Transferimi u anullua"
#define MSG_DATA_WRITE_FAILED "Gabim gjate shkrimit ne lidhjen e te dhenave"
#define MSG_DATA_READ_FAILED "Gabim gjate leximit nga lidhja e te dhenave"
#define MSG_MMAP_FAILED "Nuk mund te gjejme file ne memorie"
#define MSG_WRITE_FAILED "Gabim gjate shkrimit ne file"
#define MSG_TRANSFER_RATE_M "%.3f sekonda (te matura), %.2f Mbytes per sekond"
#define MSG_TRANSFER_RATE_K "%.3f sekonda (te matura), %.2f Kbytes per sekond"
#define MSG_TRANSFER_RATE_B "%.3f sekonda (te matura), %.2f bytes per sekond"
#define MSG_SPACE_FREE_M "%.1f Mbytes hapesire e lire ne disk"
#define MSG_SPACE_FREE_K "%f Kbytes hapesire e lire ne disk"
#define MSG_DOWNLOADED "u shkarkua"
#define MSG_REST_NOT_NUMERIC "REST kerkon nje parameter numerik"
#define MSG_REST_ASCII_STRICT "Shenjuesi i pergjigjes duhet te jete 0 ne ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "Po ristartojme %lld. Gjithsesi jemi ne ASCII mode"
#define MSG_REST_SUCCESS "Po ristartojme %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Emer drejtorie i ndaluar"
#define MSG_SANITY_FILE_FAILURE "Emer file i ndaluar: %s"
#define MSG_MKD_FAILURE "Nuk mund te krijoje direktorine"
#define MSG_MKD_SUCCESS "Direktoria u krijua me sukses"
#define MSG_RMD_FAILURE "Nuk mund te fshije direktorine"
#define MSG_RMD_SUCCESS "Direktoria u fshi me sukses"
#define MSG_TIMESTAMP_FAILURE "Nuk mund te gjej nje vule kohore"
#define MSG_MODE_ERROR "Vetem ASCII dhe binary modes mund te suportohen"
#define MSG_CREATE_FAILURE "Nuk mund te krijoje nje file"
#define MSG_ABRT_ONLY "ABRT eshte komanda e vetme gjate nje ngarkimi"
#define MSG_UPLOAD_PARTIAL "pjeserisht e ngarkuar"
#define MSG_REMOVED "e levizur"
#define MSG_UPLOADED "e ngarkuar"
#define MSG_GMTIME_FAILURE "Nuk mund te gjej kohen lokale"
#define MSG_TYPE_8BIT_FAILURE "Vetem byte me 8-bit mund te suportohen, nuk jemi 10 vjet me perpara"
#define MSG_TYPE_UNKNOWN "TYPE i panjohur"
#define MSG_TYPE_SUCCESS "TYPE eshte tani"
#define MSG_STRU_FAILURE "Vetem F(ile) suportohet"
#define MSG_MODE_FAILURE "Ju lutem perdorni S(tream) mode"
#define MSG_RENAME_ABORT "Po nderpresim veprimin e ri-emerimit"
#define MSG_RENAME_RNFR_SUCCESS "RNFR u pranua - file ekziston, gati per ne destinacion"
#define MSG_FILE_DOESNT_EXIST "Te na falni po ky file nuk ekziston"
#define MSG_RENAME_ALREADY_THERE "RENAME deshtoi - file destinacion ekziston"
#define MSG_RENAME_NORNFR "Duhet RNFR para RNTO"
#define MSG_RENAME_FAILURE "Deshtim ri-emerimi/levizje"
#define MSG_RENAME_SUCCESS "File u ri-emerua ose leviz me sukses"
#define MSG_NO_SUPERSERVER "Ju lutemi nisni pure-ftpd brenda nje super-serveri (si tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nuk mundem te gjejme llogarine 'ftp'"
#define MSG_CONF_ERR "Gabim konfigurimi"
#define MSG_NO_VIRTUAL_FILE "Mungon emri i file te perdorueseve virtual"
#define MSG_ILLEGAL_THROTTLING "Vlere e paligjshme per pershpejtim"
#define MSG_ILLEGAL_TRUSTED_GID "Id e grupit 'gid' i paligjshem per chroot"
#define MSG_ILLEGAL_USER_LIMIT "Limit i paligjshem per perdoruesin"
#define MSG_ILLEGAL_FACILITY "Emer pozicioni i panjohur"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "File konfigurimi LDAP i pavlefshem"
#define MSG_ILLEGAL_LOAD_LIMIT "Limit ngarkese i paligjshem"
#define MSG_ILLEGAL_PORTS_RANGE "Numerim portash i paligjshem"
#define MSG_ILLEGAL_LS_LIMITS "Limit 'ls' i paligjshem"
#define MSG_ILLEGAL_FORCE_PASSIVE "IP i forcuar per lidhje pasive i paligjshem"
#define MSG_ILLEGAL_RATIO "Raport ngarkim/shkarkim i paligjshem"
#define MSG_ILLEGAL_UID_LIMIT "Limit i id te perdoruesit 'uid' i paligjshem"
#define MSG_ILLEGAL_OPTION "Opsion i panjohur ne kohe ekzekutimi"
#define MSG_LDAP_MISSING_BASE "LDAPBaseDN mungon ne file te konfigurimit LDAP"
#define MSG_LDAP_WRONG_PARMS "Parametra LDAP te gabuar"
#define MSG_NEW_CONNECTION "Lidhje e re nga %s"
#define MSG_WELCOME_TO "Miresevini ne"
#define MSG_MAX_USERS "%lu perdorues (maksimumi) jane tashme te loguar, te na falni"
#define MSG_NB_USERS "Ju jeni perdoruesi numer %u nga %u te lejuar."
#define MSG_WELCOME_TIME "Koha lokale eshte %02d:%02d. Porta e serverit: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Ketu pranohet vetem FTP anonime"
#define MSG_RATIOS_EVERYONE "RAPORTET JANE TE AKTIVIZUARA PER TE GJITHE:"
#define MSG_RATIOS_ANONYMOUS "PERDORUESIT ANONIM NDIKOHEN NGA RAPORTI UL/DL:"
#define MSG_RATIOS_RULE "per shkarkim %u Mb, ngarkim/ngarkim i %u Mb te dhenash eshte i detyrueshem."
#define MSG_INFO_IDLE_M "Do te shkeputeni pas %lu minutash pa aktivitet."
#define MSG_INFO_IDLE_S "Do te shkeputeni pas %lu sekondash pa aktivitet."
#define MSG_CANT_READ_FILE "Na falni, ishte e pamundur te lexohej [%s]"
#define MSG_LS_TRUNCATED "Rezultati i shkurtuar ne %u krahasime"
#define MSG_LS_SUCCESS "%u krahasime ne total"
#define MSG_LOGOUT "Logout/Dalje."
#define MSG_AUTH_FAILED_LOG "Autentikimi nuk u krye dot per user [%s]"
#define MSG_ILLEGAL_UMASK "Umask e gabuar"
#define MSG_STANDALONE_FAILED "E pamundur te niset nje server i pavarur"
#define MSG_NO_ANONYMOUS_LOGIN "Ky eshte nje sistem privat - Nuk ka hyrje anonim"
#define MSG_ANONYMOUS_ANY_PASSWORD "Cdo fjalekalim mund te perdoret"
#define MSG_MAX_USERS_IP "Shume teper lidhje (%lu) nga kjo IP"
#define MSG_ACTIVE_DISABLED "Modaliteti aktiv eshte i c'aktivizuar"
#define MSG_TRANSFER_SUCCESSFUL "File u transferua me sukses"
#define MSG_NO_DISK_SPACE "Disku eshte plot - ju lutemi provoni te ngarkoni/ngarkim me vone"
#define MSG_OUT_OF_MEMORY "Ka mbaruar memoria"
#define MSG_ILLEGAL_TRUSTED_IP "Adrese IP ilegale por e besuar"
#define MSG_NO_ASCII_RESUME "Rikthimi me ASCII eshte i pasigurt, ju lutemi te fshini file njehere"
#define MSG_UNKNOWN_ALTLOG "Format logimi i panjohur"
#define MSG_ACCOUNT_DISABLED "Nuk mund te futem si [%s]: perdorues i c'aktivizuar"
#define MSG_SQL_WRONG_PARMS "Parametra SQL te gabuar"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "File konfigurimi SQL i gabuar"
#define MSG_SQL_MISSING_SERVER "Mungon serveri ne file te konfigurimit SQL"
#define MSG_SQL_DOWN "Serveri SQL duket jashte funksioni"
#define MSG_ILLEGAL_QUOTA "Kjo quota eshte e gabuar"
#define MSG_QUOTA_FILES "%llu file te perdorura (%d%%) - te autorizuara: %llu file"
#define MSG_QUOTA_SIZE "%llu Kbytes te perdorura (%d%%) - te autorizuara: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Quota u tejkalua: [%s] nuk do te ruhen"
#define MSG_AUTH_UNKNOWN "Metode autentikimi e panjohur"
#define MSG_PDB_BROKEN "E pamundur te lexohet file puredb i indeksuar (ose format i vjeter i detektuar) - Provo njehere pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s eshte nje alias per %s."
#define MSG_ALIASES_UNKNOWN "Alias i panjohur %s."
#define MSG_ALIASES_BROKEN_FILE "File me alias e demtuar"
#define MSG_ALIASES_LIST "Keto aliase jane te mundeshme :"
#define MSG_PERUSER_MAX "Nuk mund te pranoj me shume se %lu lidhje si i njejti perdorues"
#define MSG_IPV6_OK "Lidhjet IPv6 jane te mirepritura ne kete server."
#define MSG_TLS_INFO "TLS: E aktivizuar %s me %s, %d bite shifrimi sekret"
#define MSG_TLS_WEAK "TLS: Shifrim shume i dobet"
#define MSG_TLS_NEEDED "Na vjen keq, sesion te hapura dhe shifrime te dobeta nuk jane te pranuara ne kete server.\n" \
    "Ju lutem te lidheni perseri duke perdorur metodat e sigurise TLS."
#define MSG_ILLEGAL_CHARSET "Fusha karaktereve charset e papranueshme"
#define MSG_TLS_NO_CTX "TLS: Konteksti nuk u gjend. Po dalim."
#define MSG_PROT_OK "Niveli i mbrojtjes se te dhenave eshte \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Lidhja e te dhenave nuk mund te hapet me keto kushte PROT."
#define MSG_PROT_UNKNOWN_LEVEL "Niveli i mbrojtjes %s i pakuptueshem. Po kthehemi ne \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT duhet te paraprihet nga nje komande PBSZ"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP u pergjigj pa atributin userPassword, kontrolloni te drejtat e aksesit LDAP."
#define MSG_LDAP_INVALID_AUTH_METHOD "LDAPAuthMethod e pavlefshme nje file te konfigurimit. Duhet te jete 'bind' ose 'password'."
#define MSG_INVALID_ARGUMENT "Argument i pavlefshem: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
